@@ -1,11 +1,10 @@
 <?php
 /**
  * Piwik - Open source web analytics
- * 
+ *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: function.ajaxLoadingDiv.php 6300 2012-05-23 21:19:25Z SteveG $
- * 
+ *
  * @category Piwik
  * @package SmartyPlugins
  */
@@ -19,17 +18,17 @@
  */
 function smarty_function_ajaxLoadingDiv($params, &$smarty)
 {
-	if(empty($params['id'])) 
-	{
-		$id = 'ajaxLoading';
-	}
-	else
-	{
-		$id = $params['id'];
-	}
-	return '<div id="'.$id.'" style="display:none">'.
-				'<div class="loadingPiwik"><img src="themes/default/images/loading-blue.gif" alt="" /> '. 
-					Piwik_Translate('General_LoadingData') .
-				' </div>'.
-			'</div>';
+    if (empty($params['id'])) {
+        $id = 'ajaxLoading';
+    } else {
+        $id = $params['id'];
+    }
+    return '<div id="' . $id . '" style="display:none">' .
+        '<div class="loadingPiwik"><img src="themes/default/images/loading-blue.gif" alt="" /> ' .
+        Piwik_Translate('General_LoadingData') .
+        '<div class="loadingSegment">'.
+        Piwik_Translate('SegmentEditor_LoadingSegmentedDataMayTakeSomeTime') .
+        '</div>'.
+        ' </div>' .
+        '</div>';
 }
