@@ -1,11 +1,10 @@
 <?php
 /**
  * Piwik - Open source web analytics
- * 
+ *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: modifier.translate.php 6300 2012-05-23 21:19:25Z SteveG $
- * 
+ *
  * @category Piwik
  * @package SmartyPlugins
  */
@@ -28,20 +27,17 @@
  */
 function smarty_modifier_translate($stringToken)
 {
-	if(func_num_args() <= 1)
-	{
-		$aValues = array();
-	}
-	else
-	{
-		$aValues = func_get_args();
-		array_shift($aValues);
-	}
-	
-	try {
-		$stringTranslated = Piwik_Translate($stringToken, $aValues);
-	} catch( Exception $e) {
-		$stringTranslated = $stringToken; 
-	}
-	return $stringTranslated;
+    if (func_num_args() <= 1) {
+        $aValues = array();
+    } else {
+        $aValues = func_get_args();
+        array_shift($aValues);
+    }
+
+    try {
+        $stringTranslated = Piwik_Translate($stringToken, $aValues);
+    } catch (Exception $e) {
+        $stringTranslated = $stringToken;
+    }
+    return $stringTranslated;
 }
