@@ -4,7 +4,6 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- * @version $Id: Exception.php 6486 2012-06-20 21:01:20Z SteveG $
  *
  * @category Piwik
  * @package Piwik
@@ -16,5 +15,6 @@
  * @package Piwik
  * @subpackage Piwik_Tracker
  */
-class Piwik_Tracker_Db_Exception extends Exception {
+class Piwik_Tracker_Db_Exception extends Exception
+{
 }
