@@ -53,7 +53,6 @@ $translations = array(
 	'General_ColumnVisitsWithConversions' => 'ጉብኝት ከልወጣዎች ጋር',
 	'General_Save' => 'አስቀምጥ',
 	'General_Website' => 'ድር ጣቢያ',
-	'General_NoDataForGraph' => 'ለዚህ ግራፍ ምንም ውሂብ የለም',
 	'General_NoDataForTagCloud' => 'ለዚህ መለያ ክላውድ ምንም ውሂብ የለም.',
 	'General_PiwikXIsAvailablePleaseUpdateNow' => 'ፒዊክን %1$s ማግኘት ይቻላል። %2$s እባክዎን ያልቁት!%3$s (ለውጦቹን%4$s ይመልከቱ%5$s).',
 	'General_BackToPiwik' => 'ወደፒዊክ ተመለስ',
@@ -118,25 +117,25 @@ $translations = array(
 	'CoreHome_PeriodWeeks' => 'ሳምንታት',
 	'CoreHome_PeriodMonths' => 'ወራት',
 	'CoreHome_PeriodYears' => 'ዓመታት',
-	'CoreHome_DaySu_js' => 'እሁ',
-	'CoreHome_DayMo_js' => 'ሰኞ',
-	'CoreHome_DayTu_js' => 'ማክ',
-	'CoreHome_DayWe_js' => 'ረቡ',
-	'CoreHome_DayTh_js' => 'ሐሙ,',
-	'CoreHome_DayFr_js' => 'አርብ',
-	'CoreHome_DaySa_js' => 'ቅዳ',
-	'CoreHome_MonthJanuary_js' => 'ጥር',
-	'CoreHome_MonthFebruary_js' => 'የካቲት',
-	'CoreHome_MonthMarch_js' => 'መጋቢት',
-	'CoreHome_MonthApril_js' => 'ሚያዚያ',
-	'CoreHome_MonthMay_js' => 'ግንቦት',
-	'CoreHome_MonthJune_js' => 'ሰኔ',
-	'CoreHome_MonthJuly_js' => 'ሐምሌ',
-	'CoreHome_MonthAugust_js' => 'ነሐሴ',
-	'CoreHome_MonthSeptember_js' => 'መስከረም',
-	'CoreHome_MonthOctober_js' => 'ጥቅምት',
-	'CoreHome_MonthNovember_js' => 'ህዳር',
-	'CoreHome_MonthDecember_js' => 'ታህሳስ',
+	'General_DaySu_js' => 'እሁ',
+	'General_DayMo_js' => 'ሰኞ',
+	'General_DayTu_js' => 'ማክ',
+	'General_DayWe_js' => 'ረቡ',
+	'General_DayTh_js' => 'ሐሙ,',
+	'General_DayFr_js' => 'አርብ',
+	'General_DaySa_js' => 'ቅዳ',
+	'General_MonthJanuary_js' => 'ጥር',
+	'General_MonthFebruary_js' => 'የካቲት',
+	'General_MonthMarch_js' => 'መጋቢት',
+	'General_MonthApril_js' => 'ሚያዚያ',
+	'General_MonthMay_js' => 'ግንቦት',
+	'General_MonthJune_js' => 'ሰኔ',
+	'General_MonthJuly_js' => 'ሐምሌ',
+	'General_MonthAugust_js' => 'ነሐሴ',
+	'General_MonthSeptember_js' => 'መስከረም',
+	'General_MonthOctober_js' => 'ጥቅምት',
+	'General_MonthNovember_js' => 'ህዳር',
+	'General_MonthDecember_js' => 'ታህሳስ',
 	'CorePluginsAdmin_Plugins' => 'ተሰኪዎች',
 	'CorePluginsAdmin_PluginsManagement' => 'ተሰኪዎች መመነጅ',
 	'CorePluginsAdmin_MainDescription' => 'ተሰኪዎች የፒዊክን አገልግሎት ያራዝማሉ ያሰፋሉ። ተሰኪዎች አንዴ ከተጫኑ እዚሁ ጋር መገበርም ማቦዘንም ይቻላል።',
@@ -662,4 +661,143 @@ $translations = array(
 	'VisitTime_WidgetLocalTime' => 'ጉብኝቶች በአካባቢያዊ ሰዓት',
 	'VisitTime_WidgetServerTime' => 'ጉብኝቶች በአገልጋይ ሰዓት',
 	'VisitTime_SubmenuTimes' => 'ሰዓታት',
+	'UserLanguage_Language_aa' => 'አፋርኛ',
+	'UserLanguage_Language_ab' => 'አብሐዚኛ',
+	'UserLanguage_Language_af' => 'አፍሪካንስኛ',
+	'UserLanguage_Language_am' => 'አማርኛ',
+	'UserLanguage_Language_ar' => 'ዐርቢኛ',
+	'UserLanguage_Language_as' => 'አሳሜዛዊ',
+	'UserLanguage_Language_ay' => 'አያማርኛ',
+	'UserLanguage_Language_az' => 'አዜርባይጃንኛ',
+	'UserLanguage_Language_ba' => 'ባስኪርኛ',
+	'UserLanguage_Language_be' => 'ቤላራሻኛ',
+	'UserLanguage_Language_bg' => 'ቡልጋሪኛ',
+	'UserLanguage_Language_bh' => 'ቢሃሪ',
+	'UserLanguage_Language_bi' => 'ቢስላምኛ',
+	'UserLanguage_Language_bn' => 'በንጋሊኛ',
+	'UserLanguage_Language_bo' => 'ትበትንኛ',
+	'UserLanguage_Language_br' => 'ብሬቶንኛ',
+	'UserLanguage_Language_bs' => 'ቦስኒያንኛ',
+	'UserLanguage_Language_ca' => 'ካታላንኛ',
+	'UserLanguage_Language_co' => 'ኮርሲካኛ',
+	'UserLanguage_Language_cs' => 'ቼክኛ',
+	'UserLanguage_Language_cy' => 'ወልሽ',
+	'UserLanguage_Language_da' => 'ዴኒሽ',
+	'UserLanguage_Language_de' => 'ጀርመን',
+	'UserLanguage_Language_dz' => 'ድዞንግኻኛ',
+	'UserLanguage_Language_el' => 'ግሪክኛ',
+	'UserLanguage_Language_en' => 'እንግሊዝኛ',
+	'UserLanguage_Language_eo' => 'ኤስፐራንቶ',
+	'UserLanguage_Language_es' => 'ስፓኒሽ',
+	'UserLanguage_Language_et' => 'ኤስቶኒአን',
+	'UserLanguage_Language_eu' => 'ባስክኛ',
+	'UserLanguage_Language_fa' => 'ፐርሲያኛ',
+	'UserLanguage_Language_fi' => 'ፊኒሽ',
+	'UserLanguage_Language_fj' => 'ፊጂኛ',
+	'UserLanguage_Language_fo' => 'ፋሮኛ',
+	'UserLanguage_Language_fr' => 'ፈረንሳይኛ',
+	'UserLanguage_Language_fy' => 'ፍሪስኛ',
+	'UserLanguage_Language_ga' => 'አይሪሽ',
+	'UserLanguage_Language_gd' => 'እስኮትስ ጌልክኛ',
+	'UserLanguage_Language_gl' => 'ጋለጋኛ',
+	'UserLanguage_Language_gn' => 'ጓራኒኛ',
+	'UserLanguage_Language_gu' => 'ጉጃርቲኛ',
+	'UserLanguage_Language_ha' => 'ሃውሳኛ',
+	'UserLanguage_Language_he' => 'ዕብራስጥ',
+	'UserLanguage_Language_hi' => 'ሐንድኛ',
+	'UserLanguage_Language_hr' => 'ክሮሽያንኛ',
+	'UserLanguage_Language_hu' => 'ሀንጋሪኛ',
+	'UserLanguage_Language_hy' => 'አርመናዊ',
+	'UserLanguage_Language_ia' => 'ኢንቴርሊንጓ',
+	'UserLanguage_Language_id' => 'እንዶኒሲኛ',
+	'UserLanguage_Language_ie' => 'እንተርሊንግወ',
+	'UserLanguage_Language_ik' => 'እኑፒያቅኛ',
+	'UserLanguage_Language_is' => 'አይስላንድኛ',
+	'UserLanguage_Language_it' => 'ጣሊያንኛ',
+	'UserLanguage_Language_iu' => 'እኑክቲቱትኛ',
+	'UserLanguage_Language_ja' => 'ጃፓንኛ',
+	'UserLanguage_Language_jv' => 'ጃቫንኛ',
+	'UserLanguage_Language_ka' => 'ጊዮርጊያን',
+	'UserLanguage_Language_kk' => 'ካዛክኛ',
+	'UserLanguage_Language_kl' => 'ካላሊሱትኛ',
+	'UserLanguage_Language_km' => 'ክመርኛ',
+	'UserLanguage_Language_kn' => 'ካናዳኛ',
+	'UserLanguage_Language_ko' => 'ኮሪያኛ',
+	'UserLanguage_Language_ks' => 'ካሽሚርኛ',
+	'UserLanguage_Language_ku' => 'ኩርድሽኛ',
+	'UserLanguage_Language_ky' => 'ኪርጊዝኛ',
+	'UserLanguage_Language_la' => 'ላቲንኛ',
+	'UserLanguage_Language_ln' => 'ሊንጋላኛ',
+	'UserLanguage_Language_lo' => 'ላውስኛ',
+	'UserLanguage_Language_lt' => 'ሊቱአኒያን',
+	'UserLanguage_Language_lv' => 'ላትቪያን',
+	'UserLanguage_Language_mg' => 'ማላጋስኛ',
+	'UserLanguage_Language_mi' => 'ማዮሪኛ',
+	'UserLanguage_Language_mk' => 'ማከዶኒኛ',
+	'UserLanguage_Language_ml' => 'ማላያላምኛ',
+	'UserLanguage_Language_mn' => 'ሞንጎላዊኛ',
+	'UserLanguage_Language_mr' => 'ማራዚኛ',
+	'UserLanguage_Language_ms' => 'ማላይኛ',
+	'UserLanguage_Language_mt' => 'ማልቲስኛ',
+	'UserLanguage_Language_my' => 'ቡርማኛ',
+	'UserLanguage_Language_na' => 'ናኡሩ',
+	'UserLanguage_Language_ne' => 'ኔፓሊኛ',
+	'UserLanguage_Language_nl' => 'ደች',
+	'UserLanguage_Language_nn' => 'የኖርዌ አዲሱ ኖርዌጅያንኛ',
+	'UserLanguage_Language_no' => 'ኖርዌጂያን',
+	'UserLanguage_Language_oc' => 'ኦኪታንኛ',
+	'UserLanguage_Language_om' => 'ኦሮምኛ',
+	'UserLanguage_Language_or' => 'ኦሪያኛ',
+	'UserLanguage_Language_pa' => 'ፓንጃቢኛ',
+	'UserLanguage_Language_pl' => 'ፖሊሽ',
+	'UserLanguage_Language_ps' => 'ፑሽቶኛ',
+	'UserLanguage_Language_pt' => 'ፖርቱጋሊኛ',
+	'UserLanguage_Language_qu' => 'ኵቿኛ',
+	'UserLanguage_Language_rm' => 'ሮማንስ',
+	'UserLanguage_Language_rn' => 'ሩንዲኛ',
+	'UserLanguage_Language_ro' => 'ሮማኒያን',
+	'UserLanguage_Language_ru' => 'ራሽኛ',
+	'UserLanguage_Language_rw' => 'ኪንያርዋንድኛ',
+	'UserLanguage_Language_sa' => 'ሳንስክሪትኛ',
+	'UserLanguage_Language_sd' => 'ሲንድሂኛ',
+	'UserLanguage_Language_sg' => 'ሳንጎኛ',
+	'UserLanguage_Language_si' => 'ስንሃልኛ',
+	'UserLanguage_Language_sk' => 'ስሎቫክኛ',
+	'UserLanguage_Language_sl' => 'ስሎቪኛ',
+	'UserLanguage_Language_sm' => 'ሳሞአኛ',
+	'UserLanguage_Language_sn' => 'ሾናኛ',
+	'UserLanguage_Language_so' => 'ሱማልኛ',
+	'UserLanguage_Language_sq' => 'ልቤኒኛ',
+	'UserLanguage_Language_sr' => 'ሰርቢኛ',
+	'UserLanguage_Language_ss' => 'ስዋቲኛ',
+	'UserLanguage_Language_st' => 'ሶዞኛ',
+	'UserLanguage_Language_su' => 'ሱዳንኛ',
+	'UserLanguage_Language_sv' => 'ስዊድንኛ',
+	'UserLanguage_Language_sw' => 'ስዋሂሊኛ',
+	'UserLanguage_Language_ta' => 'ታሚልኛ',
+	'UserLanguage_Language_te' => 'ተሉጉኛ',
+	'UserLanguage_Language_tg' => 'ታጂኪኛ',
+	'UserLanguage_Language_th' => 'ታይኛ',
+	'UserLanguage_Language_ti' => 'ትግርኛ',
+	'UserLanguage_Language_tk' => 'ቱርክመንኛ',
+	'UserLanguage_Language_tl' => 'ታጋሎገኛ',
+	'UserLanguage_Language_tn' => 'ጽዋናዊኛ',
+	'UserLanguage_Language_to' => 'ቶንጋ',
+	'UserLanguage_Language_tr' => 'ቱርክኛ',
+	'UserLanguage_Language_ts' => 'ጾንጋኛ',
+	'UserLanguage_Language_tt' => 'ታታርኛ',
+	'UserLanguage_Language_tw' => 'ትዊኛ',
+	'UserLanguage_Language_ug' => 'ኡዊግሁርኛ',
+	'UserLanguage_Language_uk' => 'ዩክረኒኛ',
+	'UserLanguage_Language_ur' => 'ኡርዱኛ',
+	'UserLanguage_Language_uz' => 'ኡዝበክኛ',
+	'UserLanguage_Language_vi' => 'ቪትናምኛ',
+	'UserLanguage_Language_vo' => 'ቮላፑክኛ',
+	'UserLanguage_Language_wo' => 'ዎሎፍኛ',
+	'UserLanguage_Language_xh' => 'ዞሳኛ',
+	'UserLanguage_Language_yi' => 'ይዲሻዊኛ',
+	'UserLanguage_Language_yo' => 'ዮሩባዊኛ',
+	'UserLanguage_Language_za' => 'ዡዋንግኛ',
+	'UserLanguage_Language_zh' => 'ቻይንኛ',
+	'UserLanguage_Language_zu' => 'ዙሉኛ',
 );
