@@ -40,8 +40,45 @@ $translations = array(
 	'General_ColumnLabel' => 'Tiitel',
 	'General_Save' => 'Salvesta',
 	'General_Website' => 'Veebileht',
-	'General_NoDataForGraph' => 'Graafik - infot pole veel',
 	'General_NoDataForTagCloud' => 'Sildipilv - Infot ei ole veel.',
+	'General_ShortMonth_1' => 'jaan',
+	'General_ShortMonth_2' => 'veebr',
+	'General_ShortMonth_3' => 'märts',
+	'General_ShortMonth_4' => 'apr',
+	'General_ShortMonth_5' => 'mai',
+	'General_ShortMonth_6' => 'juuni',
+	'General_ShortMonth_7' => 'juuli',
+	'General_ShortMonth_8' => 'aug',
+	'General_ShortMonth_9' => 'sept',
+	'General_ShortMonth_10' => 'okt',
+	'General_ShortMonth_11' => 'nov',
+	'General_ShortMonth_12' => 'dets',
+	'General_LongMonth_1' => 'jaanuar',
+	'General_LongMonth_2' => 'veebruar',
+	'General_LongMonth_3' => 'märts',
+	'General_LongMonth_4' => 'aprill',
+	'General_LongMonth_5' => 'mai',
+	'General_LongMonth_6' => 'juuni',
+	'General_LongMonth_7' => 'juuli',
+	'General_LongMonth_8' => 'august',
+	'General_LongMonth_9' => 'september',
+	'General_LongMonth_10' => 'oktoober',
+	'General_LongMonth_11' => 'november',
+	'General_LongMonth_12' => 'detsember',
+	'General_ShortDay_1' => 'P',
+	'General_ShortDay_2' => 'E',
+	'General_ShortDay_3' => 'T',
+	'General_ShortDay_4' => 'K',
+	'General_ShortDay_5' => 'N',
+	'General_ShortDay_6' => 'R',
+	'General_ShortDay_7' => 'L',
+	'General_LongDay_1' => 'pühapäev',
+	'General_LongDay_2' => 'esmaspäev',
+	'General_LongDay_3' => 'teisipäev',
+	'General_LongDay_4' => 'kolmapäev',
+	'General_LongDay_5' => 'neljapäev',
+	'General_LongDay_6' => 'reede',
+	'General_LongDay_7' => 'laupäev',
 	'Actions_Actions' => 'Tegevused',
 	'Actions_SubmenuPages' => 'Vaadatud lehed',
 	'Actions_SubmenuOutlinks' => 'Väljuvad lingid',
@@ -54,54 +91,55 @@ $translations = array(
 	'CoreHome_PeriodWeek' => 'Nädal',
 	'CoreHome_PeriodMonth' => 'Kuu',
 	'CoreHome_PeriodYear' => 'Aasta',
-	'CoreHome_DaySu_js' => 'P',
-	'CoreHome_DayMo_js' => 'E',
-	'CoreHome_DayTu_js' => 'T',
-	'CoreHome_DayWe_js' => 'K',
-	'CoreHome_DayTh_js' => 'N',
-	'CoreHome_DayFr_js' => 'R',
-	'CoreHome_DaySa_js' => 'L',
-	'CoreHome_ShortDay_1_js' => 'Pühap',
-	'CoreHome_ShortDay_2_js' => 'Esmasp',
-	'CoreHome_ShortDay_3_js' => 'Teisip',
-	'CoreHome_ShortDay_4_js' => 'Kolmap',
-	'CoreHome_ShortDay_5_js' => 'Neljap',
-	'CoreHome_ShortDay_6_js' => 'Reede',
-	'CoreHome_ShortDay_7_js' => 'Laup',
-	'CoreHome_LongDay_1_js' => 'Pühapäev',
-	'CoreHome_LongDay_2_js' => 'Esmaspäev',
-	'CoreHome_LongDay_3_js' => 'Teisipäev',
-	'CoreHome_LongDay_4_js' => 'Kolmapäev',
-	'CoreHome_LongDay_5_js' => 'Neljapäev',
-	'CoreHome_LongDay_6_js' => 'Reede',
-	'CoreHome_LongDay_7_js' => 'Laupäev',
-	'CoreHome_ShortMonth_1_js' => 'Jaan',
-	'CoreHome_ShortMonth_2_js' => 'Veebr',
-	'CoreHome_ShortMonth_3_js' => 'Märts',
-	'CoreHome_ShortMonth_4_js' => 'Apr',
-	'CoreHome_ShortMonth_5_js' => 'Mai',
-	'CoreHome_ShortMonth_6_js' => 'Juuni',
-	'CoreHome_ShortMonth_7_js' => 'Juuli',
-	'CoreHome_ShortMonth_8_js' => 'Aug',
-	'CoreHome_ShortMonth_9_js' => 'Sept',
-	'CoreHome_ShortMonth_10_js' => 'Okt',
-	'CoreHome_ShortMonth_11_js' => 'Nov',
-	'CoreHome_ShortMonth_12_js' => 'Dets',
-	'CoreHome_MonthJanuary_js' => 'Jaanuar',
-	'CoreHome_MonthFebruary_js' => 'Veebruar',
-	'CoreHome_MonthMarch_js' => 'Märts',
-	'CoreHome_MonthApril_js' => 'Aprill',
-	'CoreHome_MonthMay_js' => 'Mai',
-	'CoreHome_MonthJune_js' => 'Juuni',
-	'CoreHome_MonthJuly_js' => 'Juuli',
-	'CoreHome_MonthAugust_js' => 'August',
-	'CoreHome_MonthSeptember_js' => 'September',
-	'CoreHome_MonthOctober_js' => 'Oktoober',
-	'CoreHome_MonthNovember_js' => 'November',
-	'CoreHome_MonthDecember_js' => 'Detsember',
+	'General_DaySu_js' => 'P',
+	'General_DayMo_js' => 'E',
+	'General_DayTu_js' => 'T',
+	'General_DayWe_js' => 'K',
+	'General_DayTh_js' => 'N',
+	'General_DayFr_js' => 'R',
+	'General_DaySa_js' => 'L',
+	'General_ShortDay_1_js' => 'Pühap',
+	'General_ShortDay_2_js' => 'Esmasp',
+	'General_ShortDay_3_js' => 'Teisip',
+	'General_ShortDay_4_js' => 'Kolmap',
+	'General_ShortDay_5_js' => 'Neljap',
+	'General_ShortDay_6_js' => 'Reede',
+	'General_ShortDay_7_js' => 'Laup',
+	'General_LongDay_1_js' => 'Pühapäev',
+	'General_LongDay_2_js' => 'Esmaspäev',
+	'General_LongDay_3_js' => 'Teisipäev',
+	'General_LongDay_4_js' => 'Kolmapäev',
+	'General_LongDay_5_js' => 'Neljapäev',
+	'General_LongDay_6_js' => 'Reede',
+	'General_LongDay_7_js' => 'Laupäev',
+	'General_ShortMonth_1_js' => 'Jaan',
+	'General_ShortMonth_2_js' => 'Veebr',
+	'General_ShortMonth_3_js' => 'Märts',
+	'General_ShortMonth_4_js' => 'Apr',
+	'General_ShortMonth_5_js' => 'Mai',
+	'General_ShortMonth_6_js' => 'Juuni',
+	'General_ShortMonth_7_js' => 'Juuli',
+	'General_ShortMonth_8_js' => 'Aug',
+	'General_ShortMonth_9_js' => 'Sept',
+	'General_ShortMonth_10_js' => 'Okt',
+	'General_ShortMonth_11_js' => 'Nov',
+	'General_ShortMonth_12_js' => 'Dets',
+	'General_MonthJanuary_js' => 'Jaanuar',
+	'General_MonthFebruary_js' => 'Veebruar',
+	'General_MonthMarch_js' => 'Märts',
+	'General_MonthApril_js' => 'Aprill',
+	'General_MonthMay_js' => 'Mai',
+	'General_MonthJune_js' => 'Juuni',
+	'General_MonthJuly_js' => 'Juuli',
+	'General_MonthAugust_js' => 'August',
+	'General_MonthSeptember_js' => 'September',
+	'General_MonthOctober_js' => 'Oktoober',
+	'General_MonthNovember_js' => 'November',
+	'General_MonthDecember_js' => 'Detsember',
 	'CorePluginsAdmin_Plugins' => 'Pluginad',
 	'CorePluginsAdmin_PluginsManagement' => 'Pluginate haldus',
 	'CorePluginsAdmin_MainDescription' => 'Plugins võimendavad ja suurendavad Piwik-i funktsionaalsust. Kui plugin on installeeritud ja aktiveeritud saad seda sisse ja välja lülitada siin.',
+	'CorePluginsAdmin_Plugin' => 'Plugin',
 	'CorePluginsAdmin_Version' => 'Versioon',
 	'CorePluginsAdmin_Status' => 'Olek',
 	'CorePluginsAdmin_Action' => 'Tegevus',
@@ -119,6 +157,7 @@ $translations = array(
 	'CoreUpdater_UpgradePiwik' => 'Uuenda Piwik',
 	'CoreUpdater_HelpMessageContent' => 'Vaata %1$s Piwik KKK %2$s milles selgitadakse tavapäraste probleemide põhjuseid ja lahendusi. %3$s Kui sa ei leia lahendust, siis küsi oma süsteemi administraatoritelt abi- nad võivad aidata juhul, kui need vead on seotud serveri või MySQL seadetega.',
 	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Kriitiline viga uuendamise protsessi ajal:',
+	'CoreUpdater_HelpMessageIntroductionWhenError' => 'The above is the core error message. It should help explain the cause, but if you require further help please:',
 	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Uuendamine edukalt lõpetatud, siiski esines protsessis vigu. Palun tutvu ülal vigade kirjeldustega. Saamaks rohkem abi:',
 	'CoreUpdater_UpgradeComplete' => 'Uuendamine lõpuni viidud!',
 	'CoreUpdater_WarningMessages' => 'Hoiatussõnumid:',
@@ -149,9 +188,11 @@ $translations = array(
 	'Installation_SetupWebsiteError' => 'Veebilehe lisamisel tekkis viga',
 	'Installation_SystemCheck' => 'Süsteemi kontroll',
 	'Installation_SystemCheckPhp' => 'PHP versioon',
+	'Installation_SystemCheckWriteDirs' => 'Directories with write access',
 	'Installation_SystemCheckWriteDirsHelp' => 'Parandamaks seda viga linux süsteemis, trüki sisse käsk/käsud.',
 	'Installation_SystemCheckMemoryLimit' => 'Mälu limiit',
 	'Installation_SystemCheckMemoryLimitHelp' => 'Suure liiklusega veebileht võib vajada arhiveerimiseks rohkem mälu, kui hetkel lubatud.<br />Vaata üle oma memory_limit oma php.ini failis, kui see osutub vajalikuks.',
+	'Installation_SystemCheckGD' => 'GD > 2.x (graphics)',
 	'Installation_SystemCheckGDHelp' => 'The sparklines (small graphs) will not work.',
 	'Installation_SystemCheckTimeLimitHelp' => 'Suure liiklusega veebilehe puhul, või arhiveerimisprotssess võtta rohkem aega, kui hetkel lubatud.<br />Vaata direktiiv max_execution_time  oma php.ini failis, kui see on vajalik',
 	'Installation_SystemCheckError' => 'Ilmnes viga - Enne jätkamist tuleb see parandada.',
@@ -211,6 +252,7 @@ $translations = array(
 	'TranslationsAdmin_MenuTranslations' => 'Tõlked',
 	'TranslationsAdmin_MenuLanguages' => 'Keeled',
 	'TranslationsAdmin_LanguageCode' => 'Keele kood',
+	'TranslationsAdmin_Plugin' => 'Plugin',
 	'TranslationsAdmin_Definition' => 'Definitsioon',
 	'TranslationsAdmin_DefaultString' => 'Vaikimisi keel (Inglise keel)',
 	'TranslationsAdmin_TranslationString' => 'Tõlke tõmmis (Praegune keel: %s)',
@@ -239,6 +281,7 @@ $translations = array(
 	'UserCountry_country_at' => 'Austria',
 	'UserCountry_country_au' => 'Austraalia',
 	'UserCountry_country_aw' => 'Aruuba',
+	'UserCountry_country_ax' => 'Ahvenamaa',
 	'UserCountry_country_az' => 'Azerbaijan',
 	'UserCountry_country_ba' => 'Bosnia ja Hertsegoviina',
 	'UserCountry_country_bb' => 'Barbados',
@@ -361,6 +404,7 @@ $translations = array(
 	'UserCountry_country_ma' => 'Morocco',
 	'UserCountry_country_mc' => 'Monako',
 	'UserCountry_country_md' => 'Moldova, Republic of',
+	'UserCountry_country_me' => 'Montenegro',
 	'UserCountry_country_mg' => 'Madagaskar',
 	'UserCountry_country_mh' => 'Marshalli Saared',
 	'UserCountry_country_mk' => 'Makedoonia',
@@ -439,6 +483,7 @@ $translations = array(
 	'UserCountry_country_th' => 'Taimaa',
 	'UserCountry_country_tj' => 'Tadzikistan',
 	'UserCountry_country_tk' => 'Tokelau',
+	'UserCountry_country_tl' => 'Ida-Timor',
 	'UserCountry_country_tm' => 'Türkmenistan',
 	'UserCountry_country_tn' => 'Tuneesia',
 	'UserCountry_country_to' => 'Tonga',
@@ -502,8 +547,11 @@ $translations = array(
 	'UsersManager_User' => 'Kasutaja',
 	'UsersManager_PrivNone' => 'Ligipääs puudub',
 	'UsersManager_PrivView' => 'Vaata',
+	'UsersManager_PrivAdmin' => 'Admin',
 	'UsersManager_ChangeAllConfirm' => 'Kas sa oled kindel soovis anda \'%s\' õigused kõigile veebilehtedele?',
 	'UsersManager_Password' => 'Salasõna',
+	'UsersManager_Email' => 'Email',
+	'UsersManager_Alias' => 'Alias',
 	'UsersManager_Edit' => 'Muuda',
 	'UsersManager_AddUser' => 'Lisa uus kasutaja',
 	'UsersManager_MenuUsers' => 'Kasutajad',
@@ -515,14 +563,18 @@ $translations = array(
 	'UsersManager_ExceptionAdminAnonymous' => 'Sa ei saa anda \'admin\' õiguseid \'anonymous\' kasutajale.',
 	'UsersManager_ExceptionEditAnonymous' => 'Anonüümset kasutajat ei saa muuta ega kustutada. Piwik kasutab seda määratlemaks kasutajat, kes ei ole veel sisse loginud. Näiteks, saad teha statistika lubada \'view\' statistikat õigused \'anonymous\' kasutajale.',
 	'UsersManager_ExceptionUserDoesNotExist' => 'Kasutaja \'%s\' puudub.',
+	'UsersManager_ExceptionAccessValues' => 'The parameter access must have one of the following values : [ %s ]',
 	'VisitFrequency_Evolution' => 'Perioodi areng',
 	'VisitFrequency_ReturnVisits' => '%s korduvat külastust',
 	'VisitFrequency_ReturnActions' => '%s tegevust tegi korduv külastaja',
 	'VisitFrequency_WidgetOverview' => 'Sageduse ülevaade',
 	'VisitFrequency_WidgetGraphReturning' => 'Korduvate külastuste graafik',
 	'VisitFrequency_SubmenuFrequency' => 'Sagedus',
+	'VisitorInterest_VisitsPerDuration' => 'Visits per visit duration',
+	'VisitorInterest_VisitsPerNbOfPages' => 'Visits per number of pages',
 	'VisitorInterest_WidgetLengths' => 'Külastuste kestvus',
 	'VisitorInterest_WidgetPages' => 'Erinevaid lehti külastuse kohta',
+	'VisitorInterest_PlusXMin' => '%s min',
 	'VisitorInterest_OnePage' => '1 leht',
 	'VisitorInterest_NPages' => '%s lehte',
 	'VisitsSummary_NbVisits' => '%s külastust',
@@ -541,4 +593,188 @@ $translations = array(
 	'VisitTime_WidgetServerTime' => 'Külastused serveri kellaaja järgi',
 	'VisitTime_SubmenuTimes' => 'Korda',
 	'VisitTime_NHour' => '%s',
+	'UserLanguage_Language_aa' => 'afari',
+	'UserLanguage_Language_ab' => 'abhaasi',
+	'UserLanguage_Language_ae' => 'avesta',
+	'UserLanguage_Language_af' => 'afrikaani',
+	'UserLanguage_Language_ak' => 'akani',
+	'UserLanguage_Language_am' => 'amhari',
+	'UserLanguage_Language_an' => 'aragoni',
+	'UserLanguage_Language_ar' => 'araabia',
+	'UserLanguage_Language_as' => 'assami',
+	'UserLanguage_Language_av' => 'avaari',
+	'UserLanguage_Language_ay' => 'aimara',
+	'UserLanguage_Language_az' => 'aserbaidžaani',
+	'UserLanguage_Language_ba' => 'baškiiri',
+	'UserLanguage_Language_be' => 'valgevene',
+	'UserLanguage_Language_bg' => 'bulgaaria',
+	'UserLanguage_Language_bh' => 'bihaari',
+	'UserLanguage_Language_bi' => 'bislama',
+	'UserLanguage_Language_bm' => 'bambara',
+	'UserLanguage_Language_bn' => 'bengali',
+	'UserLanguage_Language_bo' => 'tiibeti',
+	'UserLanguage_Language_br' => 'bretooni',
+	'UserLanguage_Language_bs' => 'bosnia',
+	'UserLanguage_Language_ca' => 'katalaani',
+	'UserLanguage_Language_ce' => 'tšetšeeni',
+	'UserLanguage_Language_ch' => 'tšamorro',
+	'UserLanguage_Language_co' => 'korsika',
+	'UserLanguage_Language_cr' => 'krii',
+	'UserLanguage_Language_cs' => 'tšehhi',
+	'UserLanguage_Language_cu' => 'kirikuslaavi',
+	'UserLanguage_Language_cv' => 'tšuvaši',
+	'UserLanguage_Language_cy' => 'kõmri',
+	'UserLanguage_Language_da' => 'taani',
+	'UserLanguage_Language_de' => 'saksa',
+	'UserLanguage_Language_dv' => 'maldiivi',
+	'UserLanguage_Language_dz' => 'bhutani',
+	'UserLanguage_Language_ee' => 'eve',
+	'UserLanguage_Language_el' => 'kreeka',
+	'UserLanguage_Language_en' => 'inglise',
+	'UserLanguage_Language_eo' => 'esperanto',
+	'UserLanguage_Language_es' => 'hispaania',
+	'UserLanguage_Language_et' => 'eesti',
+	'UserLanguage_Language_eu' => 'baski',
+	'UserLanguage_Language_fa' => 'pärsia',
+	'UserLanguage_Language_ff' => 'fulbe',
+	'UserLanguage_Language_fi' => 'soome',
+	'UserLanguage_Language_fj' => 'fidži',
+	'UserLanguage_Language_fo' => 'fääri',
+	'UserLanguage_Language_fr' => 'prantsuse',
+	'UserLanguage_Language_fy' => 'läänefriisi',
+	'UserLanguage_Language_ga' => 'iiri',
+	'UserLanguage_Language_gd' => 'gaeli',
+	'UserLanguage_Language_gl' => 'galeegi',
+	'UserLanguage_Language_gn' => 'guaranii',
+	'UserLanguage_Language_gu' => 'gudžarati',
+	'UserLanguage_Language_gv' => 'mänksi',
+	'UserLanguage_Language_ha' => 'hausa',
+	'UserLanguage_Language_he' => 'heebrea',
+	'UserLanguage_Language_hi' => 'hindi',
+	'UserLanguage_Language_ho' => 'motu',
+	'UserLanguage_Language_hr' => 'horvaadi',
+	'UserLanguage_Language_ht' => 'haiti',
+	'UserLanguage_Language_hu' => 'ungari',
+	'UserLanguage_Language_hy' => 'armeenia',
+	'UserLanguage_Language_hz' => 'herero',
+	'UserLanguage_Language_ia' => 'interlingua',
+	'UserLanguage_Language_id' => 'indoneesia',
+	'UserLanguage_Language_ie' => 'interlingue',
+	'UserLanguage_Language_ig' => 'ibo',
+	'UserLanguage_Language_ii' => 'Sichuani jii',
+	'UserLanguage_Language_ik' => 'injupiaki',
+	'UserLanguage_Language_io' => 'ido',
+	'UserLanguage_Language_is' => 'islandi',
+	'UserLanguage_Language_it' => 'itaalia',
+	'UserLanguage_Language_iu' => 'inuktituti',
+	'UserLanguage_Language_ja' => 'jaapani',
+	'UserLanguage_Language_jv' => 'jaava',
+	'UserLanguage_Language_ka' => 'gruusia',
+	'UserLanguage_Language_kg' => 'kongo',
+	'UserLanguage_Language_ki' => 'kikuju',
+	'UserLanguage_Language_kj' => 'ambo',
+	'UserLanguage_Language_kk' => 'kasahhi',
+	'UserLanguage_Language_kl' => 'grööni',
+	'UserLanguage_Language_km' => 'khmeeri',
+	'UserLanguage_Language_kn' => 'kannada',
+	'UserLanguage_Language_ko' => 'korea',
+	'UserLanguage_Language_kr' => 'kanuri',
+	'UserLanguage_Language_ks' => 'kašmiiri',
+	'UserLanguage_Language_ku' => 'kurdi',
+	'UserLanguage_Language_kv' => 'komi',
+	'UserLanguage_Language_kw' => 'korni',
+	'UserLanguage_Language_ky' => 'kirgiisi',
+	'UserLanguage_Language_la' => 'ladina',
+	'UserLanguage_Language_lb' => 'letseburgi',
+	'UserLanguage_Language_lg' => 'ganda',
+	'UserLanguage_Language_li' => 'limburgi',
+	'UserLanguage_Language_ln' => 'lingala',
+	'UserLanguage_Language_lo' => 'lao',
+	'UserLanguage_Language_lt' => 'leedu',
+	'UserLanguage_Language_lu' => 'luba',
+	'UserLanguage_Language_lv' => 'läti',
+	'UserLanguage_Language_mg' => 'malagassi',
+	'UserLanguage_Language_mh' => 'maršalli',
+	'UserLanguage_Language_mi' => 'maoori',
+	'UserLanguage_Language_mk' => 'makedoonia',
+	'UserLanguage_Language_ml' => 'malajalami',
+	'UserLanguage_Language_mn' => 'mongoli',
+	'UserLanguage_Language_mr' => 'marathi',
+	'UserLanguage_Language_ms' => 'malai',
+	'UserLanguage_Language_mt' => 'malta',
+	'UserLanguage_Language_my' => 'birma',
+	'UserLanguage_Language_na' => 'nauru',
+	'UserLanguage_Language_nb' => 'norra bokmål',
+	'UserLanguage_Language_nd' => 'põhjandebele',
+	'UserLanguage_Language_ne' => 'nepali',
+	'UserLanguage_Language_ng' => 'ndonga',
+	'UserLanguage_Language_nl' => 'hollandi',
+	'UserLanguage_Language_nn' => 'norra nynorsk',
+	'UserLanguage_Language_no' => 'norra',
+	'UserLanguage_Language_nr' => 'lõunandebele',
+	'UserLanguage_Language_nv' => 'navaho',
+	'UserLanguage_Language_ny' => 'njandža',
+	'UserLanguage_Language_oc' => 'oksitaani',
+	'UserLanguage_Language_oj' => 'odžibvei',
+	'UserLanguage_Language_om' => 'oromo',
+	'UserLanguage_Language_or' => 'oria',
+	'UserLanguage_Language_os' => 'osseedi',
+	'UserLanguage_Language_pa' => 'pandžabi',
+	'UserLanguage_Language_pi' => 'paali',
+	'UserLanguage_Language_pl' => 'poola',
+	'UserLanguage_Language_ps' => 'puštu',
+	'UserLanguage_Language_pt' => 'portugali',
+	'UserLanguage_Language_qu' => 'ketšua',
+	'UserLanguage_Language_rm' => 'retoromaani',
+	'UserLanguage_Language_rn' => 'rundi',
+	'UserLanguage_Language_ro' => 'rumeenia',
+	'UserLanguage_Language_ru' => 'vene',
+	'UserLanguage_Language_rw' => 'ruanda',
+	'UserLanguage_Language_sa' => 'sanskriti',
+	'UserLanguage_Language_sc' => 'sardiinia',
+	'UserLanguage_Language_sd' => 'sindhi',
+	'UserLanguage_Language_se' => 'põhjasaami',
+	'UserLanguage_Language_sg' => 'sango',
+	'UserLanguage_Language_si' => 'singali',
+	'UserLanguage_Language_sk' => 'slovaki',
+	'UserLanguage_Language_sl' => 'sloveeni',
+	'UserLanguage_Language_sm' => 'samoa',
+	'UserLanguage_Language_sn' => 'šona',
+	'UserLanguage_Language_so' => 'somaali',
+	'UserLanguage_Language_sq' => 'albaania',
+	'UserLanguage_Language_sr' => 'serbia',
+	'UserLanguage_Language_ss' => 'svaasi',
+	'UserLanguage_Language_st' => 'lõunasotho',
+	'UserLanguage_Language_su' => 'sunda',
+	'UserLanguage_Language_sv' => 'rootsi',
+	'UserLanguage_Language_sw' => 'suahiili',
+	'UserLanguage_Language_ta' => 'tamili',
+	'UserLanguage_Language_te' => 'telugu',
+	'UserLanguage_Language_tg' => 'tadžiki',
+	'UserLanguage_Language_th' => 'tai',
+	'UserLanguage_Language_ti' => 'tigrinja',
+	'UserLanguage_Language_tk' => 'türkmeeni',
+	'UserLanguage_Language_tl' => 'tagalogi',
+	'UserLanguage_Language_tn' => 'tsvana',
+	'UserLanguage_Language_to' => 'tonga',
+	'UserLanguage_Language_tr' => 'türgi',
+	'UserLanguage_Language_ts' => 'tsonga',
+	'UserLanguage_Language_tt' => 'tatari',
+	'UserLanguage_Language_tw' => 'tvii',
+	'UserLanguage_Language_ty' => 'tahiti',
+	'UserLanguage_Language_ug' => 'uiguuri',
+	'UserLanguage_Language_uk' => 'ukraina',
+	'UserLanguage_Language_ur' => 'urdu',
+	'UserLanguage_Language_uz' => 'usbeki',
+	'UserLanguage_Language_ve' => 'venda',
+	'UserLanguage_Language_vi' => 'vietnami',
+	'UserLanguage_Language_vo' => 'volapüki',
+	'UserLanguage_Language_wa' => 'vallooni',
+	'UserLanguage_Language_wo' => 'volofi',
+	'UserLanguage_Language_xh' => 'koosa',
+	'UserLanguage_Language_yi' => 'jidiši',
+	'UserLanguage_Language_yo' => 'joruba',
+	'UserLanguage_Language_za' => 'tšuangi',
+	'UserLanguage_Language_zh' => 'hiina',
+	'UserLanguage_Language_zu' => 'suulu',
 );
