@@ -99,7 +99,6 @@ $translations = array(
 	'General_NSeconds' => '%s segundo',
 	'General_RequiresFlash' => 'Piwik-en grafikoak bistaratzeko Flash behar da',
 	'General_GraphHelp' => 'Piwik-en grafikoak bistaratzeko informazio gehiago.',
-	'General_NoDataForGraph' => 'Daturik ez grafiko honentzat.',
 	'General_NoDataForTagCloud' => 'Daturik ez etiketa-hodei honentzat.',
 	'General_DisplaySimpleTable' => 'Bistaratu taula sinplea',
 	'General_DisplayTableWithMoreMetrics' => 'Bistaratu taula estatistika gehiagorekin',
@@ -202,51 +201,51 @@ $translations = array(
 	'CoreHome_PeriodWeeks' => 'aste',
 	'CoreHome_PeriodMonths' => 'hilabete',
 	'CoreHome_PeriodYears' => 'urte',
-	'CoreHome_DaySu_js' => 'ig',
-	'CoreHome_DayMo_js' => 'al',
-	'CoreHome_DayTu_js' => 'ar',
-	'CoreHome_DayWe_js' => 'az',
-	'CoreHome_DayTh_js' => 'og',
-	'CoreHome_DayFr_js' => 'ol',
-	'CoreHome_DaySa_js' => 'lr',
-	'CoreHome_ShortDay_1_js' => 'ig.',
-	'CoreHome_ShortDay_2_js' => 'al.',
-	'CoreHome_ShortDay_3_js' => 'ar.',
-	'CoreHome_ShortDay_4_js' => 'az.',
-	'CoreHome_ShortDay_5_js' => 'og.',
-	'CoreHome_ShortDay_6_js' => 'ol.',
-	'CoreHome_ShortDay_7_js' => 'lr.',
-	'CoreHome_LongDay_1_js' => 'igandea',
-	'CoreHome_LongDay_2_js' => 'astelehena',
-	'CoreHome_LongDay_3_js' => 'asteartea',
-	'CoreHome_LongDay_4_js' => 'asteazkena',
-	'CoreHome_LongDay_5_js' => 'osteguna',
-	'CoreHome_LongDay_6_js' => 'ostirala',
-	'CoreHome_LongDay_7_js' => 'larunbata',
-	'CoreHome_ShortMonth_1_js' => 'urtj',
-	'CoreHome_ShortMonth_2_js' => 'ots',
-	'CoreHome_ShortMonth_3_js' => 'mar',
-	'CoreHome_ShortMonth_4_js' => 'api',
-	'CoreHome_ShortMonth_5_js' => 'mai',
-	'CoreHome_ShortMonth_6_js' => 'eka',
-	'CoreHome_ShortMonth_7_js' => 'uzt',
-	'CoreHome_ShortMonth_8_js' => 'abu',
-	'CoreHome_ShortMonth_9_js' => 'ira',
-	'CoreHome_ShortMonth_10_js' => 'urr',
-	'CoreHome_ShortMonth_11_js' => 'aza',
-	'CoreHome_ShortMonth_12_js' => 'abe',
-	'CoreHome_MonthJanuary_js' => 'urtarrila',
-	'CoreHome_MonthFebruary_js' => 'otsaila',
-	'CoreHome_MonthMarch_js' => 'martxoa',
-	'CoreHome_MonthApril_js' => 'apirila',
-	'CoreHome_MonthMay_js' => 'maiatza',
-	'CoreHome_MonthJune_js' => 'ekaina',
-	'CoreHome_MonthJuly_js' => 'uztaila',
-	'CoreHome_MonthAugust_js' => 'abuztua',
-	'CoreHome_MonthSeptember_js' => 'iraila',
-	'CoreHome_MonthOctober_js' => 'urria',
-	'CoreHome_MonthNovember_js' => 'azaroa',
-	'CoreHome_MonthDecember_js' => 'abendua',
+	'General_DaySu_js' => 'ig',
+	'General_DayMo_js' => 'al',
+	'General_DayTu_js' => 'ar',
+	'General_DayWe_js' => 'az',
+	'General_DayTh_js' => 'og',
+	'General_DayFr_js' => 'ol',
+	'General_DaySa_js' => 'lr',
+	'General_ShortDay_1_js' => 'ig.',
+	'General_ShortDay_2_js' => 'al.',
+	'General_ShortDay_3_js' => 'ar.',
+	'General_ShortDay_4_js' => 'az.',
+	'General_ShortDay_5_js' => 'og.',
+	'General_ShortDay_6_js' => 'ol.',
+	'General_ShortDay_7_js' => 'lr.',
+	'General_LongDay_1_js' => 'igandea',
+	'General_LongDay_2_js' => 'astelehena',
+	'General_LongDay_3_js' => 'asteartea',
+	'General_LongDay_4_js' => 'asteazkena',
+	'General_LongDay_5_js' => 'osteguna',
+	'General_LongDay_6_js' => 'ostirala',
+	'General_LongDay_7_js' => 'larunbata',
+	'General_ShortMonth_1_js' => 'urtj',
+	'General_ShortMonth_2_js' => 'ots',
+	'General_ShortMonth_3_js' => 'mar',
+	'General_ShortMonth_4_js' => 'api',
+	'General_ShortMonth_5_js' => 'mai',
+	'General_ShortMonth_6_js' => 'eka',
+	'General_ShortMonth_7_js' => 'uzt',
+	'General_ShortMonth_8_js' => 'abu',
+	'General_ShortMonth_9_js' => 'ira',
+	'General_ShortMonth_10_js' => 'urr',
+	'General_ShortMonth_11_js' => 'aza',
+	'General_ShortMonth_12_js' => 'abe',
+	'General_MonthJanuary_js' => 'urtarrila',
+	'General_MonthFebruary_js' => 'otsaila',
+	'General_MonthMarch_js' => 'martxoa',
+	'General_MonthApril_js' => 'apirila',
+	'General_MonthMay_js' => 'maiatza',
+	'General_MonthJune_js' => 'ekaina',
+	'General_MonthJuly_js' => 'uztaila',
+	'General_MonthAugust_js' => 'abuztua',
+	'General_MonthSeptember_js' => 'iraila',
+	'General_MonthOctober_js' => 'urria',
+	'General_MonthNovember_js' => 'azaroa',
+	'General_MonthDecember_js' => 'abendua',
 	'CorePluginsAdmin_Plugins' => 'Pluginak',
 	'CorePluginsAdmin_PluginsManagement' => 'Pluginen kudeaketa',
 	'CorePluginsAdmin_MainDescription' => 'Piwik-en funtzionaltasunak hedatu eta zabaltzen dituzte pluginek. Plugin bat instalatu ondoren, hemendik gaitu edo ezgaitu dezakezu.',
@@ -358,7 +357,6 @@ $translations = array(
 	'Installation_DatabaseCreation' => 'Datu-basea sortzea',
 	'Installation_LargePiwikInstances' => 'Laguntza Piwik-en instalazio handientzat',
 	'Installation_JsTag' => 'JavaScript etiketa',
-	'Installation_JsTagArchivingHelp' => 'Trafiko ertain eta handiko webguneetarako, eman begirada <a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">Nola konfiguratu artxibatze automatikoko orria</a> dokumentuari Piwik azkar batean exekuta dadin!',
 	'Installation_Congratulations' => 'Zorionak',
 	'Installation_CongratulationsHelp' => '<p>Zorionak! Zure Piwik instalazioa osatu da.</p><p>Egiaztatu JavaScript kodea zure orrietan txertatuta dagoela eta ondoren itxaron lehenengo bisitei!</p>',
 	'Installation_ContinueToPiwik' => 'Jarraitu Piwik-era',
@@ -862,4 +860,106 @@ $translations = array(
 	'VisitTime_WidgetServerTime' => 'Zerbitzariaren orduko bisitak',
 	'VisitTime_SubmenuTimes' => 'Orduak',
 	'VisitTime_NHour' => '%sh',
+	'UserLanguage_Language_af' => 'afrikaans',
+	'UserLanguage_Language_am' => 'amharikera',
+	'UserLanguage_Language_ar' => 'arabiera',
+	'UserLanguage_Language_as' => 'assamera',
+	'UserLanguage_Language_az' => 'azerbaijanera',
+	'UserLanguage_Language_be' => 'bielorrusiera',
+	'UserLanguage_Language_bg' => 'bulgariera',
+	'UserLanguage_Language_bh' => 'bihariera',
+	'UserLanguage_Language_bn' => 'bengalera',
+	'UserLanguage_Language_br' => 'bretoiera',
+	'UserLanguage_Language_bs' => 'bosniera',
+	'UserLanguage_Language_ca' => 'katalana',
+	'UserLanguage_Language_cs' => 'txekiera',
+	'UserLanguage_Language_cy' => 'galesera',
+	'UserLanguage_Language_da' => 'daniera',
+	'UserLanguage_Language_de' => 'alemanera',
+	'UserLanguage_Language_el' => 'greziera',
+	'UserLanguage_Language_en' => 'ingelera',
+	'UserLanguage_Language_eo' => 'esperantoa',
+	'UserLanguage_Language_es' => 'espainiera',
+	'UserLanguage_Language_et' => 'estoniera',
+	'UserLanguage_Language_eu' => 'euskara',
+	'UserLanguage_Language_fa' => 'pertsiera',
+	'UserLanguage_Language_fi' => 'finlandiera',
+	'UserLanguage_Language_fo' => 'faroera',
+	'UserLanguage_Language_fr' => 'frantsesera',
+	'UserLanguage_Language_fy' => 'frisiarra',
+	'UserLanguage_Language_ga' => 'gaelikoa',
+	'UserLanguage_Language_gd' => 'eskoziar gaelikoa',
+	'UserLanguage_Language_gl' => 'galegoa',
+	'UserLanguage_Language_gn' => 'guaraniera',
+	'UserLanguage_Language_gu' => 'gujaratera',
+	'UserLanguage_Language_he' => 'hebreera',
+	'UserLanguage_Language_hi' => 'hindia',
+	'UserLanguage_Language_hr' => 'kroaziera',
+	'UserLanguage_Language_hu' => 'hungariera',
+	'UserLanguage_Language_hy' => 'armeniera',
+	'UserLanguage_Language_ia' => 'interlingua',
+	'UserLanguage_Language_id' => 'indonesiera',
+	'UserLanguage_Language_ie' => 'interlingue',
+	'UserLanguage_Language_is' => 'islandiera',
+	'UserLanguage_Language_it' => 'italiera',
+	'UserLanguage_Language_ja' => 'japoniera',
+	'UserLanguage_Language_jv' => 'javera',
+	'UserLanguage_Language_ka' => 'georgiera',
+	'UserLanguage_Language_km' => 'khemerera',
+	'UserLanguage_Language_kn' => 'kannada',
+	'UserLanguage_Language_ko' => 'koreera',
+	'UserLanguage_Language_ku' => 'kurduera',
+	'UserLanguage_Language_ky' => 'kirgizera',
+	'UserLanguage_Language_la' => 'latina',
+	'UserLanguage_Language_ln' => 'lingala',
+	'UserLanguage_Language_lo' => 'laosera',
+	'UserLanguage_Language_lt' => 'lituaniera',
+	'UserLanguage_Language_lv' => 'letoniera',
+	'UserLanguage_Language_mk' => 'mazedoniera',
+	'UserLanguage_Language_ml' => 'malayalamera',
+	'UserLanguage_Language_mn' => 'mongoliera',
+	'UserLanguage_Language_mr' => 'marathera',
+	'UserLanguage_Language_ms' => 'malaysiera',
+	'UserLanguage_Language_mt' => 'maltera',
+	'UserLanguage_Language_ne' => 'nepalera',
+	'UserLanguage_Language_nl' => 'nederlandera',
+	'UserLanguage_Language_nn' => 'norvegiera berria',
+	'UserLanguage_Language_no' => 'norvegiera',
+	'UserLanguage_Language_oc' => 'okzitaniera',
+	'UserLanguage_Language_or' => 'oriya',
+	'UserLanguage_Language_pa' => 'punjabera',
+	'UserLanguage_Language_pl' => 'poloniera',
+	'UserLanguage_Language_ps' => 'paxtuera',
+	'UserLanguage_Language_pt' => 'portugalera',
+	'UserLanguage_Language_ro' => 'errumaniera',
+	'UserLanguage_Language_ru' => 'errusiera',
+	'UserLanguage_Language_sa' => 'sanskritoa',
+	'UserLanguage_Language_sd' => 'sindhia',
+	'UserLanguage_Language_si' => 'sinhala',
+	'UserLanguage_Language_sk' => 'eslovakiera',
+	'UserLanguage_Language_sl' => 'esloveniera',
+	'UserLanguage_Language_so' => 'somaliera',
+	'UserLanguage_Language_sq' => 'albaniera',
+	'UserLanguage_Language_sr' => 'serbiera',
+	'UserLanguage_Language_st' => 'sesothoera',
+	'UserLanguage_Language_su' => 'sundanera',
+	'UserLanguage_Language_sv' => 'suediera',
+	'UserLanguage_Language_sw' => 'swahili',
+	'UserLanguage_Language_ta' => 'tamilera',
+	'UserLanguage_Language_te' => 'telugua',
+	'UserLanguage_Language_th' => 'thailandiera',
+	'UserLanguage_Language_ti' => 'tigrinya',
+	'UserLanguage_Language_tk' => 'turkmeniera',
+	'UserLanguage_Language_tl' => 'tagalog',
+	'UserLanguage_Language_tr' => 'turkiera',
+	'UserLanguage_Language_tw' => 'twia',
+	'UserLanguage_Language_ug' => 'uigurrera',
+	'UserLanguage_Language_uk' => 'ukrainera',
+	'UserLanguage_Language_ur' => 'urdu',
+	'UserLanguage_Language_uz' => 'uzbekera',
+	'UserLanguage_Language_vi' => 'vietnamera',
+	'UserLanguage_Language_xh' => 'xhosa',
+	'UserLanguage_Language_yi' => 'yiddishera',
+	'UserLanguage_Language_zh' => 'txinera',
+	'UserLanguage_Language_zu' => 'zuluera',
 );
