@@ -106,7 +106,6 @@ $translations = array(
 	'General_MediumToHighTrafficItIsRecommendedTo' => 'Á vefsvæðum með umferð yfir meðallagi, er mælt með að úrvinnsla skýrslna sé ekki framkvæmd tíðar en á hálftíma fresti (%s sekúndur) eða á klukkustundar fresti (%s seconds).',
 	'General_RequiresFlash' => 'Til að birta gröf í Piwik þarf Flash.',
 	'General_GraphHelp' => 'Nánari upplýsingar um birtingu grafa í Piwik.',
-	'General_NoDataForGraph' => 'Engin gögn fyrir þetta graf.',
 	'General_NoDataForTagCloud' => 'Engin gögn fyrir þetta klisjuský.',
 	'General_DisplaySimpleTable' => 'Sýna einfalda töflu.',
 	'General_DisplayTableWithMoreMetrics' => 'Sýna töflu með mörgum mæligildum.',
@@ -230,51 +229,51 @@ $translations = array(
 	'CoreHome_PeriodWeeks' => 'vikur',
 	'CoreHome_PeriodMonths' => 'mánuði',
 	'CoreHome_PeriodYears' => 'ár',
-	'CoreHome_DaySu_js' => 'su',
-	'CoreHome_DayMo_js' => 'má',
-	'CoreHome_DayTu_js' => 'þr',
-	'CoreHome_DayWe_js' => 'mi',
-	'CoreHome_DayTh_js' => 'fi',
-	'CoreHome_DayFr_js' => 'fö',
-	'CoreHome_DaySa_js' => 'la',
-	'CoreHome_ShortDay_1_js' => 'sun',
-	'CoreHome_ShortDay_2_js' => 'mán',
-	'CoreHome_ShortDay_3_js' => 'þri',
-	'CoreHome_ShortDay_4_js' => 'mið',
-	'CoreHome_ShortDay_5_js' => 'fim',
-	'CoreHome_ShortDay_6_js' => 'fös',
-	'CoreHome_ShortDay_7_js' => 'lau',
-	'CoreHome_LongDay_1_js' => 'sunnudagur',
-	'CoreHome_LongDay_2_js' => 'mánudagur',
-	'CoreHome_LongDay_3_js' => 'þriðjudagur',
-	'CoreHome_LongDay_4_js' => 'miðvikudagur',
-	'CoreHome_LongDay_5_js' => 'fimtudagur',
-	'CoreHome_LongDay_6_js' => 'föstudagur',
-	'CoreHome_LongDay_7_js' => 'laugardagur',
-	'CoreHome_ShortMonth_1_js' => 'jan',
-	'CoreHome_ShortMonth_2_js' => 'feb',
-	'CoreHome_ShortMonth_3_js' => 'mar',
-	'CoreHome_ShortMonth_4_js' => 'apr',
-	'CoreHome_ShortMonth_5_js' => 'maí',
-	'CoreHome_ShortMonth_6_js' => 'jún',
-	'CoreHome_ShortMonth_7_js' => 'júl',
-	'CoreHome_ShortMonth_8_js' => 'ágú',
-	'CoreHome_ShortMonth_9_js' => 'sep',
-	'CoreHome_ShortMonth_10_js' => 'okt',
-	'CoreHome_ShortMonth_11_js' => 'nóv',
-	'CoreHome_ShortMonth_12_js' => 'des',
-	'CoreHome_MonthJanuary_js' => 'janúar',
-	'CoreHome_MonthFebruary_js' => 'febrúar',
-	'CoreHome_MonthMarch_js' => 'mars',
-	'CoreHome_MonthApril_js' => 'apríl',
-	'CoreHome_MonthMay_js' => 'maí',
-	'CoreHome_MonthJune_js' => 'júní',
-	'CoreHome_MonthJuly_js' => 'júlí',
-	'CoreHome_MonthAugust_js' => 'ágúst',
-	'CoreHome_MonthSeptember_js' => 'september',
-	'CoreHome_MonthOctober_js' => 'október',
-	'CoreHome_MonthNovember_js' => 'nóvember',
-	'CoreHome_MonthDecember_js' => 'desember',
+	'General_DaySu_js' => 'su',
+	'General_DayMo_js' => 'má',
+	'General_DayTu_js' => 'þr',
+	'General_DayWe_js' => 'mi',
+	'General_DayTh_js' => 'fi',
+	'General_DayFr_js' => 'fö',
+	'General_DaySa_js' => 'la',
+	'General_ShortDay_1_js' => 'sun',
+	'General_ShortDay_2_js' => 'mán',
+	'General_ShortDay_3_js' => 'þri',
+	'General_ShortDay_4_js' => 'mið',
+	'General_ShortDay_5_js' => 'fim',
+	'General_ShortDay_6_js' => 'fös',
+	'General_ShortDay_7_js' => 'lau',
+	'General_LongDay_1_js' => 'sunnudagur',
+	'General_LongDay_2_js' => 'mánudagur',
+	'General_LongDay_3_js' => 'þriðjudagur',
+	'General_LongDay_4_js' => 'miðvikudagur',
+	'General_LongDay_5_js' => 'fimtudagur',
+	'General_LongDay_6_js' => 'föstudagur',
+	'General_LongDay_7_js' => 'laugardagur',
+	'General_ShortMonth_1_js' => 'jan',
+	'General_ShortMonth_2_js' => 'feb',
+	'General_ShortMonth_3_js' => 'mar',
+	'General_ShortMonth_4_js' => 'apr',
+	'General_ShortMonth_5_js' => 'maí',
+	'General_ShortMonth_6_js' => 'jún',
+	'General_ShortMonth_7_js' => 'júl',
+	'General_ShortMonth_8_js' => 'ágú',
+	'General_ShortMonth_9_js' => 'sep',
+	'General_ShortMonth_10_js' => 'okt',
+	'General_ShortMonth_11_js' => 'nóv',
+	'General_ShortMonth_12_js' => 'des',
+	'General_MonthJanuary_js' => 'janúar',
+	'General_MonthFebruary_js' => 'febrúar',
+	'General_MonthMarch_js' => 'mars',
+	'General_MonthApril_js' => 'apríl',
+	'General_MonthMay_js' => 'maí',
+	'General_MonthJune_js' => 'júní',
+	'General_MonthJuly_js' => 'júlí',
+	'General_MonthAugust_js' => 'ágúst',
+	'General_MonthSeptember_js' => 'september',
+	'General_MonthOctober_js' => 'október',
+	'General_MonthNovember_js' => 'nóvember',
+	'General_MonthDecember_js' => 'desember',
 	'CorePluginsAdmin_PluginDescription' => 'Viðmót fyrir Íbótastjórnun',
 	'CorePluginsAdmin_Plugins' => 'Íbætur',
 	'CorePluginsAdmin_PluginsManagement' => 'Íbótastjórnun',
@@ -476,6 +475,7 @@ $translations = array(
 	'UserCountry_country_bh' => 'Barein',
 	'UserCountry_country_bi' => 'Búrúndí',
 	'UserCountry_country_bj' => 'Benín',
+	'UserCountry_country_bl' => 'Saint Barthélemy',
 	'UserCountry_country_bm' => 'Bermúdaeyjar',
 	'UserCountry_country_bn' => 'Brúnei',
 	'UserCountry_country_bo' => 'Bólivía',
@@ -523,6 +523,7 @@ $translations = array(
 	'UserCountry_country_fi' => 'Finnland',
 	'UserCountry_country_fj' => 'Fídjieyjar',
 	'UserCountry_country_fk' => 'Falklandseyjar',
+	'UserCountry_country_fm' => 'Mikrónesía',
 	'UserCountry_country_fo' => 'Færeyjar',
 	'UserCountry_country_fr' => 'Frakkland',
 	'UserCountry_country_ga' => 'Gabon',
@@ -530,12 +531,14 @@ $translations = array(
 	'UserCountry_country_gd' => 'Grenada',
 	'UserCountry_country_ge' => 'Georgía',
 	'UserCountry_country_gf' => 'Franska Gvæjana',
+	'UserCountry_country_gg' => 'Guernsey',
 	'UserCountry_country_gh' => 'Gana',
 	'UserCountry_country_gi' => 'Gíbraltar',
 	'UserCountry_country_gl' => 'Grænland',
 	'UserCountry_country_gm' => 'Gambía',
 	'UserCountry_country_gn' => 'Gínea',
 	'UserCountry_country_gp' => 'Gvadelúpeyjar',
+	'UserCountry_country_gq' => 'Miðbaugs-Gínea',
 	'UserCountry_country_gr' => 'Grikkland',
 	'UserCountry_country_gs' => 'Suður-Georgía og Suður-Sandvíkureyjar',
 	'UserCountry_country_gt' => 'Gvatemala',
@@ -569,6 +572,7 @@ $translations = array(
 	'UserCountry_country_ki' => 'Kíribatí',
 	'UserCountry_country_km' => 'Kómoreyjar',
 	'UserCountry_country_kn' => 'Sankti Kristófer og Nevis',
+	'UserCountry_country_kp' => 'Norður-Kórea',
 	'UserCountry_country_kr' => 'Suður-Kórea',
 	'UserCountry_country_kw' => 'Kúveit',
 	'UserCountry_country_ky' => 'Cayman-eyjar',
@@ -583,10 +587,12 @@ $translations = array(
 	'UserCountry_country_lt' => 'Litháen',
 	'UserCountry_country_lu' => 'Lúxemborg',
 	'UserCountry_country_lv' => 'Lettland',
+	'UserCountry_country_ly' => 'Líbía',
 	'UserCountry_country_ma' => 'Marokkó',
 	'UserCountry_country_mc' => 'Mónakó',
 	'UserCountry_country_md' => 'Moldóva',
 	'UserCountry_country_me' => 'Svartfjallaland',
+	'UserCountry_country_mf' => 'Saint Martin',
 	'UserCountry_country_mg' => 'Madagaskar',
 	'UserCountry_country_mh' => 'Marshall-eyjar',
 	'UserCountry_country_mk' => 'Makedónía',
@@ -614,6 +620,8 @@ $translations = array(
 	'UserCountry_country_nl' => 'Holland',
 	'UserCountry_country_no' => 'Noregur',
 	'UserCountry_country_np' => 'Nepal',
+	'UserCountry_country_nr' => 'Nárú',
+	'UserCountry_country_nu' => 'Niue',
 	'UserCountry_country_nz' => 'Nýja-Sjáland',
 	'UserCountry_country_om' => 'Óman',
 	'UserCountry_country_pa' => 'Panama',
@@ -631,6 +639,7 @@ $translations = array(
 	'UserCountry_country_pw' => 'Palá',
 	'UserCountry_country_py' => 'Paragvæ',
 	'UserCountry_country_qa' => 'Katar',
+	'UserCountry_country_re' => 'Réunion',
 	'UserCountry_country_ro' => 'Rúmenía',
 	'UserCountry_country_rs' => 'Serbía',
 	'UserCountry_country_ru' => 'Rússland',
@@ -651,6 +660,7 @@ $translations = array(
 	'UserCountry_country_sn' => 'Senegal',
 	'UserCountry_country_so' => 'Sómalía',
 	'UserCountry_country_sr' => 'Súrínam',
+	'UserCountry_country_st' => 'Saó Tóme og Prinsípe',
 	'UserCountry_country_su' => 'Sovétríkin',
 	'UserCountry_country_sv' => 'El Salvador',
 	'UserCountry_country_sy' => 'Sýrland',
@@ -683,6 +693,7 @@ $translations = array(
 	'UserCountry_country_va' => 'Páfagarður (Vatíkanið)',
 	'UserCountry_country_vc' => 'Sankti Vinsent og Grenadíneyjar',
 	'UserCountry_country_ve' => 'Venesúela',
+	'UserCountry_country_vg' => 'Jómfrúaeyjar (bresku)',
 	'UserCountry_country_vi' => 'Jómfrúaeyjar',
 	'UserCountry_country_vn' => 'Víetnam',
 	'UserCountry_country_vu' => 'Vanúatú',
@@ -817,4 +828,188 @@ $translations = array(
 	'PDFReports_PiwikReports' => 'Piwik skýrslur',
 	'PDFReports_EmailHello' => 'Halló,',
 	'PDFReports_PleaseFindAttachedFile' => 'Gjörðu svo vel að skoða skýrslu um %2$s í skránni %1$s sem er hjálögð.',
+	'UserLanguage_Language_aa' => 'afár',
+	'UserLanguage_Language_ab' => 'abkasíska',
+	'UserLanguage_Language_ae' => 'avestíska',
+	'UserLanguage_Language_af' => 'afríkanska',
+	'UserLanguage_Language_ak' => 'akan',
+	'UserLanguage_Language_am' => 'amharíska',
+	'UserLanguage_Language_an' => 'aragonska',
+	'UserLanguage_Language_ar' => 'arabíska',
+	'UserLanguage_Language_as' => 'assamska',
+	'UserLanguage_Language_av' => 'avaríska',
+	'UserLanguage_Language_ay' => 'aímara',
+	'UserLanguage_Language_az' => 'aserska',
+	'UserLanguage_Language_ba' => 'baskír',
+	'UserLanguage_Language_be' => 'hvítrússneska',
+	'UserLanguage_Language_bg' => 'búlgarska',
+	'UserLanguage_Language_bh' => 'bíharí',
+	'UserLanguage_Language_bi' => 'bíslama',
+	'UserLanguage_Language_bm' => 'bambara',
+	'UserLanguage_Language_bn' => 'bengalska',
+	'UserLanguage_Language_bo' => 'tíbeska',
+	'UserLanguage_Language_br' => 'bretónska',
+	'UserLanguage_Language_bs' => 'bosníska',
+	'UserLanguage_Language_ca' => 'katalónska',
+	'UserLanguage_Language_ce' => 'tsjetsjenska',
+	'UserLanguage_Language_ch' => 'kamorró',
+	'UserLanguage_Language_co' => 'korsíska',
+	'UserLanguage_Language_cr' => 'krí',
+	'UserLanguage_Language_cs' => 'tékkneska',
+	'UserLanguage_Language_cu' => 'kirkjuslavneska',
+	'UserLanguage_Language_cv' => 'sjúvas',
+	'UserLanguage_Language_cy' => 'velska',
+	'UserLanguage_Language_da' => 'danska',
+	'UserLanguage_Language_de' => 'þýska',
+	'UserLanguage_Language_dv' => 'dívehí',
+	'UserLanguage_Language_dz' => 'dsongka',
+	'UserLanguage_Language_ee' => 'eve',
+	'UserLanguage_Language_el' => 'nýgríska (1453-)',
+	'UserLanguage_Language_en' => 'enska',
+	'UserLanguage_Language_eo' => 'esperantó',
+	'UserLanguage_Language_es' => 'spænska',
+	'UserLanguage_Language_et' => 'eistneska',
+	'UserLanguage_Language_eu' => 'baskneska',
+	'UserLanguage_Language_fa' => 'persneska',
+	'UserLanguage_Language_ff' => 'fúla',
+	'UserLanguage_Language_fi' => 'finnska',
+	'UserLanguage_Language_fj' => 'fídjeyska',
+	'UserLanguage_Language_fo' => 'færeyska',
+	'UserLanguage_Language_fr' => 'franska',
+	'UserLanguage_Language_fy' => 'frísneska',
+	'UserLanguage_Language_ga' => 'írska',
+	'UserLanguage_Language_gd' => 'skosk gelíska',
+	'UserLanguage_Language_gl' => 'gallegska',
+	'UserLanguage_Language_gn' => 'gvaraní',
+	'UserLanguage_Language_gu' => 'gújaratí',
+	'UserLanguage_Language_gv' => 'manx',
+	'UserLanguage_Language_ha' => 'hása',
+	'UserLanguage_Language_he' => 'hebreska',
+	'UserLanguage_Language_hi' => 'hindí',
+	'UserLanguage_Language_ho' => 'hírímótú',
+	'UserLanguage_Language_hr' => 'króatíska',
+	'UserLanguage_Language_ht' => 'haítíska',
+	'UserLanguage_Language_hu' => 'ungverska',
+	'UserLanguage_Language_hy' => 'armenska',
+	'UserLanguage_Language_hz' => 'hereró',
+	'UserLanguage_Language_ia' => 'interlingva',
+	'UserLanguage_Language_id' => 'indónesíska',
+	'UserLanguage_Language_ie' => 'interlingve',
+	'UserLanguage_Language_ig' => 'ígbó',
+	'UserLanguage_Language_ii' => 'sísúanjí',
+	'UserLanguage_Language_ik' => 'ínúpíak',
+	'UserLanguage_Language_io' => 'ídó',
+	'UserLanguage_Language_is' => 'íslenska',
+	'UserLanguage_Language_it' => 'ítalska',
+	'UserLanguage_Language_iu' => 'inúktitút',
+	'UserLanguage_Language_ja' => 'japanska',
+	'UserLanguage_Language_jv' => 'javanska',
+	'UserLanguage_Language_ka' => 'georgíska',
+	'UserLanguage_Language_kg' => 'kongó',
+	'UserLanguage_Language_ki' => 'kíkújú',
+	'UserLanguage_Language_kj' => 'kúanjama',
+	'UserLanguage_Language_kk' => 'kasakska',
+	'UserLanguage_Language_kl' => 'grænlenska',
+	'UserLanguage_Language_km' => 'kmer',
+	'UserLanguage_Language_kn' => 'kannada',
+	'UserLanguage_Language_ko' => 'kóreska',
+	'UserLanguage_Language_kr' => 'kanúrí',
+	'UserLanguage_Language_ks' => 'kasmírska',
+	'UserLanguage_Language_ku' => 'kúrdneska',
+	'UserLanguage_Language_kv' => 'komíska',
+	'UserLanguage_Language_kw' => 'korníska',
+	'UserLanguage_Language_ky' => 'kirgiska',
+	'UserLanguage_Language_la' => 'latína',
+	'UserLanguage_Language_lb' => 'lúxemborgíska',
+	'UserLanguage_Language_lg' => 'ganda',
+	'UserLanguage_Language_li' => 'limbúrgíska',
+	'UserLanguage_Language_ln' => 'lingala',
+	'UserLanguage_Language_lo' => 'laó',
+	'UserLanguage_Language_lt' => 'litháíska',
+	'UserLanguage_Language_lu' => 'lúbakatanga',
+	'UserLanguage_Language_lv' => 'lettneska',
+	'UserLanguage_Language_mg' => 'malagasíska',
+	'UserLanguage_Language_mh' => 'marshallska',
+	'UserLanguage_Language_mi' => 'maórí',
+	'UserLanguage_Language_mk' => 'makedónska',
+	'UserLanguage_Language_ml' => 'malajalam',
+	'UserLanguage_Language_mn' => 'mongólska',
+	'UserLanguage_Language_mr' => 'maratí',
+	'UserLanguage_Language_ms' => 'malaíska',
+	'UserLanguage_Language_mt' => 'maltneska',
+	'UserLanguage_Language_my' => 'burmneska',
+	'UserLanguage_Language_na' => 'nárúska',
+	'UserLanguage_Language_nb' => 'norskt bókmál',
+	'UserLanguage_Language_nd' => 'norðurndebele',
+	'UserLanguage_Language_ne' => 'nepalska',
+	'UserLanguage_Language_ng' => 'ndonga',
+	'UserLanguage_Language_nl' => 'hollenska',
+	'UserLanguage_Language_nn' => 'nýnorska',
+	'UserLanguage_Language_no' => 'norska',
+	'UserLanguage_Language_nr' => 'suðurndebele',
+	'UserLanguage_Language_nv' => 'navahó',
+	'UserLanguage_Language_ny' => 'Njanja; Sísjeva; Sjeva',
+	'UserLanguage_Language_oc' => 'Okkitíska (eftir 1500); Próvensalska',
+	'UserLanguage_Language_oj' => 'ojibva',
+	'UserLanguage_Language_om' => 'órómó',
+	'UserLanguage_Language_or' => 'óría',
+	'UserLanguage_Language_os' => 'ossetíska',
+	'UserLanguage_Language_pa' => 'púnjabí',
+	'UserLanguage_Language_pi' => 'palí',
+	'UserLanguage_Language_pl' => 'pólska',
+	'UserLanguage_Language_ps' => 'pastú',
+	'UserLanguage_Language_pt' => 'portúgalska',
+	'UserLanguage_Language_qu' => 'kvesjúa',
+	'UserLanguage_Language_rm' => 'retórómanska',
+	'UserLanguage_Language_rn' => 'rúndí',
+	'UserLanguage_Language_ro' => 'rúmenska',
+	'UserLanguage_Language_ru' => 'rússneska',
+	'UserLanguage_Language_rw' => 'kínjarvanda',
+	'UserLanguage_Language_sa' => 'sanskrít',
+	'UserLanguage_Language_sc' => 'sardínska',
+	'UserLanguage_Language_sd' => 'sindí',
+	'UserLanguage_Language_se' => 'norðursamíska',
+	'UserLanguage_Language_sg' => 'sangó',
+	'UserLanguage_Language_si' => 'singalesíska',
+	'UserLanguage_Language_sk' => 'slóvakíska',
+	'UserLanguage_Language_sl' => 'slóvenska',
+	'UserLanguage_Language_sm' => 'samóska',
+	'UserLanguage_Language_sn' => 'shóna',
+	'UserLanguage_Language_so' => 'sómalska',
+	'UserLanguage_Language_sq' => 'albanska',
+	'UserLanguage_Language_sr' => 'serbneska',
+	'UserLanguage_Language_ss' => 'svatí',
+	'UserLanguage_Language_st' => 'suðursótó',
+	'UserLanguage_Language_su' => 'súndanska',
+	'UserLanguage_Language_sv' => 'sænska',
+	'UserLanguage_Language_sw' => 'svahílí',
+	'UserLanguage_Language_ta' => 'tamílska',
+	'UserLanguage_Language_te' => 'telúgú',
+	'UserLanguage_Language_tg' => 'tadsjikska',
+	'UserLanguage_Language_th' => 'taílenska',
+	'UserLanguage_Language_ti' => 'tígrinja',
+	'UserLanguage_Language_tk' => 'túrkmenska',
+	'UserLanguage_Language_tl' => 'tagalog',
+	'UserLanguage_Language_tn' => 'tsúana',
+	'UserLanguage_Language_to' => 'Tongverska (Tongaeyjar)',
+	'UserLanguage_Language_tr' => 'tyrkneska',
+	'UserLanguage_Language_ts' => 'tsonga',
+	'UserLanguage_Language_tt' => 'tatarska',
+	'UserLanguage_Language_tw' => 'tví',
+	'UserLanguage_Language_ty' => 'tahítíska',
+	'UserLanguage_Language_ug' => 'úígúr',
+	'UserLanguage_Language_uk' => 'úkraínska',
+	'UserLanguage_Language_ur' => 'úrdú',
+	'UserLanguage_Language_uz' => 'úsbekska',
+	'UserLanguage_Language_ve' => 'venda',
+	'UserLanguage_Language_vi' => 'víetnamska',
+	'UserLanguage_Language_vo' => 'volapyk',
+	'UserLanguage_Language_wa' => 'vallónska',
+	'UserLanguage_Language_wo' => 'volof',
+	'UserLanguage_Language_xh' => 'sósa',
+	'UserLanguage_Language_yi' => 'jiddíska',
+	'UserLanguage_Language_yo' => 'jórúba',
+	'UserLanguage_Language_za' => 'súang',
+	'UserLanguage_Language_zh' => 'kínverska',
+	'UserLanguage_Language_zu' => 'súlú',
 );
