@@ -152,7 +152,6 @@ $translations = array(
 	'General_MediumToHighTrafficItIsRecommendedTo' => 'Vidutinio ir didelio srauto svetainėms rekomenduojame generuoti kasdienines ataskaitas kas pusę valandos (%s sekundės) arba kas valandą (%s sekundės).',
 	'General_RequiresFlash' => 'Grafikų atvaizdavimui reikalingas Flash',
 	'General_GraphHelp' => 'Daugiau informacijos apie grafikų atvaizdavimą',
-	'General_NoDataForGraph' => 'Šiam grafikui duomenų nėra',
 	'General_NoDataForTagCloud' => 'Šiam žymių debesiui duomenų nėra',
 	'General_DisplaySimpleTable' => 'Rodyti paprastą lentelę',
 	'General_DisplayTableWithMoreMetrics' => 'Rodyti lentelę su daugiau duomenų',
@@ -309,51 +308,51 @@ $translations = array(
 	'CoreHome_PeriodWeeks' => 'savaitės',
 	'CoreHome_PeriodMonths' => 'mėnesiai',
 	'CoreHome_PeriodYears' => 'metai',
-	'CoreHome_DaySu_js' => 'Se',
-	'CoreHome_DayMo_js' => 'Pi',
-	'CoreHome_DayTu_js' => 'An',
-	'CoreHome_DayWe_js' => 'Tr',
-	'CoreHome_DayTh_js' => 'Kt',
-	'CoreHome_DayFr_js' => 'Pn',
-	'CoreHome_DaySa_js' => 'Št',
-	'CoreHome_ShortDay_1_js' => 'Sek',
-	'CoreHome_ShortDay_2_js' => 'Pir',
-	'CoreHome_ShortDay_3_js' => 'Ant',
-	'CoreHome_ShortDay_4_js' => 'Tre',
-	'CoreHome_ShortDay_5_js' => 'Ket',
-	'CoreHome_ShortDay_6_js' => 'Pen',
-	'CoreHome_ShortDay_7_js' => 'Šeš',
-	'CoreHome_LongDay_1_js' => 'Sekmadienis',
-	'CoreHome_LongDay_2_js' => 'Pirmadienis',
-	'CoreHome_LongDay_3_js' => 'Antradienis',
-	'CoreHome_LongDay_4_js' => 'Trečiadienis',
-	'CoreHome_LongDay_5_js' => 'Ketvirtadienis',
-	'CoreHome_LongDay_6_js' => 'Penktadienis',
-	'CoreHome_LongDay_7_js' => 'Šeštadienis',
-	'CoreHome_ShortMonth_1_js' => 'Sau',
-	'CoreHome_ShortMonth_2_js' => 'Vas',
-	'CoreHome_ShortMonth_3_js' => 'Kov',
-	'CoreHome_ShortMonth_4_js' => 'Bal',
-	'CoreHome_ShortMonth_5_js' => 'Geg',
-	'CoreHome_ShortMonth_6_js' => 'Bir',
-	'CoreHome_ShortMonth_7_js' => 'Lie',
-	'CoreHome_ShortMonth_8_js' => 'Rgp',
-	'CoreHome_ShortMonth_9_js' => 'Rgs',
-	'CoreHome_ShortMonth_10_js' => 'Spa',
-	'CoreHome_ShortMonth_11_js' => 'Lap',
-	'CoreHome_ShortMonth_12_js' => 'Grd',
-	'CoreHome_MonthJanuary_js' => 'Sausis',
-	'CoreHome_MonthFebruary_js' => 'Vasaris',
-	'CoreHome_MonthMarch_js' => 'Kovas',
-	'CoreHome_MonthApril_js' => 'Balandis',
-	'CoreHome_MonthMay_js' => 'Gegužė',
-	'CoreHome_MonthJune_js' => 'Birželis',
-	'CoreHome_MonthJuly_js' => 'Liepa',
-	'CoreHome_MonthAugust_js' => 'Rugpjūtis',
-	'CoreHome_MonthSeptember_js' => 'Rugsėjis',
-	'CoreHome_MonthOctober_js' => 'Spalis',
-	'CoreHome_MonthNovember_js' => 'Lapkritis',
-	'CoreHome_MonthDecember_js' => 'Gruodis',
+	'General_DaySu_js' => 'Se',
+	'General_DayMo_js' => 'Pi',
+	'General_DayTu_js' => 'An',
+	'General_DayWe_js' => 'Tr',
+	'General_DayTh_js' => 'Kt',
+	'General_DayFr_js' => 'Pn',
+	'General_DaySa_js' => 'Št',
+	'General_ShortDay_1_js' => 'Sek',
+	'General_ShortDay_2_js' => 'Pir',
+	'General_ShortDay_3_js' => 'Ant',
+	'General_ShortDay_4_js' => 'Tre',
+	'General_ShortDay_5_js' => 'Ket',
+	'General_ShortDay_6_js' => 'Pen',
+	'General_ShortDay_7_js' => 'Šeš',
+	'General_LongDay_1_js' => 'Sekmadienis',
+	'General_LongDay_2_js' => 'Pirmadienis',
+	'General_LongDay_3_js' => 'Antradienis',
+	'General_LongDay_4_js' => 'Trečiadienis',
+	'General_LongDay_5_js' => 'Ketvirtadienis',
+	'General_LongDay_6_js' => 'Penktadienis',
+	'General_LongDay_7_js' => 'Šeštadienis',
+	'General_ShortMonth_1_js' => 'Sau',
+	'General_ShortMonth_2_js' => 'Vas',
+	'General_ShortMonth_3_js' => 'Kov',
+	'General_ShortMonth_4_js' => 'Bal',
+	'General_ShortMonth_5_js' => 'Geg',
+	'General_ShortMonth_6_js' => 'Bir',
+	'General_ShortMonth_7_js' => 'Lie',
+	'General_ShortMonth_8_js' => 'Rgp',
+	'General_ShortMonth_9_js' => 'Rgs',
+	'General_ShortMonth_10_js' => 'Spa',
+	'General_ShortMonth_11_js' => 'Lap',
+	'General_ShortMonth_12_js' => 'Grd',
+	'General_MonthJanuary_js' => 'Sausis',
+	'General_MonthFebruary_js' => 'Vasaris',
+	'General_MonthMarch_js' => 'Kovas',
+	'General_MonthApril_js' => 'Balandis',
+	'General_MonthMay_js' => 'Gegužė',
+	'General_MonthJune_js' => 'Birželis',
+	'General_MonthJuly_js' => 'Liepa',
+	'General_MonthAugust_js' => 'Rugpjūtis',
+	'General_MonthSeptember_js' => 'Rugsėjis',
+	'General_MonthOctober_js' => 'Spalis',
+	'General_MonthNovember_js' => 'Lapkritis',
+	'General_MonthDecember_js' => 'Gruodis',
 	'CorePluginsAdmin_PluginDescription' => 'Papildinių administravimo sąsaja.',
 	'CorePluginsAdmin_Plugins' => 'Papildiniai',
 	'CorePluginsAdmin_PluginsManagement' => 'Papildinių valdymas',
@@ -534,7 +533,6 @@ $translations = array(
 	'Installation_PleaseFixTheFollowingErrors' => 'Prašome ištaisyti šias klaidas',
 	'Installation_LargePiwikInstances' => 'Pagalba dideliems Piwik pavyzdžiams',
 	'Installation_JsTag' => 'JavaScript gairė (tag)',
-	'Installation_JsTagArchivingHelp' => 'Vidutinio ir aukšto lankytojų srauto svetainėms, rekomenduojame pasidomėti <a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">Kaip sukurti automatiškai archyvuojantį puslapį</a> ir priversti Piwik veikti dar greičiau!',
 	'Installation_Congratulations' => 'Sveikiname',
 	'Installation_CongratulationsHelp' => '<p>Sveikiname! Piwik diegimas baigtas.</p><p>Įsitikinkite, kad JavaScript žymė (tag) yra įrašyta visuose puslapiuose ir laukite pirmųjų lankytojų!</p>',
 	'Installation_ContinueToPiwik' => 'Grįžti į Piwik',
@@ -1183,4 +1181,188 @@ $translations = array(
 	'PDFReports_TableOfContent' => 'Ataskaitos sąrašas',
 	'PDFReports_TopOfReport' => 'Atgal į viršų',
 	'PDFReports_Pagination' => 'Puslapis %s iš %s',
+	'UserLanguage_Language_aa' => 'afarų',
+	'UserLanguage_Language_ab' => 'abchazų',
+	'UserLanguage_Language_ae' => 'avestų',
+	'UserLanguage_Language_af' => 'afrikanų',
+	'UserLanguage_Language_ak' => 'akanų',
+	'UserLanguage_Language_am' => 'amharų',
+	'UserLanguage_Language_an' => 'aragonesų',
+	'UserLanguage_Language_ar' => 'arabų',
+	'UserLanguage_Language_as' => 'asamų',
+	'UserLanguage_Language_av' => 'avarikų',
+	'UserLanguage_Language_ay' => 'aimarų',
+	'UserLanguage_Language_az' => 'azerbaidžaniečių',
+	'UserLanguage_Language_ba' => 'baškirų',
+	'UserLanguage_Language_be' => 'baltarusių',
+	'UserLanguage_Language_bg' => 'bulgarų',
+	'UserLanguage_Language_bh' => 'biharų',
+	'UserLanguage_Language_bi' => 'bislama',
+	'UserLanguage_Language_bm' => 'bambarų',
+	'UserLanguage_Language_bn' => 'bengalų',
+	'UserLanguage_Language_bo' => 'tibetiečių',
+	'UserLanguage_Language_br' => 'bretonų',
+	'UserLanguage_Language_bs' => 'bosnių',
+	'UserLanguage_Language_ca' => 'katalonų',
+	'UserLanguage_Language_ce' => 'čečėnų',
+	'UserLanguage_Language_ch' => 'čamorų',
+	'UserLanguage_Language_co' => 'korsikiečių',
+	'UserLanguage_Language_cr' => 'kry',
+	'UserLanguage_Language_cs' => 'čekų',
+	'UserLanguage_Language_cu' => 'bažnytinė slavų',
+	'UserLanguage_Language_cv' => 'čiuvašų',
+	'UserLanguage_Language_cy' => 'valų',
+	'UserLanguage_Language_da' => 'danų',
+	'UserLanguage_Language_de' => 'vokiečių',
+	'UserLanguage_Language_dv' => 'divehi',
+	'UserLanguage_Language_dz' => 'svazilando',
+	'UserLanguage_Language_ee' => 'eve',
+	'UserLanguage_Language_el' => 'graikų',
+	'UserLanguage_Language_en' => 'anglų',
+	'UserLanguage_Language_eo' => 'esperanto',
+	'UserLanguage_Language_es' => 'ispanų',
+	'UserLanguage_Language_et' => 'estų',
+	'UserLanguage_Language_eu' => 'baskų',
+	'UserLanguage_Language_fa' => 'persų',
+	'UserLanguage_Language_ff' => 'fulahų',
+	'UserLanguage_Language_fi' => 'suomių',
+	'UserLanguage_Language_fj' => 'fidžio',
+	'UserLanguage_Language_fo' => 'farerų kalba',
+	'UserLanguage_Language_fr' => 'prancūzų',
+	'UserLanguage_Language_fy' => 'vakarų fryzų',
+	'UserLanguage_Language_ga' => 'airių',
+	'UserLanguage_Language_gd' => 'škotų (gėlų)',
+	'UserLanguage_Language_gl' => 'galisų',
+	'UserLanguage_Language_gn' => 'gvaranių',
+	'UserLanguage_Language_gu' => 'gudžaratų',
+	'UserLanguage_Language_gv' => 'manks',
+	'UserLanguage_Language_ha' => 'hausų',
+	'UserLanguage_Language_he' => 'hebrajų',
+	'UserLanguage_Language_hi' => 'hindi',
+	'UserLanguage_Language_ho' => 'hiri motu',
+	'UserLanguage_Language_hr' => 'kroatų',
+	'UserLanguage_Language_ht' => 'haičio',
+	'UserLanguage_Language_hu' => 'vengrų',
+	'UserLanguage_Language_hy' => 'armėnų',
+	'UserLanguage_Language_hz' => 'herero',
+	'UserLanguage_Language_ia' => 'interlingva',
+	'UserLanguage_Language_id' => 'indoneziečių',
+	'UserLanguage_Language_ie' => 'interkalba',
+	'UserLanguage_Language_ig' => 'igbo',
+	'UserLanguage_Language_ii' => 'sičuan ji',
+	'UserLanguage_Language_ik' => 'inupiak',
+	'UserLanguage_Language_io' => 'ido',
+	'UserLanguage_Language_is' => 'islandų',
+	'UserLanguage_Language_it' => 'italų',
+	'UserLanguage_Language_iu' => 'inukitut',
+	'UserLanguage_Language_ja' => 'japonų',
+	'UserLanguage_Language_jv' => 'javiečių',
+	'UserLanguage_Language_ka' => 'gruzinų',
+	'UserLanguage_Language_kg' => 'kongo',
+	'UserLanguage_Language_ki' => 'kikui',
+	'UserLanguage_Language_kj' => 'kuaniama',
+	'UserLanguage_Language_kk' => 'kazachų',
+	'UserLanguage_Language_kl' => 'kalalisut',
+	'UserLanguage_Language_km' => 'khmerų',
+	'UserLanguage_Language_kn' => 'kanadų',
+	'UserLanguage_Language_ko' => 'korėjiečių',
+	'UserLanguage_Language_kr' => 'kanuri',
+	'UserLanguage_Language_ks' => 'kašmyro',
+	'UserLanguage_Language_ku' => 'kurdų',
+	'UserLanguage_Language_kv' => 'komi',
+	'UserLanguage_Language_kw' => 'kornų',
+	'UserLanguage_Language_ky' => 'kirgizų',
+	'UserLanguage_Language_la' => 'lotynų',
+	'UserLanguage_Language_lb' => 'liuksemburgiečių',
+	'UserLanguage_Language_lg' => 'ganda',
+	'UserLanguage_Language_li' => 'limburgiš',
+	'UserLanguage_Language_ln' => 'lingala',
+	'UserLanguage_Language_lo' => 'laosiečių',
+	'UserLanguage_Language_lt' => 'lietuvių',
+	'UserLanguage_Language_lu' => 'luba katanga',
+	'UserLanguage_Language_lv' => 'latvių',
+	'UserLanguage_Language_mg' => 'malagasijos',
+	'UserLanguage_Language_mh' => 'Maršalo salų',
+	'UserLanguage_Language_mi' => 'maorių',
+	'UserLanguage_Language_mk' => 'makedonų',
+	'UserLanguage_Language_ml' => 'malajalių',
+	'UserLanguage_Language_mn' => 'mongolų',
+	'UserLanguage_Language_mr' => 'maratų',
+	'UserLanguage_Language_ms' => 'malajiečių',
+	'UserLanguage_Language_mt' => 'maltiečių',
+	'UserLanguage_Language_my' => 'birmiečių',
+	'UserLanguage_Language_na' => 'naurų',
+	'UserLanguage_Language_nb' => 'Norvegijos bokmal',
+	'UserLanguage_Language_nd' => 'šiaurės ndebelų',
+	'UserLanguage_Language_ne' => 'nepalų',
+	'UserLanguage_Language_ng' => 'ndongų',
+	'UserLanguage_Language_nl' => 'olandų',
+	'UserLanguage_Language_nn' => 'naujoji norvegų',
+	'UserLanguage_Language_no' => 'norvegų',
+	'UserLanguage_Language_nr' => 'pietų ndebele',
+	'UserLanguage_Language_nv' => 'navajų',
+	'UserLanguage_Language_ny' => 'nianja',
+	'UserLanguage_Language_oc' => 'provansalų',
+	'UserLanguage_Language_oj' => 'ojibva',
+	'UserLanguage_Language_om' => 'oromo',
+	'UserLanguage_Language_or' => 'orijų',
+	'UserLanguage_Language_os' => 'osetinų',
+	'UserLanguage_Language_pa' => 'pandžabų',
+	'UserLanguage_Language_pi' => 'pali',
+	'UserLanguage_Language_pl' => 'lenkų',
+	'UserLanguage_Language_ps' => 'puštūnų',
+	'UserLanguage_Language_pt' => 'portugalų',
+	'UserLanguage_Language_qu' => 'kečujų',
+	'UserLanguage_Language_rm' => 'raeto romanų',
+	'UserLanguage_Language_rn' => 'rundi',
+	'UserLanguage_Language_ro' => 'rumunų',
+	'UserLanguage_Language_ru' => 'rusų',
+	'UserLanguage_Language_rw' => 'kinjarvanda',
+	'UserLanguage_Language_sa' => 'sanskritas',
+	'UserLanguage_Language_sc' => 'sardiniečių',
+	'UserLanguage_Language_sd' => 'sindų',
+	'UserLanguage_Language_se' => 'šiaurinių samių',
+	'UserLanguage_Language_sg' => 'sango',
+	'UserLanguage_Language_si' => 'sinhalų',
+	'UserLanguage_Language_sk' => 'slovakų',
+	'UserLanguage_Language_sl' => 'slovėnų',
+	'UserLanguage_Language_sm' => 'samoa',
+	'UserLanguage_Language_sn' => 'šona',
+	'UserLanguage_Language_so' => 'somalių',
+	'UserLanguage_Language_sq' => 'albanų',
+	'UserLanguage_Language_sr' => 'serbų',
+	'UserLanguage_Language_ss' => 'svati',
+	'UserLanguage_Language_st' => 'pietų sesuto',
+	'UserLanguage_Language_su' => 'sundų',
+	'UserLanguage_Language_sv' => 'švedų',
+	'UserLanguage_Language_sw' => 'svahili',
+	'UserLanguage_Language_ta' => 'tamilų',
+	'UserLanguage_Language_te' => 'telugų',
+	'UserLanguage_Language_tg' => 'tadžikų',
+	'UserLanguage_Language_th' => 'tajų',
+	'UserLanguage_Language_ti' => 'tigrajų',
+	'UserLanguage_Language_tk' => 'turkmėnų',
+	'UserLanguage_Language_tl' => 'tagalogų',
+	'UserLanguage_Language_tn' => 'tsvana',
+	'UserLanguage_Language_to' => 'tonga',
+	'UserLanguage_Language_tr' => 'turkų',
+	'UserLanguage_Language_ts' => 'tsonga',
+	'UserLanguage_Language_tt' => 'totorių',
+	'UserLanguage_Language_tw' => 'tvi',
+	'UserLanguage_Language_ty' => 'taitiečių',
+	'UserLanguage_Language_ug' => 'uigūrų',
+	'UserLanguage_Language_uk' => 'ukrainiečių',
+	'UserLanguage_Language_ur' => 'urdų',
+	'UserLanguage_Language_uz' => 'uzbekų',
+	'UserLanguage_Language_ve' => 'venda',
+	'UserLanguage_Language_vi' => 'vietnamiečių',
+	'UserLanguage_Language_vo' => 'volapiuk',
+	'UserLanguage_Language_wa' => 'valonų',
+	'UserLanguage_Language_wo' => 'volof',
+	'UserLanguage_Language_xh' => 'kosų',
+	'UserLanguage_Language_yi' => 'jidiš',
+	'UserLanguage_Language_yo' => 'joruba',
+	'UserLanguage_Language_za' => 'chuang',
+	'UserLanguage_Language_zh' => 'kinų',
+	'UserLanguage_Language_zu' => 'zulų',
 );
