@@ -41,10 +41,7 @@ $translations = array(
 	'General_Description' => 'Apraksts',
 	'General_Done' => 'Pabeigts',
 	'General_PoweredBy' => 'Darbina',
-	'General_MetricsToPlot' => 'Mērījumi plānošanai',
 	'General_RowsToDisplay' => 'Rindas parādīšanai',
-	'General_MetricToPlot' => 'Mērījums plānošanai',
-	'General_RecordsToPlot' => 'Ieraksti plānošanai',
 	'General_Name' => 'Vārds',
 	'General_Value' => 'Vērtība',
 	'General_Total' => 'Kopā',
@@ -78,7 +75,6 @@ $translations = array(
 	'General_NumberOfVisits' => 'Apmeklējumu skaits',
 	'General_VisitConvertedGoal' => 'Apmeklējums sasniedza vismaz vienu mērķi',
 	'General_VisitConvertedGoalId' => 'Apmeklējums sasniedza konkrētu mērķi ar Id',
-	'General_EcommerceVisitStatus' => 'Apmeklējuma e-komercijas statuss apmeklējuma beigās. Piemēra, lai izvēlētos visus apmeklējumus, kuros tikai veikts e-komercijas pasūtījums, API pieprasījums saturētu %s',
 	'General_VisitConvertedNGoals' => 'Apmeklējums sasniedza %s mērķus',
 	'General_NewVisitor' => 'Jauns apmeklētājs',
 	'General_NewVisits' => 'Jauni apmeklējumi',
@@ -186,7 +182,6 @@ $translations = array(
 	'General_MediumToHighTrafficItIsRecommendedTo' => 'Vidēja un augsta apmklējuma vietnēm iesakam apstrādāt atskaites ne biežāk kā katru pusstundu (%s sekundes) vai katru stundu (%s sekundes).',
 	'General_RequiresFlash' => 'Lai Piwik parādītu grafikus ir nepieciešams Flash',
 	'General_GraphHelp' => 'Vairāk informācijas par grafiku parādīšanu Piwik',
-	'General_NoDataForGraph' => 'Nav datu šim grafikam.',
 	'General_NoDataForTagCloud' => 'Nav datu šim iezīmju mākonim.',
 	'General_DisplaySimpleTable' => 'Rādīt vienkāršu tabulu',
 	'General_DisplayTableWithMoreMetrics' => 'Rādīt tabulu ar vairāk datiem',
@@ -357,51 +352,51 @@ $translations = array(
 	'CoreHome_PeriodWeeks' => 'nedēļas',
 	'CoreHome_PeriodMonths' => 'mēneši',
 	'CoreHome_PeriodYears' => 'gadi',
-	'CoreHome_DaySu_js' => 'Sv',
-	'CoreHome_DayMo_js' => 'P',
-	'CoreHome_DayTu_js' => 'O',
-	'CoreHome_DayWe_js' => 'T',
-	'CoreHome_DayTh_js' => 'C',
-	'CoreHome_DayFr_js' => 'Pk',
-	'CoreHome_DaySa_js' => 'S',
-	'CoreHome_ShortDay_1_js' => 'Sv',
-	'CoreHome_ShortDay_2_js' => 'P',
-	'CoreHome_ShortDay_3_js' => 'O',
-	'CoreHome_ShortDay_4_js' => 'T',
-	'CoreHome_ShortDay_5_js' => 'C',
-	'CoreHome_ShortDay_6_js' => 'Pk',
-	'CoreHome_ShortDay_7_js' => 'S',
-	'CoreHome_LongDay_1_js' => 'Svētdiena',
-	'CoreHome_LongDay_2_js' => 'Pirmdiena',
-	'CoreHome_LongDay_3_js' => 'Otrdiena',
-	'CoreHome_LongDay_4_js' => 'Trešdiena',
-	'CoreHome_LongDay_5_js' => 'Ceturtdiena',
-	'CoreHome_LongDay_6_js' => 'Piektdiena',
-	'CoreHome_LongDay_7_js' => 'Sestdiena',
-	'CoreHome_ShortMonth_1_js' => 'Jan',
-	'CoreHome_ShortMonth_2_js' => 'Feb',
-	'CoreHome_ShortMonth_3_js' => 'Mar',
-	'CoreHome_ShortMonth_4_js' => 'Apr',
-	'CoreHome_ShortMonth_5_js' => 'Mai',
-	'CoreHome_ShortMonth_6_js' => 'Jūn',
-	'CoreHome_ShortMonth_7_js' => 'Jūl',
-	'CoreHome_ShortMonth_8_js' => 'Aug',
-	'CoreHome_ShortMonth_9_js' => 'Sep',
-	'CoreHome_ShortMonth_10_js' => 'Okt',
-	'CoreHome_ShortMonth_11_js' => 'Nov',
-	'CoreHome_ShortMonth_12_js' => 'Dec',
-	'CoreHome_MonthJanuary_js' => 'Janvāris',
-	'CoreHome_MonthFebruary_js' => 'Februāris',
-	'CoreHome_MonthMarch_js' => 'Marts',
-	'CoreHome_MonthApril_js' => 'Aprīlis',
-	'CoreHome_MonthMay_js' => 'Maijs',
-	'CoreHome_MonthJune_js' => 'Jūnijs',
-	'CoreHome_MonthJuly_js' => 'Jūlijs',
-	'CoreHome_MonthAugust_js' => 'Augusts',
-	'CoreHome_MonthSeptember_js' => 'Septembris',
-	'CoreHome_MonthOctober_js' => 'Oktobris',
-	'CoreHome_MonthNovember_js' => 'Novembris',
-	'CoreHome_MonthDecember_js' => 'Decembris',
+	'General_DaySu_js' => 'Sv',
+	'General_DayMo_js' => 'P',
+	'General_DayTu_js' => 'O',
+	'General_DayWe_js' => 'T',
+	'General_DayTh_js' => 'C',
+	'General_DayFr_js' => 'Pk',
+	'General_DaySa_js' => 'S',
+	'General_ShortDay_1_js' => 'Sv',
+	'General_ShortDay_2_js' => 'P',
+	'General_ShortDay_3_js' => 'O',
+	'General_ShortDay_4_js' => 'T',
+	'General_ShortDay_5_js' => 'C',
+	'General_ShortDay_6_js' => 'Pk',
+	'General_ShortDay_7_js' => 'S',
+	'General_LongDay_1_js' => 'Svētdiena',
+	'General_LongDay_2_js' => 'Pirmdiena',
+	'General_LongDay_3_js' => 'Otrdiena',
+	'General_LongDay_4_js' => 'Trešdiena',
+	'General_LongDay_5_js' => 'Ceturtdiena',
+	'General_LongDay_6_js' => 'Piektdiena',
+	'General_LongDay_7_js' => 'Sestdiena',
+	'General_ShortMonth_1_js' => 'Jan',
+	'General_ShortMonth_2_js' => 'Feb',
+	'General_ShortMonth_3_js' => 'Mar',
+	'General_ShortMonth_4_js' => 'Apr',
+	'General_ShortMonth_5_js' => 'Mai',
+	'General_ShortMonth_6_js' => 'Jūn',
+	'General_ShortMonth_7_js' => 'Jūl',
+	'General_ShortMonth_8_js' => 'Aug',
+	'General_ShortMonth_9_js' => 'Sep',
+	'General_ShortMonth_10_js' => 'Okt',
+	'General_ShortMonth_11_js' => 'Nov',
+	'General_ShortMonth_12_js' => 'Dec',
+	'General_MonthJanuary_js' => 'Janvāris',
+	'General_MonthFebruary_js' => 'Februāris',
+	'General_MonthMarch_js' => 'Marts',
+	'General_MonthApril_js' => 'Aprīlis',
+	'General_MonthMay_js' => 'Maijs',
+	'General_MonthJune_js' => 'Jūnijs',
+	'General_MonthJuly_js' => 'Jūlijs',
+	'General_MonthAugust_js' => 'Augusts',
+	'General_MonthSeptember_js' => 'Septembris',
+	'General_MonthOctober_js' => 'Oktobris',
+	'General_MonthNovember_js' => 'Novembris',
+	'General_MonthDecember_js' => 'Decembris',
 	'CorePluginsAdmin_PluginDescription' => 'Spraudņu administrācijas skats',
 	'CorePluginsAdmin_Plugins' => 'Spraudņi',
 	'CorePluginsAdmin_PluginsManagement' => 'Spraudņu pārvaldība',
@@ -1195,4 +1190,188 @@ $translations = array(
 	'PDFReports_TopOfReport' => 'Atpakaļ uz sākumu',
 	'PDFReports_Pagination' => '%s. lapa no %s',
 	'ImageGraph_PluginDescription' => 'Ģenerējiet skaistus, statiskus PNG formāta grafikus jebkurai Piwik atskaitei.',
+	'UserLanguage_Language_aa' => 'afāru',
+	'UserLanguage_Language_ab' => 'abhāzu',
+	'UserLanguage_Language_ae' => 'avesta',
+	'UserLanguage_Language_af' => 'afrikandu',
+	'UserLanguage_Language_ak' => 'akanu',
+	'UserLanguage_Language_am' => 'amharu',
+	'UserLanguage_Language_an' => 'aragoniešu',
+	'UserLanguage_Language_ar' => 'arābu',
+	'UserLanguage_Language_as' => 'asamiešu',
+	'UserLanguage_Language_av' => 'avāru',
+	'UserLanguage_Language_ay' => 'aimaru',
+	'UserLanguage_Language_az' => 'azerbaidžāņu',
+	'UserLanguage_Language_ba' => 'baškīru',
+	'UserLanguage_Language_be' => 'baltkrievu',
+	'UserLanguage_Language_bg' => 'bulgāru',
+	'UserLanguage_Language_bh' => 'biharu',
+	'UserLanguage_Language_bi' => 'bišlamā',
+	'UserLanguage_Language_bm' => 'bambaru',
+	'UserLanguage_Language_bn' => 'bengāļu',
+	'UserLanguage_Language_bo' => 'tibetiešu',
+	'UserLanguage_Language_br' => 'bretoņu',
+	'UserLanguage_Language_bs' => 'bosniešu',
+	'UserLanguage_Language_ca' => 'katalāņu',
+	'UserLanguage_Language_ce' => 'čečenu',
+	'UserLanguage_Language_ch' => 'čamorru',
+	'UserLanguage_Language_co' => 'korsikāņu',
+	'UserLanguage_Language_cr' => 'krī',
+	'UserLanguage_Language_cs' => 'čehu',
+	'UserLanguage_Language_cu' => 'baznīcslāvu',
+	'UserLanguage_Language_cv' => 'čuvašu',
+	'UserLanguage_Language_cy' => 'velsiešu',
+	'UserLanguage_Language_da' => 'dāņu',
+	'UserLanguage_Language_de' => 'vācu',
+	'UserLanguage_Language_dv' => 'maldīviešu',
+	'UserLanguage_Language_dz' => 'dzongke',
+	'UserLanguage_Language_ee' => 'evu',
+	'UserLanguage_Language_el' => 'grieķu',
+	'UserLanguage_Language_en' => 'angļu',
+	'UserLanguage_Language_eo' => 'esperanto',
+	'UserLanguage_Language_es' => 'spāņu',
+	'UserLanguage_Language_et' => 'igauņu',
+	'UserLanguage_Language_eu' => 'basku',
+	'UserLanguage_Language_fa' => 'persiešu',
+	'UserLanguage_Language_ff' => 'fulu',
+	'UserLanguage_Language_fi' => 'somu',
+	'UserLanguage_Language_fj' => 'fidžiešu',
+	'UserLanguage_Language_fo' => 'fēru',
+	'UserLanguage_Language_fr' => 'franču',
+	'UserLanguage_Language_fy' => 'rietumfrīzu',
+	'UserLanguage_Language_ga' => 'īru',
+	'UserLanguage_Language_gd' => 'gēlu',
+	'UserLanguage_Language_gl' => 'galisiešu',
+	'UserLanguage_Language_gn' => 'gvaranu',
+	'UserLanguage_Language_gu' => 'gudžaratu',
+	'UserLanguage_Language_gv' => 'meniešu',
+	'UserLanguage_Language_ha' => 'hausu',
+	'UserLanguage_Language_he' => 'ivrits',
+	'UserLanguage_Language_hi' => 'hindi',
+	'UserLanguage_Language_ho' => 'hirimotu',
+	'UserLanguage_Language_hr' => 'horvātu',
+	'UserLanguage_Language_ht' => 'haitiešu',
+	'UserLanguage_Language_hu' => 'ungāru',
+	'UserLanguage_Language_hy' => 'armēņu',
+	'UserLanguage_Language_hz' => 'hereru',
+	'UserLanguage_Language_ia' => 'interlingva',
+	'UserLanguage_Language_id' => 'indonēziešu',
+	'UserLanguage_Language_ie' => 'interlingve',
+	'UserLanguage_Language_ig' => 'igbo',
+	'UserLanguage_Language_ii' => 'Sičuaņas ji',
+	'UserLanguage_Language_ik' => 'inupiaku',
+	'UserLanguage_Language_io' => 'ido',
+	'UserLanguage_Language_is' => 'īslandiešu',
+	'UserLanguage_Language_it' => 'itāliešu',
+	'UserLanguage_Language_iu' => 'inuītu',
+	'UserLanguage_Language_ja' => 'japāņu',
+	'UserLanguage_Language_jv' => 'javiešu',
+	'UserLanguage_Language_ka' => 'gruzīnu',
+	'UserLanguage_Language_kg' => 'kongu',
+	'UserLanguage_Language_ki' => 'kikuju',
+	'UserLanguage_Language_kj' => 'kvaņamu',
+	'UserLanguage_Language_kk' => 'kazahu',
+	'UserLanguage_Language_kl' => 'grenlandiešu',
+	'UserLanguage_Language_km' => 'khmeru',
+	'UserLanguage_Language_kn' => 'kannadu',
+	'UserLanguage_Language_ko' => 'korejiešu',
+	'UserLanguage_Language_kr' => 'kanuru',
+	'UserLanguage_Language_ks' => 'kašmiriešu',
+	'UserLanguage_Language_ku' => 'kurdu',
+	'UserLanguage_Language_kv' => 'komiešu',
+	'UserLanguage_Language_kw' => 'korniešu',
+	'UserLanguage_Language_ky' => 'kirgīzu',
+	'UserLanguage_Language_la' => 'latīņu',
+	'UserLanguage_Language_lb' => 'luksemburgiešu',
+	'UserLanguage_Language_lg' => 'gandu',
+	'UserLanguage_Language_li' => 'limburgiešu',
+	'UserLanguage_Language_ln' => 'lingala',
+	'UserLanguage_Language_lo' => 'laosiešu',
+	'UserLanguage_Language_lt' => 'lietuviešu',
+	'UserLanguage_Language_lu' => 'lubakatanga',
+	'UserLanguage_Language_lv' => 'latviešu',
+	'UserLanguage_Language_mg' => 'malagasu',
+	'UserLanguage_Language_mh' => 'māršaliešu',
+	'UserLanguage_Language_mi' => 'maoru',
+	'UserLanguage_Language_mk' => 'maķedoniešu',
+	'UserLanguage_Language_ml' => 'malajalu',
+	'UserLanguage_Language_mn' => 'mongoļu',
+	'UserLanguage_Language_mr' => 'maratu',
+	'UserLanguage_Language_ms' => 'malajiešu',
+	'UserLanguage_Language_mt' => 'maltiešu',
+	'UserLanguage_Language_my' => 'birmiešu',
+	'UserLanguage_Language_na' => 'nauruiešu',
+	'UserLanguage_Language_nb' => 'norvēģu bukmols',
+	'UserLanguage_Language_nd' => 'ziemeļndebelu',
+	'UserLanguage_Language_ne' => 'nepāliešu',
+	'UserLanguage_Language_ng' => 'ndongu',
+	'UserLanguage_Language_nl' => 'holandiešu',
+	'UserLanguage_Language_nn' => 'jaunnorvēģu',
+	'UserLanguage_Language_no' => 'norvēģu',
+	'UserLanguage_Language_nr' => 'dienvidndebelu',
+	'UserLanguage_Language_nv' => 'navahu',
+	'UserLanguage_Language_ny' => 'čičeva',
+	'UserLanguage_Language_oc' => 'oksitāņu',
+	'UserLanguage_Language_oj' => 'odžibvu',
+	'UserLanguage_Language_om' => 'oromu',
+	'UserLanguage_Language_or' => 'orisiešu',
+	'UserLanguage_Language_os' => 'osetīnu',
+	'UserLanguage_Language_pa' => 'pandžabu',
+	'UserLanguage_Language_pi' => 'pāli',
+	'UserLanguage_Language_pl' => 'poļu',
+	'UserLanguage_Language_ps' => 'puštu',
+	'UserLanguage_Language_pt' => 'portugāļu',
+	'UserLanguage_Language_qu' => 'kečvu',
+	'UserLanguage_Language_rm' => 'retoromāņu',
+	'UserLanguage_Language_rn' => 'rundu',
+	'UserLanguage_Language_ro' => 'rumāņu',
+	'UserLanguage_Language_ru' => 'krievu',
+	'UserLanguage_Language_rw' => 'kiņaruanda',
+	'UserLanguage_Language_sa' => 'sanskrits',
+	'UserLanguage_Language_sc' => 'sardīniešu',
+	'UserLanguage_Language_sd' => 'sindhu',
+	'UserLanguage_Language_se' => 'ziemeļsāmu',
+	'UserLanguage_Language_sg' => 'sangu',
+	'UserLanguage_Language_si' => 'singāļu',
+	'UserLanguage_Language_sk' => 'slovāku',
+	'UserLanguage_Language_sl' => 'slovēņu',
+	'UserLanguage_Language_sm' => 'samoāņu',
+	'UserLanguage_Language_sn' => 'šonu',
+	'UserLanguage_Language_so' => 'somāļu',
+	'UserLanguage_Language_sq' => 'albāņu',
+	'UserLanguage_Language_sr' => 'serbu',
+	'UserLanguage_Language_ss' => 'svatu',
+	'UserLanguage_Language_st' => 'sesoto',
+	'UserLanguage_Language_su' => 'sundaniešu',
+	'UserLanguage_Language_sv' => 'zviedru',
+	'UserLanguage_Language_sw' => 'svahili',
+	'UserLanguage_Language_ta' => 'tamilu',
+	'UserLanguage_Language_te' => 'telugu',
+	'UserLanguage_Language_tg' => 'tadžiku',
+	'UserLanguage_Language_th' => 'taju',
+	'UserLanguage_Language_ti' => 'tigrinja',
+	'UserLanguage_Language_tk' => 'turkmēņu',
+	'UserLanguage_Language_tl' => 'tagalu',
+	'UserLanguage_Language_tn' => 'cvanu',
+	'UserLanguage_Language_to' => 'tongu',
+	'UserLanguage_Language_tr' => 'turku',
+	'UserLanguage_Language_ts' => 'congu',
+	'UserLanguage_Language_tt' => 'tatāru',
+	'UserLanguage_Language_tw' => 'tvī',
+	'UserLanguage_Language_ty' => 'taitiešu',
+	'UserLanguage_Language_ug' => 'uiguru',
+	'UserLanguage_Language_uk' => 'ukraiņu',
+	'UserLanguage_Language_ur' => 'urdu',
+	'UserLanguage_Language_uz' => 'uzbeku',
+	'UserLanguage_Language_ve' => 'vendu',
+	'UserLanguage_Language_vi' => 'vjetnamiešu',
+	'UserLanguage_Language_vo' => 'volapiks',
+	'UserLanguage_Language_wa' => 'valoņu',
+	'UserLanguage_Language_wo' => 'volofu',
+	'UserLanguage_Language_xh' => 'khosu',
+	'UserLanguage_Language_yi' => 'jidišs',
+	'UserLanguage_Language_yo' => 'jorubu',
+	'UserLanguage_Language_za' => 'džuanu',
+	'UserLanguage_Language_zh' => 'ķīniešu',
+	'UserLanguage_Language_zu' => 'zulu',
 );
