@@ -32,6 +32,7 @@ $translations = array(
 	'General_Upload' => 'Last opp',
 	'General_Ok' => 'Ok',
 	'General_Close' => 'Lukk',
+	'General_Cancel' => 'Avbryt',
 	'General_OrCancel' => 'eller %s avbryt %s',
 	'General_Logout' => 'Logg ut',
 	'General_Username' => 'Brukernavn',
@@ -124,7 +125,6 @@ $translations = array(
 	'General_NSeconds' => '%s sekund',
 	'General_RequiresFlash' => 'Visning av grafikk i Piwik krever Flash',
 	'General_GraphHelp' => 'Mer informasjon om visning av grafikk i Piwik',
-	'General_NoDataForGraph' => 'Ingen data for denne grafen.',
 	'General_NoDataForTagCloud' => 'Ingen data for denne merkelappskyen.',
 	'General_DisplaySimpleTable' => 'Vis enkel tabell',
 	'General_DisplayTableWithMoreMetrics' => 'Vis en tabell mer flere måltall',
@@ -217,27 +217,55 @@ $translations = array(
 	'Actions_SubmenuPages' => 'Sider',
 	'Actions_SubmenuPagesEntry' => 'Innganssider',
 	'Actions_SubmenuPagesExit' => 'Utgangssider',
+	'Actions_WidgetExitPageTitles' => 'Utgangs Side Tittler',
 	'Actions_SubmenuPageTitles' => 'Sidetitler',
+	'Actions_WidgetPageTitles' => 'Side Tittler',
+	'Actions_WidgetPageTitlesFollowingSearch' => 'Side Tittel fulgt av ett sidesøk',
 	'Actions_SubmenuOutlinks' => 'Utlenker',
 	'Actions_SubmenuDownloads' => 'Nedlastinger',
+	'Actions_SubmenuSitesearch' => 'Sidesøk',
 	'Actions_ColumnClicks' => 'Klikk',
+	'Actions_ColumnClicksDocumentation' => 'Antall klikk på denne lenken',
 	'Actions_ColumnUniqueClicks' => 'Unike klikk',
 	'Actions_ColumnDownloads' => 'Nedlastinger',
 	'Actions_ColumnUniqueDownloads' => 'Unike nedlastinger',
+	'Actions_ColumnOutlinks' => 'Utlenker',
+	'Actions_ColumnUniqueOutlinks' => 'Unike utlenker',
 	'Actions_ColumnPageName' => 'Sidenavn',
 	'Actions_ColumnPageURL' => 'URL for side',
+	'Actions_ColumnSearchCategory' => 'Søkekategori',
+	'Actions_ColumnSearchResultsCount' => 'Antall Søke Resultater',
+	'Actions_ColumnSearchKeyword' => 'Nøkkelord',
 	'Actions_ColumnClickedURL' => 'URL for klikk',
 	'Actions_ColumnDownloadURL' => 'URL for nedlasting',
 	'Actions_ColumnEntryPageURL' => 'URL for inngangsside',
 	'Actions_ColumnEntryPageTitle' => 'Tittel for inngangsside',
 	'Actions_ColumnExitPageURL' => 'URL for utgangsside',
 	'Actions_ColumnExitPageTitle' => 'Tittel for utgangsside',
+	'Actions_ColumnNoResultKeyword' => 'Nøkkelord uten søkeresultat',
+	'Actions_ColumnSearches' => 'Søk',
+	'Actions_ColumnSiteSearchKeywords' => 'Unike nøkkelord',
+	'Actions_ColumnSearchesDocumentation' => 'Antall besøkende som søkte etter dette nøkkelordet i din søkemotor.',
+	'Actions_ColumnSearchExits' => '% Søk Eksisterer',
+	'Actions_ColumnSearchExitsDocumentation' => 'Antall besøkende som forlot webside etter og ha søkt etter dette nøkkelordet.',
+	'Actions_ColumnPagesPerSearch' => 'Søke Resultater',
+	'Actions_AvgGenerationTimeTooltip' => 'Gjennomsnitt basert på %s treff %s mellom %s og %s',
 	'API_LoadedAPIs' => 'Lastet %s API',
 	'CoreAdminHome_PluginDescription' => 'Administrasjonsområdet for Piwik.',
 	'CoreAdminHome_MenuGeneralSettings' => 'Generelle innstillinger',
+	'CoreAdminHome_MenuManage' => 'Administrer',
 	'CoreAdminHome_Administration' => 'Administrasjon',
 	'CoreAdminHome_EmailServerSettings' => 'Innstillinger for e-posttjener',
 	'CoreAdminHome_OptOutForYourVisitors' => 'Piwik «opt-out» for dine besøkende',
+	'CoreAdminHome_YouMayOptOut' => 'Du kan velge å ikke få tildelt en unik id for nettanalyse slik at du ikke blir en del av analysegrunnlaget',
+	'CoreAdminHome_YouMayOptOutBis' => 'Hvis du ikke ønsker å delta, klikk under for å motta en blank informasjonskapsel så du ikke registreres.',
+	'CoreAdminHome_YouAreOptedIn' => 'Du deltar i analysegrunnlaget',
+	'CoreAdminHome_YouAreOptedOut' => 'Du deltar ikke i analysegrunnlaget',
+	'CoreAdminHome_ClickHereToOptOut' => 'Trykk her for å ikke delta.',
+	'CoreAdminHome_ClickHereToOptIn' => 'Trykk her for å delta.',
+	'CoreAdminHome_ImageTracking' => 'Bilde sporing',
+	'CoreAdminHome_ImageTrackingLink' => 'Sporings lenke for bilde',
+	'CoreAdminHome_ForBetaTestersOnly' => 'Kun for beta testere',
 	'CoreHome_PluginDescription' => 'Struktur for nettstatistikkrapporter.',
 	'CoreHome_WebAnalyticsReports' => 'Nettstatistikkrapporter',
 	'CoreHome_JavascriptDisabled' => 'JavaScript må være aktivert for at du skal kunne bruke Piwik i standardvisning.<br />Det ser ut til at JavaScript enten er deaktivert eller ikke støttet av din nettleser.<br />For å bruke standardvisning, må du aktivere JavaScript i nettleserinnstillingene og deretter %1$sprøve igjen%2$s.<br />',
@@ -253,51 +281,51 @@ $translations = array(
 	'CoreHome_PeriodWeeks' => 'uker',
 	'CoreHome_PeriodMonths' => 'måneder',
 	'CoreHome_PeriodYears' => 'år',
-	'CoreHome_DaySu_js' => 'Sø',
-	'CoreHome_DayMo_js' => 'Ma',
-	'CoreHome_DayTu_js' => 'Ti',
-	'CoreHome_DayWe_js' => 'On',
-	'CoreHome_DayTh_js' => 'To',
-	'CoreHome_DayFr_js' => 'Fr',
-	'CoreHome_DaySa_js' => 'Lø',
-	'CoreHome_ShortDay_1_js' => 'Søn',
-	'CoreHome_ShortDay_2_js' => 'Man',
-	'CoreHome_ShortDay_3_js' => 'Tir',
-	'CoreHome_ShortDay_4_js' => 'Ons',
-	'CoreHome_ShortDay_5_js' => 'Tor',
-	'CoreHome_ShortDay_6_js' => 'Fre',
-	'CoreHome_ShortDay_7_js' => 'Lør',
-	'CoreHome_LongDay_1_js' => 'Søndag',
-	'CoreHome_LongDay_2_js' => 'Mandag',
-	'CoreHome_LongDay_3_js' => 'Tirsdag',
-	'CoreHome_LongDay_4_js' => 'Onsdag',
-	'CoreHome_LongDay_5_js' => 'Torsdag',
-	'CoreHome_LongDay_6_js' => 'Fredag',
-	'CoreHome_LongDay_7_js' => 'Lørdag',
-	'CoreHome_ShortMonth_1_js' => 'Jan',
-	'CoreHome_ShortMonth_2_js' => 'Feb',
-	'CoreHome_ShortMonth_3_js' => 'Mar',
-	'CoreHome_ShortMonth_4_js' => 'Apr',
-	'CoreHome_ShortMonth_5_js' => 'Mai',
-	'CoreHome_ShortMonth_6_js' => 'Jun',
-	'CoreHome_ShortMonth_7_js' => 'Jul',
-	'CoreHome_ShortMonth_8_js' => 'Aug',
-	'CoreHome_ShortMonth_9_js' => 'Sep',
-	'CoreHome_ShortMonth_10_js' => 'Okt',
-	'CoreHome_ShortMonth_11_js' => 'Nov',
-	'CoreHome_ShortMonth_12_js' => 'Dec',
-	'CoreHome_MonthJanuary_js' => 'Januar',
-	'CoreHome_MonthFebruary_js' => 'Februar',
-	'CoreHome_MonthMarch_js' => 'Mars',
-	'CoreHome_MonthApril_js' => 'April',
-	'CoreHome_MonthMay_js' => 'Mai',
-	'CoreHome_MonthJune_js' => 'Juni',
-	'CoreHome_MonthJuly_js' => 'Juli',
-	'CoreHome_MonthAugust_js' => 'August',
-	'CoreHome_MonthSeptember_js' => 'September',
-	'CoreHome_MonthOctober_js' => 'Oktober',
-	'CoreHome_MonthNovember_js' => 'November',
-	'CoreHome_MonthDecember_js' => 'Desember',
+	'General_DaySu_js' => 'Sø',
+	'General_DayMo_js' => 'Ma',
+	'General_DayTu_js' => 'Ti',
+	'General_DayWe_js' => 'On',
+	'General_DayTh_js' => 'To',
+	'General_DayFr_js' => 'Fr',
+	'General_DaySa_js' => 'Lø',
+	'General_ShortDay_1_js' => 'Søn',
+	'General_ShortDay_2_js' => 'Man',
+	'General_ShortDay_3_js' => 'Tir',
+	'General_ShortDay_4_js' => 'Ons',
+	'General_ShortDay_5_js' => 'Tor',
+	'General_ShortDay_6_js' => 'Fre',
+	'General_ShortDay_7_js' => 'Lør',
+	'General_LongDay_1_js' => 'Søndag',
+	'General_LongDay_2_js' => 'Mandag',
+	'General_LongDay_3_js' => 'Tirsdag',
+	'General_LongDay_4_js' => 'Onsdag',
+	'General_LongDay_5_js' => 'Torsdag',
+	'General_LongDay_6_js' => 'Fredag',
+	'General_LongDay_7_js' => 'Lørdag',
+	'General_ShortMonth_1_js' => 'Jan',
+	'General_ShortMonth_2_js' => 'Feb',
+	'General_ShortMonth_3_js' => 'Mar',
+	'General_ShortMonth_4_js' => 'Apr',
+	'General_ShortMonth_5_js' => 'Mai',
+	'General_ShortMonth_6_js' => 'Jun',
+	'General_ShortMonth_7_js' => 'Jul',
+	'General_ShortMonth_8_js' => 'Aug',
+	'General_ShortMonth_9_js' => 'Sep',
+	'General_ShortMonth_10_js' => 'Okt',
+	'General_ShortMonth_11_js' => 'Nov',
+	'General_ShortMonth_12_js' => 'Dec',
+	'General_MonthJanuary_js' => 'Januar',
+	'General_MonthFebruary_js' => 'Februar',
+	'General_MonthMarch_js' => 'Mars',
+	'General_MonthApril_js' => 'April',
+	'General_MonthMay_js' => 'Mai',
+	'General_MonthJune_js' => 'Juni',
+	'General_MonthJuly_js' => 'Juli',
+	'General_MonthAugust_js' => 'August',
+	'General_MonthSeptember_js' => 'September',
+	'General_MonthOctober_js' => 'Oktober',
+	'General_MonthNovember_js' => 'November',
+	'General_MonthDecember_js' => 'Desember',
 	'CorePluginsAdmin_PluginDescription' => 'Grensesnitt for administrasjon av tillegg',
 	'CorePluginsAdmin_Plugins' => 'Tillegg',
 	'CorePluginsAdmin_PluginsManagement' => 'Administrasjon av tillegg',
@@ -360,6 +388,9 @@ $translations = array(
 	'CoreUpdater_ExceptionArchiveIncompatible' => 'Inkompatibelt arkiv: %s',
 	'CoreUpdater_ExceptionArchiveEmpty' => 'Tomt arkiv.',
 	'CoreUpdater_ExceptionArchiveIncomplete' => 'Arkivet er ikke komplett - noen file mangler (f.eks. %s).',
+	'CustomVariables_PluginDescription' => 'Egendefinerte variabler er navn og verdier som du kan sette for en besøkende via funksjonen setVisitCustomVariables() i Javascript API-et. Piwik vil da kunne rapportere hvor mange besøkende, sider, konverteringer som benytter disse egendefinerte variablene og verdiene.',
+	'CustomVariables_CustomVariables' => 'Egendefinerte variabler',
+	'CustomVariables_TrackingHelp' => 'Hjelp: %1$sSporing av egendefinerte variabler i Piwik%2$s',
 	'Dashboard_PluginDescription' => 'Ditt nettanalyse-kontrollpanel. Du kan tilpasse kontrollpanelet: Legge til nye element, endre rekkefølgene for dine element. Hver bruker kan tilpasse sitt eget kontrollpanel.',
 	'Dashboard_Dashboard' => 'Kontrollpanel',
 	'Dashboard_DeleteWidgetConfirm' => 'Er du sikker på at du vil fjerne dette elementet fra ditt kontrollpanel?',
@@ -371,6 +402,12 @@ $translations = array(
 	'Dashboard_TitleClickToAdd_js' => 'Klikk her for å legge til kontrollpanelet',
 	'Dashboard_LoadingWidget_js' => 'Laster element, vennligst vent ...',
 	'Dashboard_WidgetNotFound_js' => 'Finner ikke element',
+	'Dashboard_ResetDashboard' => 'Nullstill kontrollpanel',
+	'Dashboard_ChangeDashboardLayout' => 'Endre layout for kontrollpanel',
+	'Dashboard_DashboardOf' => 'Kontrollpanel for %s',
+	'Dashboard_ManageDashboard' => 'Administrer kontrollpanel',
+	'Dashboard_CreateNewDashboard' => 'Opprett nytt kontrollpanel',
+	'Dashboard_RenameDashboard' => 'Gi nytt navn på kontrollpanel',
 	'DBStats_PluginDescription' => 'Dette tillegget rapporterer MySQL-databasebruk for Piwik-tabeller.',
 	'DBStats_DatabaseUsage' => 'Databasebruk',
 	'DBStats_MainDescription' => 'Piwik lagrer all din statistikk i MySQL-databasen. Akkurat nå bruker Piwik-tabellene %s.',
@@ -407,6 +444,7 @@ $translations = array(
 	'Feedback_ExceptionBodyLength' => 'Meldingen må være minst %s tegn lang.',
 	'Feedback_ExceptionNoUrls' => 'Meldingen kan ikke inneholde en URL (for å unngå spam)',
 	'Goals_Goals' => 'Mål',
+	'Goals_GoalsManagement' => 'Administrasjon av mål',
 	'Goals_ColumnConversions' => 'Konvertering',
 	'Goals_ColumnRevenue' => 'Inntekter',
 	'Goals_AddNewGoal' => 'Legg til et nytt mål',
@@ -506,12 +544,14 @@ $translations = array(
 	'Login_PasswordRepeat' => 'Passord (gjenta)',
 	'Login_ChangePassword' => 'Endre passord',
 	'Login_LoginOrEmail' => 'Brukernavn eller e-post',
+	'Login_RememberMe' => 'Husk meg',
 	'Login_LogIn' => 'Logg inn',
 	'Login_Logout' => 'Logg ut',
 	'Login_LostYourPassword' => 'Glemt passord?',
 	'Login_PasswordsDoNotMatch' => 'Passordene stemmer ikke overens.',
 	'Login_InvalidUsernameEmail' => 'Feil brukernavn og/eller epost-adresse.',
 	'Login_ContactAdmin' => 'Mulig grunn: Din tjener har kanskje deaktivert mail()-funksjonen. <br />Kontakt din Piwik administrator.',
+	'MobileMessaging_Settings_ManagePhoneNumbers' => 'Administrer telefonnummer',
 	'MultiSites_Evolution' => 'Utvikling',
 	'Provider_PluginDescription' => 'Rapporterer tilbyderen for de besøkende.',
 	'Provider_WidgetProviders' => 'Tilbydere',
@@ -543,6 +583,7 @@ $translations = array(
 	'Referers_DistinctCampaigns' => 'ulike kampanjer',
 	'Referers_DistinctWebsites' => 'ulike nettsteder',
 	'Referers_UsingNDistinctUrls' => '(bruker %s forskjellige URL-er)',
+	'Referers_SubmenuOverview' => 'Oversikt',
 	'Referers_SubmenuSearchEngines' => 'Søkemotorer og nøkkelord',
 	'Referers_SubmenuWebsites' => 'Nettsteder',
 	'Referers_SubmenuCampaigns' => 'Kampanjer',
@@ -982,6 +1023,8 @@ $translations = array(
 	'VisitsSummary_NbVisits' => '%s besøk',
 	'VisitsSummary_NbUniqueVisitors' => '%s unike besøkende',
 	'VisitsSummary_NbActionsDescription' => '%s handlinger (sidevisninger, nedlastinger og utlenker)',
+	'VisitsSummary_NbOutlinksDescription' => '%s utlenker',
+	'VisitsSummary_NbUniqueOutlinksDescription' => '%s unike utlenker',
 	'VisitsSummary_AverageVisitDuration' => '%s gjennomsnittlig besøksvarighet',
 	'VisitsSummary_MaxNbActions' => '%s maks handlinger i ett besøk',
 	'VisitsSummary_NbActionsPerVisit' => '%s handlinger per besøk',
@@ -1001,6 +1044,8 @@ $translations = array(
 	'VisitTime_WidgetServerTime' => 'Besøk etter tjenertid',
 	'VisitTime_SubmenuTimes' => 'Tider',
 	'VisitTime_NHour' => '%st',
+	'PDFReports_ManageEmailReports' => 'Administrer e-postrapporter',
+	'PDFReports_EmailReports' => 'E-postrapporter',
 	'PDFReports_PDF' => 'PDF',
 	'PDFReports_EmailSchedule' => 'E-postplan',
 	'PDFReports_SendReportTo' => 'Send rapport til',
@@ -1011,4 +1056,191 @@ $translations = array(
 	'PDFReports_PiwikReports' => 'Piwik-rapporter',
 	'PDFReports_EmailHello' => 'Hei,',
 	'PDFReports_PleaseFindAttachedFile' => 'I den vedlagte filen finner du din %1$s rapport for %2$s.',
+	'UserLanguage_Language_aa' => 'afar',
+	'UserLanguage_Language_ab' => 'abkhasisk',
+	'UserLanguage_Language_ae' => 'avestisk',
+	'UserLanguage_Language_af' => 'afrikaans',
+	'UserLanguage_Language_ak' => 'akan',
+	'UserLanguage_Language_am' => 'amharisk',
+	'UserLanguage_Language_an' => 'aragonsk',
+	'UserLanguage_Language_ar' => 'arabisk',
+	'UserLanguage_Language_as' => 'assamisk',
+	'UserLanguage_Language_av' => 'avarisk',
+	'UserLanguage_Language_ay' => 'aymara',
+	'UserLanguage_Language_az' => 'aserbajdsjansk',
+	'UserLanguage_Language_ba' => 'basjkirsk',
+	'UserLanguage_Language_be' => 'hviterussisk',
+	'UserLanguage_Language_bg' => 'bulgarsk',
+	'UserLanguage_Language_bh' => 'bihari',
+	'UserLanguage_Language_bi' => 'bislama',
+	'UserLanguage_Language_bm' => 'bambara',
+	'UserLanguage_Language_bn' => 'bengali',
+	'UserLanguage_Language_bo' => 'tibetansk',
+	'UserLanguage_Language_br' => 'bretonsk',
+	'UserLanguage_Language_bs' => 'bosnisk',
+	'UserLanguage_Language_ca' => 'katalansk',
+	'UserLanguage_Language_ce' => 'tsjetsjensk',
+	'UserLanguage_Language_ch' => 'chamorro',
+	'UserLanguage_Language_co' => 'korsikansk',
+	'UserLanguage_Language_cr' => 'cree',
+	'UserLanguage_Language_cs' => 'tsjekkisk',
+	'UserLanguage_Language_cu' => 'kirkeslavisk',
+	'UserLanguage_Language_cv' => 'tsjuvansk',
+	'UserLanguage_Language_cy' => 'walisisk',
+	'UserLanguage_Language_da' => 'dansk',
+	'UserLanguage_Language_de' => 'tysk',
+	'UserLanguage_Language_dv' => 'divehi',
+	'UserLanguage_Language_dz' => 'dzongkha',
+	'UserLanguage_Language_ee' => 'ewe',
+	'UserLanguage_Language_el' => 'gresk',
+	'UserLanguage_Language_en' => 'engelsk',
+	'UserLanguage_Language_eo' => 'esperanto',
+	'UserLanguage_Language_es' => 'spansk',
+	'UserLanguage_Language_et' => 'estisk',
+	'UserLanguage_Language_eu' => 'baskisk',
+	'UserLanguage_Language_fa' => 'persisk',
+	'UserLanguage_Language_ff' => 'fulani',
+	'UserLanguage_Language_fi' => 'finsk',
+	'UserLanguage_Language_fj' => 'fijiansk',
+	'UserLanguage_Language_fo' => 'færøysk',
+	'UserLanguage_Language_fr' => 'fransk',
+	'UserLanguage_Language_fy' => 'vestfrisisk',
+	'UserLanguage_Language_ga' => 'irsk',
+	'UserLanguage_Language_gd' => 'skotsk gælisk',
+	'UserLanguage_Language_gl' => 'galisisk',
+	'UserLanguage_Language_gn' => 'guarani',
+	'UserLanguage_Language_gu' => 'gujarati',
+	'UserLanguage_Language_gv' => 'manx',
+	'UserLanguage_Language_ha' => 'hausa',
+	'UserLanguage_Language_he' => 'hebraisk',
+	'UserLanguage_Language_hi' => 'hindi',
+	'UserLanguage_Language_ho' => 'hiri motu',
+	'UserLanguage_Language_hr' => 'kroatisk',
+	'UserLanguage_Language_ht' => 'haitisk',
+	'UserLanguage_Language_hu' => 'ungarsk',
+	'UserLanguage_Language_hy' => 'armensk',
+	'UserLanguage_Language_hz' => 'herero',
+	'UserLanguage_Language_ia' => 'interlingua',
+	'UserLanguage_Language_id' => 'indonesisk',
+	'UserLanguage_Language_ie' => 'interlingue',
+	'UserLanguage_Language_ig' => 'ibo',
+	'UserLanguage_Language_ii' => 'sichuan-yi',
+	'UserLanguage_Language_ik' => 'inupiak',
+	'UserLanguage_Language_io' => 'ido',
+	'UserLanguage_Language_is' => 'islandsk',
+	'UserLanguage_Language_it' => 'italiensk',
+	'UserLanguage_Language_iu' => 'inuktitut',
+	'UserLanguage_Language_ja' => 'japansk',
+	'UserLanguage_Language_jv' => 'javanesisk',
+	'UserLanguage_Language_ka' => 'georgisk',
+	'UserLanguage_Language_kg' => 'kikongo',
+	'UserLanguage_Language_ki' => 'kikuyu',
+	'UserLanguage_Language_kj' => 'kuanyama',
+	'UserLanguage_Language_kk' => 'kasakhisk',
+	'UserLanguage_Language_kl' => 'grønlandsk',
+	'UserLanguage_Language_km' => 'khmer',
+	'UserLanguage_Language_kn' => 'kannada',
+	'UserLanguage_Language_ko' => 'koreansk',
+	'UserLanguage_Language_kr' => 'kanuri',
+	'UserLanguage_Language_ks' => 'kasjmiri',
+	'UserLanguage_Language_ku' => 'kurdisk',
+	'UserLanguage_Language_kv' => 'komi',
+	'UserLanguage_Language_kw' => 'kornisk',
+	'UserLanguage_Language_ky' => 'kirgisisk',
+	'UserLanguage_Language_la' => 'latin',
+	'UserLanguage_Language_lb' => 'luxemburgsk',
+	'UserLanguage_Language_lg' => 'ganda',
+	'UserLanguage_Language_li' => 'limburgisk',
+	'UserLanguage_Language_ln' => 'lingala',
+	'UserLanguage_Language_lo' => 'laotisk',
+	'UserLanguage_Language_lt' => 'litauisk',
+	'UserLanguage_Language_lu' => 'luba-katanga',
+	'UserLanguage_Language_lv' => 'latvisk',
+	'UserLanguage_Language_mg' => 'madagassisk',
+	'UserLanguage_Language_mh' => 'marshallesisk',
+	'UserLanguage_Language_mi' => 'maori',
+	'UserLanguage_Language_mk' => 'makedonsk',
+	'UserLanguage_Language_ml' => 'malayalam',
+	'UserLanguage_Language_mn' => 'mongolsk',
+	'UserLanguage_Language_mr' => 'marathi',
+	'UserLanguage_Language_ms' => 'malayisk',
+	'UserLanguage_Language_mt' => 'maltesisk',
+	'UserLanguage_Language_my' => 'burmesisk',
+	'UserLanguage_Language_na' => 'nauru',
+	'UserLanguage_Language_nb' => 'norsk bokmål',
+	'UserLanguage_Language_nd' => 'nord-ndebele',
+	'UserLanguage_Language_ne' => 'nepalsk',
+	'UserLanguage_Language_ng' => 'ndonga',
+	'UserLanguage_Language_nl' => 'nederlandsk',
+	'UserLanguage_Language_nn' => 'norsk nynorsk',
+	'UserLanguage_Language_no' => 'norsk',
+	'UserLanguage_Language_nr' => 'sør-ndebele',
+	'UserLanguage_Language_nv' => 'navajo',
+	'UserLanguage_Language_ny' => 'nyanja',
+	'UserLanguage_Language_oc' => 'oksitansk',
+	'UserLanguage_Language_oj' => 'ojibwa',
+	'UserLanguage_Language_om' => 'oromo',
+	'UserLanguage_Language_or' => 'oriya',
+	'UserLanguage_Language_os' => 'ossetisk',
+	'UserLanguage_Language_pa' => 'panjabi',
+	'UserLanguage_Language_pi' => 'pali',
+	'UserLanguage_Language_pl' => 'polsk',
+	'UserLanguage_Language_ps' => 'pashto',
+	'UserLanguage_Language_pt' => 'portugisisk',
+	'UserLanguage_Language_qu' => 'quechua',
+	'UserLanguage_Language_rm' => 'retoromansk',
+	'UserLanguage_Language_rn' => 'rundi',
+	'UserLanguage_Language_ro' => 'rumensk',
+	'UserLanguage_Language_ru' => 'russisk',
+	'UserLanguage_Language_rw' => 'kinjarwanda',
+	'UserLanguage_Language_sa' => 'sanskrit',
+	'UserLanguage_Language_sc' => 'sardinsk',
+	'UserLanguage_Language_sd' => 'sindhi',
+	'UserLanguage_Language_se' => 'nordsamisk',
+	'UserLanguage_Language_sg' => 'sango',
+	'UserLanguage_Language_si' => 'singalesisk',
+	'UserLanguage_Language_sk' => 'slovakisk',
+	'UserLanguage_Language_sl' => 'slovensk',
+	'UserLanguage_Language_sm' => 'samoansk',
+	'UserLanguage_Language_sn' => 'shona',
+	'UserLanguage_Language_so' => 'somali',
+	'UserLanguage_Language_sq' => 'albansk',
+	'UserLanguage_Language_sr' => 'serbisk',
+	'UserLanguage_Language_ss' => 'swati',
+	'UserLanguage_Language_st' => 'sør-sotho',
+	'UserLanguage_Language_su' => 'sundanesisk',
+	'UserLanguage_Language_sv' => 'svensk',
+	'UserLanguage_Language_sw' => 'swahili',
+	'UserLanguage_Language_ta' => 'tamil',
+	'UserLanguage_Language_te' => 'telugu',
+	'UserLanguage_Language_tg' => 'tadsjikisk',
+	'UserLanguage_Language_th' => 'thai',
+	'UserLanguage_Language_ti' => 'tigrinja',
+	'UserLanguage_Language_tk' => 'turkmensk',
+	'UserLanguage_Language_tl' => 'tagalog',
+	'UserLanguage_Language_tn' => 'setswana',
+	'UserLanguage_Language_to' => 'tongansk',
+	'UserLanguage_Language_tr' => 'tyrkisk',
+	'UserLanguage_Language_ts' => 'tsonga',
+	'UserLanguage_Language_tt' => 'tatarisk',
+	'UserLanguage_Language_tw' => 'twi',
+	'UserLanguage_Language_ty' => 'tahitisk',
+	'UserLanguage_Language_ug' => 'uigurisk',
+	'UserLanguage_Language_uk' => 'ukrainsk',
+	'UserLanguage_Language_ur' => 'urdu',
+	'UserLanguage_Language_uz' => 'usbekisk',
+	'UserLanguage_Language_ve' => 'venda',
+	'UserLanguage_Language_vi' => 'vietnamesisk',
+	'UserLanguage_Language_vo' => 'volapyk',
+	'UserLanguage_Language_wa' => 'vallonsk',
+	'UserLanguage_Language_wo' => 'wolof',
+	'UserLanguage_Language_xh' => 'xhosa',
+	'UserLanguage_Language_yi' => 'jiddisk',
+	'UserLanguage_Language_yo' => 'joruba',
+	'UserLanguage_Language_za' => 'zhuang',
+	'UserLanguage_Language_zh' => 'kinesisk',
+	'UserLanguage_Language_zu' => 'zulu',
+
+	// FOR REVIEW
+	'Forecast_Visitors' => 'Besøkende',
 );
