@@ -46,10 +46,7 @@ $translations = array(
 	'General_Description' => 'Forklaring',
 	'General_Done' => 'Ferdig',
 	'General_PoweredBy' => 'Levert av',
-	'General_MetricsToPlot' => 'Verdiar å teikna',
 	'General_RowsToDisplay' => 'Vis radar',
-	'General_MetricToPlot' => 'Verdi å teikna',
-	'General_RecordsToPlot' => 'Postar å teikna',
 	'General_Name' => 'Namn',
 	'General_Value' => 'Verdi',
 	'General_Total' => 'Total',
@@ -80,7 +77,6 @@ $translations = array(
 	'General_DaysSinceFirstVisit' => 'Dagar sidan fyrste vitjing',
 	'General_DaysSinceLastEcommerceOrder' => 'Dagar sidan førre ordre i netthandel',
 	'General_NumberOfVisits' => 'Tal på vitjingar',
-	'General_EcommerceVisitStatus' => 'Netthandelstatus på slutten av vitjinga. Til dømes, for å velja alle vitjingar som har lagt inn ein ordre i netthandelen, vil API-spurnaden innehalda %s',
 	'General_NewVisitor' => 'Ny vitjar',
 	'General_NewVisits' => 'Nye vitjingar',
 	'General_ReturningVisitor' => 'Attendevendande vitjar',
@@ -185,7 +181,6 @@ $translations = array(
 	'General_MediumToHighTrafficItIsRecommendedTo' => 'For nettstader med middels til høg trafikk, tilrår me å handsama rapportar for idag maksimalt kvar halve (%s sekundar) eller heile time (%s sekundar).',
 	'General_RequiresFlash' => 'Grafar i Piwik krev Flash',
 	'General_GraphHelp' => 'Meir informasjon om visning av grafar i Piwik.',
-	'General_NoDataForGraph' => 'Ingen data for denne grafen.',
 	'General_DataForThisGraphHasBeenPurged' => 'Data for denne grafen er meir enn %s månader gammal og er fjerna.',
 	'General_NoDataForTagCloud' => 'Ingen data for denne emneskyen.',
 	'General_DataForThisTagCloudHasBeenPurged' => 'Data for denne emneskypen er meir enn %s månader gammal og er fjerna.',
@@ -407,51 +402,51 @@ $translations = array(
 	'CoreHome_PeriodWeeks' => 'veker',
 	'CoreHome_PeriodMonths' => 'månader',
 	'CoreHome_PeriodYears' => 'år',
-	'CoreHome_DaySu_js' => 'Su',
-	'CoreHome_DayMo_js' => 'Må',
-	'CoreHome_DayTu_js' => 'Ty',
-	'CoreHome_DayWe_js' => 'On',
-	'CoreHome_DayTh_js' => 'To',
-	'CoreHome_DayFr_js' => 'Fr',
-	'CoreHome_DaySa_js' => 'La',
-	'CoreHome_ShortDay_1_js' => 'Sun',
-	'CoreHome_ShortDay_2_js' => 'Mån',
-	'CoreHome_ShortDay_3_js' => 'Tys',
-	'CoreHome_ShortDay_4_js' => 'Ons',
-	'CoreHome_ShortDay_5_js' => 'Tor',
-	'CoreHome_ShortDay_6_js' => 'Fre',
-	'CoreHome_ShortDay_7_js' => 'Lau',
-	'CoreHome_LongDay_1_js' => 'Sundag',
-	'CoreHome_LongDay_2_js' => 'Måndag',
-	'CoreHome_LongDay_3_js' => 'Tysdag',
-	'CoreHome_LongDay_4_js' => 'Onsdag',
-	'CoreHome_LongDay_5_js' => 'Torsdag',
-	'CoreHome_LongDay_6_js' => 'Fredag',
-	'CoreHome_LongDay_7_js' => 'Laurdag',
-	'CoreHome_ShortMonth_1_js' => 'Jan',
-	'CoreHome_ShortMonth_2_js' => 'Feb',
-	'CoreHome_ShortMonth_3_js' => 'Mar',
-	'CoreHome_ShortMonth_4_js' => 'Apr',
-	'CoreHome_ShortMonth_5_js' => 'Mai',
-	'CoreHome_ShortMonth_6_js' => 'Jun',
-	'CoreHome_ShortMonth_7_js' => 'Jul',
-	'CoreHome_ShortMonth_8_js' => 'Aug',
-	'CoreHome_ShortMonth_9_js' => 'Sep',
-	'CoreHome_ShortMonth_10_js' => 'Okt',
-	'CoreHome_ShortMonth_11_js' => 'Nov',
-	'CoreHome_ShortMonth_12_js' => 'Des',
-	'CoreHome_MonthJanuary_js' => 'Januar',
-	'CoreHome_MonthFebruary_js' => 'Februar',
-	'CoreHome_MonthMarch_js' => 'Mars',
-	'CoreHome_MonthApril_js' => 'April',
-	'CoreHome_MonthMay_js' => 'Mai',
-	'CoreHome_MonthJune_js' => 'Juni',
-	'CoreHome_MonthJuly_js' => 'Juli',
-	'CoreHome_MonthAugust_js' => 'August',
-	'CoreHome_MonthSeptember_js' => 'September',
-	'CoreHome_MonthOctober_js' => 'Oktober',
-	'CoreHome_MonthNovember_js' => 'November',
-	'CoreHome_MonthDecember_js' => 'Desember',
+	'General_DaySu_js' => 'Su',
+	'General_DayMo_js' => 'Må',
+	'General_DayTu_js' => 'Ty',
+	'General_DayWe_js' => 'On',
+	'General_DayTh_js' => 'To',
+	'General_DayFr_js' => 'Fr',
+	'General_DaySa_js' => 'La',
+	'General_ShortDay_1_js' => 'Sun',
+	'General_ShortDay_2_js' => 'Mån',
+	'General_ShortDay_3_js' => 'Tys',
+	'General_ShortDay_4_js' => 'Ons',
+	'General_ShortDay_5_js' => 'Tor',
+	'General_ShortDay_6_js' => 'Fre',
+	'General_ShortDay_7_js' => 'Lau',
+	'General_LongDay_1_js' => 'Sundag',
+	'General_LongDay_2_js' => 'Måndag',
+	'General_LongDay_3_js' => 'Tysdag',
+	'General_LongDay_4_js' => 'Onsdag',
+	'General_LongDay_5_js' => 'Torsdag',
+	'General_LongDay_6_js' => 'Fredag',
+	'General_LongDay_7_js' => 'Laurdag',
+	'General_ShortMonth_1_js' => 'Jan',
+	'General_ShortMonth_2_js' => 'Feb',
+	'General_ShortMonth_3_js' => 'Mar',
+	'General_ShortMonth_4_js' => 'Apr',
+	'General_ShortMonth_5_js' => 'Mai',
+	'General_ShortMonth_6_js' => 'Jun',
+	'General_ShortMonth_7_js' => 'Jul',
+	'General_ShortMonth_8_js' => 'Aug',
+	'General_ShortMonth_9_js' => 'Sep',
+	'General_ShortMonth_10_js' => 'Okt',
+	'General_ShortMonth_11_js' => 'Nov',
+	'General_ShortMonth_12_js' => 'Des',
+	'General_MonthJanuary_js' => 'Januar',
+	'General_MonthFebruary_js' => 'Februar',
+	'General_MonthMarch_js' => 'Mars',
+	'General_MonthApril_js' => 'April',
+	'General_MonthMay_js' => 'Mai',
+	'General_MonthJune_js' => 'Juni',
+	'General_MonthJuly_js' => 'Juli',
+	'General_MonthAugust_js' => 'August',
+	'General_MonthSeptember_js' => 'September',
+	'General_MonthOctober_js' => 'Oktober',
+	'General_MonthNovember_js' => 'November',
+	'General_MonthDecember_js' => 'Desember',
 	'CoreHome_ReportGeneratedOn' => 'Rapport generert den %s',
 	'CoreHome_ReportGeneratedXAgo' => 'Rapport generert %s sidan',
 	'CorePluginsAdmin_PluginDescription' => 'Administrasjon av innstikk.',
@@ -660,7 +655,6 @@ $translations = array(
 	'Installation_PleaseFixTheFollowingErrors' => 'Rett på følgjande feil',
 	'Installation_LargePiwikInstances' => 'Hjelp for større Piwik-installasjonar',
 	'Installation_JsTag' => 'JavaScript-sporingskode',
-	'Installation_JsTagArchivingHelp' => 'For nettstader med middels og høg trafikk, sjå <a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">Korleis setja opp autoarkivering</a> for å få Piwik til å køyra raskare!',
 	'Installation_Congratulations' => 'Gratulerer',
 	'Installation_CongratulationsHelp' => '<p>Gratulerer! Piwik-installasjon er ferdig.</p><p>Sjå til at JavaScript-koden er lagt til på sidene dine, og vent på dine fyrste vitjarar!</p>',
 	'Installation_ContinueToPiwik' => 'Hald fram til Piwik',
@@ -1078,7 +1072,7 @@ $translations = array(
 	'UserCountry_country_tv' => 'Tuvalu',
 	'UserCountry_country_tw' => 'Taiwan',
 	'UserCountry_country_tz' => 'Tanzania',
-	'UserCountry_country_ti' => 'Tibet, okkupert',
+	'UserCountry_country_ti' => 'Tibet',
 	'UserCountry_country_ua' => 'Ukraina',
 	'UserCountry_country_ug' => 'Uganda',
 	'UserCountry_country_uk' => 'Storbritania',
@@ -1228,4 +1222,188 @@ $translations = array(
 	'VisitTime_SubmenuTimes' => 'Tid',
 	'VisitTime_NHour' => '%st',
 	'ImageGraph_PluginDescription' => 'Opprett vakre statiske grafar som PNG-bilete for ein Piwik-rapport.',
+	'UserLanguage_Language_aa' => 'afar',
+	'UserLanguage_Language_ab' => 'abkhasisk',
+	'UserLanguage_Language_ae' => 'avestisk',
+	'UserLanguage_Language_af' => 'afrikaans',
+	'UserLanguage_Language_ak' => 'akan',
+	'UserLanguage_Language_am' => 'amharisk',
+	'UserLanguage_Language_an' => 'aragonsk',
+	'UserLanguage_Language_ar' => 'arabisk',
+	'UserLanguage_Language_as' => 'assamisk',
+	'UserLanguage_Language_av' => 'avarisk',
+	'UserLanguage_Language_ay' => 'aymara',
+	'UserLanguage_Language_az' => 'aserbajdsjansk',
+	'UserLanguage_Language_ba' => 'basjkirsk',
+	'UserLanguage_Language_be' => 'kviterussisk',
+	'UserLanguage_Language_bg' => 'bulgarsk',
+	'UserLanguage_Language_bh' => 'bihari',
+	'UserLanguage_Language_bi' => 'bislama',
+	'UserLanguage_Language_bm' => 'bambara',
+	'UserLanguage_Language_bn' => 'bengali',
+	'UserLanguage_Language_bo' => 'tibetansk',
+	'UserLanguage_Language_br' => 'bretonsk',
+	'UserLanguage_Language_bs' => 'bosnisk',
+	'UserLanguage_Language_ca' => 'katalansk',
+	'UserLanguage_Language_ce' => 'tsjetsjensk',
+	'UserLanguage_Language_ch' => 'chamorro',
+	'UserLanguage_Language_co' => 'korsikansk',
+	'UserLanguage_Language_cr' => 'cree',
+	'UserLanguage_Language_cs' => 'tsjekkisk',
+	'UserLanguage_Language_cu' => 'kyrkjeslavisk',
+	'UserLanguage_Language_cv' => 'tsjuvansk',
+	'UserLanguage_Language_cy' => 'walisisk',
+	'UserLanguage_Language_da' => 'dansk',
+	'UserLanguage_Language_de' => 'tysk',
+	'UserLanguage_Language_dv' => 'divehi',
+	'UserLanguage_Language_dz' => 'dzongkha',
+	'UserLanguage_Language_ee' => 'ewe',
+	'UserLanguage_Language_el' => 'gresk',
+	'UserLanguage_Language_en' => 'engelsk',
+	'UserLanguage_Language_eo' => 'esperanto',
+	'UserLanguage_Language_es' => 'spansk',
+	'UserLanguage_Language_et' => 'estisk',
+	'UserLanguage_Language_eu' => 'baskisk',
+	'UserLanguage_Language_fa' => 'persisk',
+	'UserLanguage_Language_ff' => 'fulani',
+	'UserLanguage_Language_fi' => 'finsk',
+	'UserLanguage_Language_fj' => 'fijiansk',
+	'UserLanguage_Language_fo' => 'færøysk',
+	'UserLanguage_Language_fr' => 'fransk',
+	'UserLanguage_Language_fy' => 'vestfrisisk',
+	'UserLanguage_Language_ga' => 'irsk',
+	'UserLanguage_Language_gd' => 'skotsk-gælisk',
+	'UserLanguage_Language_gl' => 'galicisk',
+	'UserLanguage_Language_gn' => 'guarani',
+	'UserLanguage_Language_gu' => 'gujarati',
+	'UserLanguage_Language_gv' => 'manx',
+	'UserLanguage_Language_ha' => 'hausa',
+	'UserLanguage_Language_he' => 'hebraisk',
+	'UserLanguage_Language_hi' => 'hindi',
+	'UserLanguage_Language_ho' => 'hiri motu',
+	'UserLanguage_Language_hr' => 'kroatisk',
+	'UserLanguage_Language_ht' => 'haitisk',
+	'UserLanguage_Language_hu' => 'ungarsk',
+	'UserLanguage_Language_hy' => 'armensk',
+	'UserLanguage_Language_hz' => 'herero',
+	'UserLanguage_Language_ia' => 'interlingua',
+	'UserLanguage_Language_id' => 'indonesisk',
+	'UserLanguage_Language_ie' => 'interlingue',
+	'UserLanguage_Language_ig' => 'ibo',
+	'UserLanguage_Language_ii' => 'sichuan-yi',
+	'UserLanguage_Language_ik' => 'inupiak',
+	'UserLanguage_Language_io' => 'ido',
+	'UserLanguage_Language_is' => 'islandsk',
+	'UserLanguage_Language_it' => 'italiensk',
+	'UserLanguage_Language_iu' => 'inuktitut',
+	'UserLanguage_Language_ja' => 'japansk',
+	'UserLanguage_Language_jv' => 'javanesisk',
+	'UserLanguage_Language_ka' => 'georgisk',
+	'UserLanguage_Language_kg' => 'kikongo',
+	'UserLanguage_Language_ki' => 'kikuyu',
+	'UserLanguage_Language_kj' => 'kuanyama',
+	'UserLanguage_Language_kk' => 'kasakhisk',
+	'UserLanguage_Language_kl' => 'kalaallisut; grønlandsk',
+	'UserLanguage_Language_km' => 'khmer',
+	'UserLanguage_Language_kn' => 'kannada',
+	'UserLanguage_Language_ko' => 'koreansk',
+	'UserLanguage_Language_kr' => 'kanuri',
+	'UserLanguage_Language_ks' => 'kasjmiri',
+	'UserLanguage_Language_ku' => 'kurdisk',
+	'UserLanguage_Language_kv' => 'komi',
+	'UserLanguage_Language_kw' => 'kornisk',
+	'UserLanguage_Language_ky' => 'kirgisisk',
+	'UserLanguage_Language_la' => 'latin',
+	'UserLanguage_Language_lb' => 'luxemburgsk',
+	'UserLanguage_Language_lg' => 'ganda',
+	'UserLanguage_Language_li' => 'limburgisk',
+	'UserLanguage_Language_ln' => 'lingala',
+	'UserLanguage_Language_lo' => 'laotisk',
+	'UserLanguage_Language_lt' => 'litauisk',
+	'UserLanguage_Language_lu' => 'luba-katanga',
+	'UserLanguage_Language_lv' => 'latvisk',
+	'UserLanguage_Language_mg' => 'madagassisk',
+	'UserLanguage_Language_mh' => 'marshallesisk',
+	'UserLanguage_Language_mi' => 'maori',
+	'UserLanguage_Language_mk' => 'makedonsk',
+	'UserLanguage_Language_ml' => 'malayalam',
+	'UserLanguage_Language_mn' => 'mongolsk',
+	'UserLanguage_Language_mr' => 'marathi',
+	'UserLanguage_Language_ms' => 'malayisk',
+	'UserLanguage_Language_mt' => 'maltesisk',
+	'UserLanguage_Language_my' => 'burmesisk',
+	'UserLanguage_Language_na' => 'nauru',
+	'UserLanguage_Language_nb' => 'bokmål',
+	'UserLanguage_Language_nd' => 'nord-ndebele',
+	'UserLanguage_Language_ne' => 'nepalsk',
+	'UserLanguage_Language_ng' => 'ndonga',
+	'UserLanguage_Language_nl' => 'nederlandsk',
+	'UserLanguage_Language_nn' => 'nynorsk',
+	'UserLanguage_Language_no' => 'norsk',
+	'UserLanguage_Language_nr' => 'sør-ndebele',
+	'UserLanguage_Language_nv' => 'navajo',
+	'UserLanguage_Language_ny' => 'nyanja',
+	'UserLanguage_Language_oc' => 'oksitansk',
+	'UserLanguage_Language_oj' => 'ojibwa',
+	'UserLanguage_Language_om' => 'oromo',
+	'UserLanguage_Language_or' => 'oriya',
+	'UserLanguage_Language_os' => 'ossetisk',
+	'UserLanguage_Language_pa' => 'panjabi',
+	'UserLanguage_Language_pi' => 'pali',
+	'UserLanguage_Language_pl' => 'polsk',
+	'UserLanguage_Language_ps' => 'pashto',
+	'UserLanguage_Language_pt' => 'portugisisk',
+	'UserLanguage_Language_qu' => 'quechua',
+	'UserLanguage_Language_rm' => 'retoromansk',
+	'UserLanguage_Language_rn' => 'rundi',
+	'UserLanguage_Language_ro' => 'rumensk',
+	'UserLanguage_Language_ru' => 'russisk',
+	'UserLanguage_Language_rw' => 'kinjarwanda',
+	'UserLanguage_Language_sa' => 'sanskrit',
+	'UserLanguage_Language_sc' => 'sardinsk',
+	'UserLanguage_Language_sd' => 'sindhi',
+	'UserLanguage_Language_se' => 'nordsamisk',
+	'UserLanguage_Language_sg' => 'sango',
+	'UserLanguage_Language_si' => 'singalesisk',
+	'UserLanguage_Language_sk' => 'slovakisk',
+	'UserLanguage_Language_sl' => 'slovensk',
+	'UserLanguage_Language_sm' => 'samoansk',
+	'UserLanguage_Language_sn' => 'shona',
+	'UserLanguage_Language_so' => 'somali',
+	'UserLanguage_Language_sq' => 'albansk',
+	'UserLanguage_Language_sr' => 'serbisk',
+	'UserLanguage_Language_ss' => 'swati',
+	'UserLanguage_Language_st' => 'sørsotho',
+	'UserLanguage_Language_su' => 'sundanesisk',
+	'UserLanguage_Language_sv' => 'svensk',
+	'UserLanguage_Language_sw' => 'swahili',
+	'UserLanguage_Language_ta' => 'tamil',
+	'UserLanguage_Language_te' => 'telugu',
+	'UserLanguage_Language_tg' => 'tatsjikisk',
+	'UserLanguage_Language_th' => 'thai',
+	'UserLanguage_Language_ti' => 'tigrinja',
+	'UserLanguage_Language_tk' => 'turkmensk',
+	'UserLanguage_Language_tl' => 'tagalog',
+	'UserLanguage_Language_tn' => 'tswana',
+	'UserLanguage_Language_to' => 'tonga (Tonga-øyane)',
+	'UserLanguage_Language_tr' => 'tyrkisk',
+	'UserLanguage_Language_ts' => 'tsonga',
+	'UserLanguage_Language_tt' => 'tatarisk',
+	'UserLanguage_Language_tw' => 'twi',
+	'UserLanguage_Language_ty' => 'tahitisk',
+	'UserLanguage_Language_ug' => 'uigurisk',
+	'UserLanguage_Language_uk' => 'ukrainsk',
+	'UserLanguage_Language_ur' => 'urdu',
+	'UserLanguage_Language_uz' => 'usbekisk',
+	'UserLanguage_Language_ve' => 'venda',
+	'UserLanguage_Language_vi' => 'vietnamesisk',
+	'UserLanguage_Language_vo' => 'volapyk',
+	'UserLanguage_Language_wa' => 'vallonsk',
+	'UserLanguage_Language_wo' => 'wolof',
+	'UserLanguage_Language_xh' => 'xhosa',
+	'UserLanguage_Language_yi' => 'jiddisk',
+	'UserLanguage_Language_yo' => 'joruba',
+	'UserLanguage_Language_za' => 'zhuang',
+	'UserLanguage_Language_zh' => 'kinesisk',
+	'UserLanguage_Language_zu' => 'zulu',
 );
