@@ -46,10 +46,7 @@ $translations = array(
 	'General_Description' => 'Descriere',
 	'General_Done' => 'Gata',
 	'General_PoweredBy' => 'Oferit de',
-	'General_MetricsToPlot' => 'Metrici de adaugat',
 	'General_RowsToDisplay' => 'Afişează liniile',
-	'General_MetricToPlot' => 'Metric de adaugat',
-	'General_RecordsToPlot' => 'Inregistrari de adaugat',
 	'General_Name' => 'Nume',
 	'General_Value' => 'Valoare',
 	'General_Total' => 'Total',
@@ -83,7 +80,6 @@ $translations = array(
 	'General_NumberOfVisits' => 'Numar de vizite',
 	'General_VisitConvertedGoal' => 'Vizite care au convertit in cel putin un Scop',
 	'General_VisitConvertedGoalId' => 'Vizite care au convertit intr-un anumit Scop',
-	'General_EcommerceVisitStatus' => 'Statusul comenzii ecommerce la sfarsitul vizitei. De exemplu, pentru a selecta toate vizitele care au rezultat intr-o comanda, cererea catre API ar contine %s',
 	'General_VisitConvertedNGoals' => 'Vizite convertite in %s scopuri',
 	'General_NewVisitor' => 'Vizitator nou',
 	'General_NewVisits' => 'Vizite noi',
@@ -192,7 +188,6 @@ $translations = array(
 	'General_MediumToHighTrafficItIsRecommendedTo' => 'Pentru site-uri cu trafic mediu sau mare, este recomandata procesarea rapoartelor la fiecare jumate de ora (%s secunde) sau ora (%s secunde)',
 	'General_RequiresFlash' => 'Afisarea graficelor in Piwik necesita Flash',
 	'General_GraphHelp' => 'Mai multe informatii despre afisarea graficelor in Piwik',
-	'General_NoDataForGraph' => 'Nici o informatie pentru acest grafic',
 	'General_DataForThisGraphHasBeenPurged' => 'Datele din acest grafic sunt mai vechi de %s luni şi au fost curăţate.',
 	'General_NoDataForTagCloud' => 'No data for this tag cloud.',
 	'General_DataForThisTagCloudHasBeenPurged' => 'Datele din acest nor de etichete sunt mai vechi de %s luni şi au fost curăţate.',
@@ -335,12 +330,17 @@ $translations = array(
 	'Actions_SubmenuPages' => 'Pagini',
 	'Actions_SubmenuPagesEntry' => 'Pagini de intrare',
 	'Actions_SubmenuPagesExit' => 'Pagini de ieşire',
+	'Actions_WidgetPagesExit' => 'Pagini de iesire',
 	'Actions_EntryPageTitles' => 'Titlurile paginilor de intrare',
 	'Actions_ExitPageTitles' => 'Titlurile paginilor de ieşire',
+	'Actions_WidgetExitPageTitles' => 'Titlurile paginii de iesire',
 	'Actions_SubmenuPageTitles' => 'Titluri pagini',
+	'Actions_WidgetSearchCategories' => 'Categorii de cautare',
+	'Actions_WidgetSearchNoResultKeywords' => 'Interogari de cautare fara rezultat',
 	'Actions_PageUrls' => 'URL-uri pagini',
 	'Actions_SubmenuOutlinks' => 'Linkuri externe',
 	'Actions_SubmenuDownloads' => 'Descarcari',
+	'Actions_SubmenuSitesearch' => 'Cautare pe site',
 	'Actions_PagesReportDocumentation' => 'Acest raport conţine informaţii despre URL-urile paginilor ce au fost vizitate. %s Acest tabel este organizat ierarhic,URL-urile sunt afişate într-o structură tip arbore.',
 	'Actions_PageTitlesReportDocumentation' => 'Acest raport conţine informaţii despre titlurile paginilor ce au fost vizitate. %s Titlul paginii este Tag-ul HTML %s afişat de cele mai multe browsere ca nume al ferestrei.',
 	'Actions_OutlinksReportDocumentation' => 'Acest raport arată o listă ierarhică al URL-urilor outlink-urilor ce au fost click-uite de vizitatorii tăi.',
@@ -356,18 +356,35 @@ $translations = array(
 	'Actions_ColumnUniqueOutlinks' => 'Outlink-uri Unice',
 	'Actions_ColumnPageName' => 'Numele Paginii',
 	'Actions_ColumnPageURL' => 'URL-ul Paginii',
+	'Actions_ColumnSearchCategory' => 'Categorie căutare',
+	'Actions_ColumnSearchKeyword' => 'Cuvant cheie',
+	'Actions_SiteSearchKeyword' => 'Intereogare (Cautare pe site)',
 	'Actions_ColumnClickedURL' => 'URL-uri Click-uite',
 	'Actions_ColumnDownloadURL' => 'URL Descărcare',
 	'Actions_ColumnEntryPageURL' => 'URL Paginii de Intrare',
 	'Actions_ColumnEntryPageTitle' => 'Titlul Paginii de Intrare',
 	'Actions_ColumnExitPageURL' => 'URL-ul Paginii de Ieşire',
 	'Actions_ColumnExitPageTitle' => 'Titlul Paginii de Ieşire',
+	'Actions_ColumnNoResultKeyword' => 'Cuvânt cheie fără rezultate în căutări',
+	'Actions_ColumnSearches' => 'Căutări',
+	'Actions_ColumnSiteSearchKeywords' => 'Cuvinte cheie unice',
+	'Actions_ColumnSearchesDocumentation' => 'Numărul de vizite care au căutat după acest cuvânt cheie folosind motorul de căutare de pe site-ul dvs web.',
+	'Actions_ColumnPagesPerSearch' => 'Pagini cu rezultate căutări',
+	'Actions_ColumnPagesPerSearchDocumentation' => 'Vizitatorii vor căuta pe site-ul dvs web şi uneori vor apăsa "următorul" pentru a vizualiza mai multe rezultate. Acesta este numărul mediu de pagini cu rezultate ale căutării vizualizate pentru acest cuvânt cheie.',
 	'Actions_EntryPagesReportDocumentation' => 'Acest raport conţinte informaţii despre paginile de intrare ce au fost folosite în perioada specificată. O pagină de intrare este prima pagină ce a fost văzută de un vizitator în timpul vizitei sale. %s URL-urile de intrare sunt afişate într-o structură arborescentă.',
 	'Actions_EntryPageTitlesReportDocumentation' => 'Acest raport conţine informaţii despre titlurile paginilor de intrare ce au fost folosite în timpul perioadei specificate.',
 	'Actions_ExitPagesReportDocumentation' => 'Acest raport conţine informaţii despre paginile de ieşire ce au fost folosite în timpul perioadei specificate. O pagină de ieşire este ultima pagină ce a fost văzută de un vizitator în timpul vizitei sale. %s URL-urile de ieşire sunt afişate ca o structură tip arbore.',
 	'Actions_ExitPageTitlesReportDocumentation' => 'Acest raport conţine informaţii despre titlurile paginilor de ieşire ce au fost folosite în timpul perioadei specificate.',
 	'AnonymizeIP_PluginDescription' => 'Ascunde ultimele cifre ale IP-ului vizitatorilor pentru a fi în conformitate cu legile privind protecţia datelor personale.',
+	'API_QuickDocumentationTitle' => 'Demonstrare rapida API',
+	'API_UserAuthentication' => 'Identificare utilizator',
 	'API_LoadedAPIs' => 'Incarcare de succes %s al API',
+	'CoreAdminHome_Administration' => 'Administrare',
+	'CoreAdminHome_EmailServerSettings' => 'Setarile serverului email',
+	'CoreAdminHome_JSTracking_CustomCampaignQueryParamDesc' => 'Nota: %1$sPiwik va detecta automat parametrii Google Analytics.%2$s',
+	'CoreAdminHome_ImageTracking' => 'Urmarire prin imagine',
+	'CoreAdminHome_ImageTrackingLink' => 'Legatura de urmarire prin imagine',
+	'CoreAdminHome_JavaScriptTracking' => 'Urmarire prin JavaScript',
 	'CoreHome_CategoryNoData' => 'Nici o data in aceasta categorie. Incearca "Include toata populatia".',
 	'CoreHome_ShowJSCode' => 'Arat codul  javascript ce trebuie folosit',
 	'CoreHome_PageOf_js' => '%1$s al %2$s',
@@ -375,51 +392,51 @@ $translations = array(
 	'CoreHome_PeriodWeek' => 'Saptamana',
 	'CoreHome_PeriodMonth' => 'Luna',
 	'CoreHome_PeriodYear' => 'An',
-	'CoreHome_DaySu_js' => 'Du',
-	'CoreHome_DayMo_js' => 'Lu',
-	'CoreHome_DayTu_js' => 'Ma',
-	'CoreHome_DayWe_js' => 'Mi',
-	'CoreHome_DayTh_js' => 'Jo',
-	'CoreHome_DayFr_js' => 'Vi',
-	'CoreHome_DaySa_js' => 'Sâ',
-	'CoreHome_ShortDay_1_js' => 'Dum',
-	'CoreHome_ShortDay_2_js' => 'Lun',
-	'CoreHome_ShortDay_3_js' => 'Mar',
-	'CoreHome_ShortDay_4_js' => 'Mie',
-	'CoreHome_ShortDay_5_js' => 'Joi',
-	'CoreHome_ShortDay_6_js' => 'Vin',
-	'CoreHome_ShortDay_7_js' => 'Sâm',
-	'CoreHome_LongDay_1_js' => 'Duminică',
-	'CoreHome_LongDay_2_js' => 'Luni',
-	'CoreHome_LongDay_3_js' => 'Marţi',
-	'CoreHome_LongDay_4_js' => 'Miercuri',
-	'CoreHome_LongDay_5_js' => 'Joi',
-	'CoreHome_LongDay_6_js' => 'Vineri',
-	'CoreHome_LongDay_7_js' => 'Sâmbătă',
-	'CoreHome_ShortMonth_1_js' => 'Ian',
-	'CoreHome_ShortMonth_2_js' => 'Feb',
-	'CoreHome_ShortMonth_3_js' => 'Mar',
-	'CoreHome_ShortMonth_4_js' => 'Apr',
-	'CoreHome_ShortMonth_5_js' => 'Mai',
-	'CoreHome_ShortMonth_6_js' => 'Iun',
-	'CoreHome_ShortMonth_7_js' => 'Iul',
-	'CoreHome_ShortMonth_8_js' => 'Aug',
-	'CoreHome_ShortMonth_9_js' => 'Sep',
-	'CoreHome_ShortMonth_10_js' => 'Oct',
-	'CoreHome_ShortMonth_11_js' => 'Nov',
-	'CoreHome_ShortMonth_12_js' => 'Dec',
-	'CoreHome_MonthJanuary_js' => 'Ianuarie',
-	'CoreHome_MonthFebruary_js' => 'Februarie',
-	'CoreHome_MonthMarch_js' => 'Martie',
-	'CoreHome_MonthApril_js' => 'Aprilie',
-	'CoreHome_MonthMay_js' => 'Mai',
-	'CoreHome_MonthJune_js' => 'Iunie',
-	'CoreHome_MonthJuly_js' => 'Iulie',
-	'CoreHome_MonthAugust_js' => 'August',
-	'CoreHome_MonthSeptember_js' => 'Septembrie',
-	'CoreHome_MonthOctober_js' => 'Octombrie',
-	'CoreHome_MonthNovember_js' => 'Noiembrie',
-	'CoreHome_MonthDecember_js' => 'Decembrie',
+	'General_DaySu_js' => 'Du',
+	'General_DayMo_js' => 'Lu',
+	'General_DayTu_js' => 'Ma',
+	'General_DayWe_js' => 'Mi',
+	'General_DayTh_js' => 'Jo',
+	'General_DayFr_js' => 'Vi',
+	'General_DaySa_js' => 'Sâ',
+	'General_ShortDay_1_js' => 'Dum',
+	'General_ShortDay_2_js' => 'Lun',
+	'General_ShortDay_3_js' => 'Mar',
+	'General_ShortDay_4_js' => 'Mie',
+	'General_ShortDay_5_js' => 'Joi',
+	'General_ShortDay_6_js' => 'Vin',
+	'General_ShortDay_7_js' => 'Sâm',
+	'General_LongDay_1_js' => 'Duminică',
+	'General_LongDay_2_js' => 'Luni',
+	'General_LongDay_3_js' => 'Marţi',
+	'General_LongDay_4_js' => 'Miercuri',
+	'General_LongDay_5_js' => 'Joi',
+	'General_LongDay_6_js' => 'Vineri',
+	'General_LongDay_7_js' => 'Sâmbătă',
+	'General_ShortMonth_1_js' => 'Ian',
+	'General_ShortMonth_2_js' => 'Feb',
+	'General_ShortMonth_3_js' => 'Mar',
+	'General_ShortMonth_4_js' => 'Apr',
+	'General_ShortMonth_5_js' => 'Mai',
+	'General_ShortMonth_6_js' => 'Iun',
+	'General_ShortMonth_7_js' => 'Iul',
+	'General_ShortMonth_8_js' => 'Aug',
+	'General_ShortMonth_9_js' => 'Sep',
+	'General_ShortMonth_10_js' => 'Oct',
+	'General_ShortMonth_11_js' => 'Nov',
+	'General_ShortMonth_12_js' => 'Dec',
+	'General_MonthJanuary_js' => 'Ianuarie',
+	'General_MonthFebruary_js' => 'Februarie',
+	'General_MonthMarch_js' => 'Martie',
+	'General_MonthApril_js' => 'Aprilie',
+	'General_MonthMay_js' => 'Mai',
+	'General_MonthJune_js' => 'Iunie',
+	'General_MonthJuly_js' => 'Iulie',
+	'General_MonthAugust_js' => 'August',
+	'General_MonthSeptember_js' => 'Septembrie',
+	'General_MonthOctober_js' => 'Octombrie',
+	'General_MonthNovember_js' => 'Noiembrie',
+	'General_MonthDecember_js' => 'Decembrie',
 	'CorePluginsAdmin_Plugins' => 'Pluginuri',
 	'CorePluginsAdmin_PluginsManagement' => 'Managementul pluginurilor',
 	'CorePluginsAdmin_MainDescription' => 'Pluginurile extind functionaliatatea lui Piwik. Orice plugin instalat , poate fi activat sau dezactivat aici.',
@@ -498,15 +515,44 @@ $translations = array(
 	'DBStats_DataSize' => 'Marime date',
 	'DBStats_IndexSize' => 'Marime index',
 	'DBStats_TotalSize' => 'Marime totala',
+	'Installation_Installation' => 'Installation',
+	'Installation_InstallationStatus' => 'Installation status',
+	'Installation_PercentDone' => '%s %% Done',
+	'Installation_NoConfigFound' => 'The Piwik configuration file couldn\'t be found and you are trying to access a Piwik page.<br /><b>  » You can <a href=\'index.php\'>install Piwik now</a></b><br /><small>If you installed Piwik before and have some tables in your DB, don\'t worry, you can reuse the same tables and keep your existing data!</small>',
 	'Installation_JsTag' => 'Javascript tag',
+	'Installation_Congratulations' => 'Congratulations',
 	'Installation_CongratulationsHelp' => '<p>Congratulations! Your Piwik installation is complete.</p><p>Make sure your javascript code is entered on your pages, and wait for your first visitors!</p>',
+	'Installation_ContinueToPiwik' => 'Continue to Piwik',
 	'Installation_SetupWebsite' => 'Setup a website',
+	'Installation_SetupWebsiteError' => 'There was an error when adding the website',
+	'Installation_SuperUserLogin' => 'super user login',
+	'Installation_Password' => 'password',
+	'Installation_PasswordRepeat' => 'password (repeat)',
+	'Installation_Email' => 'email',
+	'Installation_SecurityNewsletter' => 'email me with major Piwik upgrades and security alerts',
+	'Installation_CommunityNewsletter' => 'email me with community updates (new plugins, new features, etc.)',
+	'Installation_PasswordDoNotMatch' => 'password do not match',
 	'Installation_SystemCheck' => 'System check',
+	'Installation_SystemCheckPhp' => 'PHP version',
+	'Installation_SystemCheckWriteDirs' => 'Directories with write access',
+	'Installation_SystemCheckWriteDirsHelp' => 'To fix this error on your Linux system, try typing in the following command(s)',
+	'Installation_SystemCheckMemoryLimit' => 'Memory limit',
 	'Installation_SystemCheckMemoryLimitHelp' => 'On a high traffic website, the archiving process may require more memory than currently allowed.<br />See the directive memory_limit in your php.ini file if necessary.',
+	'Installation_SystemCheckGD' => 'GD > 2.x (graphics)',
 	'Installation_SystemCheckGDHelp' => 'The sparklines (small graphs) will not work.',
 	'Installation_SystemCheckTimeLimitHelp' => 'On a high traffic website, executing the archiving process may require more time than currently allowed.<br />See the directive max_execution_time  in your php.ini file if necessary',
+	'Installation_SystemCheckError' => 'An error occured - must be fixed before you proceed',
+	'Installation_SystemCheckWarning' => 'Piwik will work normally but some features may be missing',
 	'Installation_Tables' => 'Creating the tables',
+	'Installation_TablesFound' => 'The following tables have been found in the database',
+	'Installation_TablesWarningHelp' => 'Either choose to reuse the existing database tables or select a clean install to erase all existing data in the database.',
+	'Installation_TablesReuse' => 'Reuse the existing tables',
+	'Installation_TablesDelete' => 'Delete the detected tables',
+	'Installation_TablesDeletedSuccess' => 'Existing Piwik tables deleted with success',
+	'Installation_TablesCreatedSuccess' => 'Tables created with success!',
+	'Installation_DatabaseCreatedSuccess' => 'Database %s created with success!',
 	'Installation_Welcome' => 'Bine ai venit!',
+	'Installation_WelcomeHelp' => '<p>Piwik is an open source web analytics software that makes it easy to get the information you want from your visitors.</p><p>This process is split up into %s easy steps and will take around 5 minutes.</p>',
 	'Login_PluginDescription' => 'Modul de autentintificare, ce citeşte credenţialele din fişierul config/config.inc.php pentru Super User şi din Baza de date pentru alţi useri. Poate fi uşor schimbat pentru a folosi un nou mecanism de Autentificare (OpenID, htaccess, custom Auth, etc.).',
 	'Login_LoginPasswordNotCorrect' => 'Numele si parola nu sunt corecte',
 	'Login_Password' => 'Parola',
@@ -554,14 +600,19 @@ $translations = array(
 	'SitesManager_Sites' => 'Situri',
 	'SitesManager_WebsitesManagement' => 'Mangementul siteurilor',
 	'SitesManager_MainDescription' => 'Your Web Analytics reports need Websites! Add, update, delete Websites, and show the Javascript to insert in your pages.',
+	'SitesManager_NoWebsites' => 'You don\'t have any website to administrate.',
 	'SitesManager_AddSite' => 'Adauga un site',
 	'SitesManager_Urls' => 'Adresa',
 	'SitesManager_MenuSites' => 'Situri',
+	'SitesManager_DeleteConfirm_js' => 'Are you sure you want to delete the website %s?',
+	'SitesManager_ExceptionDeleteSite' => 'It is not possible to delete this website as it is the only registered website. Add a new website first, then delete this one.',
 	'SitesManager_ExceptionNoUrl' => 'You must specify at least one URL for the site.',
 	'SitesManager_ExceptionEmptyName' => 'The site name can\'t be empty.',
+	'SitesManager_ExceptionInvalidUrl' => 'The url \'%s\' is not a valid URL.',
 	'TranslationsAdmin_MenuTranslations' => 'Traducere',
 	'TranslationsAdmin_MenuLanguages' => 'Limba',
 	'TranslationsAdmin_LanguageCode' => 'Cod limba',
+	'TranslationsAdmin_Plugin' => 'Plugin',
 	'TranslationsAdmin_Definition' => 'Definitie',
 	'TranslationsAdmin_DefaultString' => 'Limba curenta (English)',
 	'TranslationsAdmin_TranslationString' => 'Traducere (Limba curenta: %s)',
@@ -868,8 +919,11 @@ $translations = array(
 	'UsersManager_User' => 'Utilizator',
 	'UsersManager_PrivNone' => 'Fara acces',
 	'UsersManager_PrivView' => 'Vezi',
+	'UsersManager_PrivAdmin' => 'Admin',
 	'UsersManager_ChangeAllConfirm' => 'Esti sigur ca vrei sa scimbi \'%s\' permisiunile tuturor siteurilor?',
 	'UsersManager_Password' => 'Parola',
+	'UsersManager_Email' => 'Email',
+	'UsersManager_Alias' => 'Alias',
 	'UsersManager_Edit' => 'Editeaza',
 	'UsersManager_AddUser' => 'Adauga user',
 	'UsersManager_MenuUsers' => 'Useri',
@@ -882,6 +936,7 @@ $translations = array(
 	'UsersManager_ExceptionAdminAnonymous' => 'Nu poti autoriza \'admin\' accesul la \'anonymous\' user.',
 	'UsersManager_ExceptionEditAnonymous' => 'Userul anonim nu poate fi editat sau sters.De exemplu poti face ca statisticile tale sa fie publice autorizand \'view\' accesul la \'anonymous\' user.',
 	'UsersManager_ExceptionUserDoesNotExist' => 'User \'%s\' nu exista.',
+	'UsersManager_ExceptionAccessValues' => 'The parameter access must have one of the following values : [ %s ]',
 	'VisitFrequency_Evolution' => 'Evolutii peste perioada',
 	'VisitFrequency_ReturnVisits' => '%s vizitatori intorsi',
 	'VisitFrequency_ReturnActions' => '%s actiuni ale vizitatorilor intorsi',
@@ -892,6 +947,7 @@ $translations = array(
 	'VisitorInterest_VisitsPerNbOfPages' => 'Vizite per numar pagini',
 	'VisitorInterest_WidgetLengths' => 'Durata vizitelor',
 	'VisitorInterest_WidgetPages' => 'Pagini per vizita',
+	'VisitorInterest_PlusXMin' => '%s min',
 	'VisitorInterest_OnePage' => '1 pagina',
 	'VisitorInterest_NPages' => '%s pagini',
 	'VisitsSummary_NbVisits' => '%s vizitari',
@@ -912,4 +968,151 @@ $translations = array(
 	'VisitTime_WidgetLocalTime' => 'Vizite dupa timpul local',
 	'VisitTime_WidgetServerTime' => 'Vizite dupa timpul serverului',
 	'VisitTime_SubmenuTimes' => 'Timp',
+	'VisitTime_NHour' => '%sh',
+	'Annotations_Annotations' => 'Note',
+	'Annotations_EnterAnnotationText' => 'Introdu nota...',
+	'Annotations_IconDesc_js' => 'Vezi notele pentru aceasta data de interval.',
+	'Annotations_ViewAndAddAnnotations_js' => 'Vezi si adauga nota pentru %s...',
+	'Annotations_ClickToDelete' => 'Click pentru a sterge acesta nota',
+	'Annotations_ClickToStarOrUnstar' => 'Click pentru a marca sau demarca aceasta nota.',
+	'Annotations_LoginToAnnotate' => 'Conecteaza-te pentru a crea o nota.',
+	'Annotations_AnnotationOnDate' => 'Comentariu in %1$s: %2$s',
+	'UserLanguage_Language_ab' => 'abhază',
+	'UserLanguage_Language_af' => 'afrikaans',
+	'UserLanguage_Language_am' => 'amharică',
+	'UserLanguage_Language_an' => 'aragoneză',
+	'UserLanguage_Language_ar' => 'arabă',
+	'UserLanguage_Language_as' => 'asameză',
+	'UserLanguage_Language_av' => 'avară',
+	'UserLanguage_Language_ay' => 'aymara',
+	'UserLanguage_Language_az' => 'azeră',
+	'UserLanguage_Language_ba' => 'bașkiră',
+	'UserLanguage_Language_be' => 'bielorusă',
+	'UserLanguage_Language_bg' => 'bulgară',
+	'UserLanguage_Language_bh' => 'bihari',
+	'UserLanguage_Language_bn' => 'bengaleză',
+	'UserLanguage_Language_bo' => 'tibetană',
+	'UserLanguage_Language_br' => 'bretonă',
+	'UserLanguage_Language_bs' => 'bosniacă',
+	'UserLanguage_Language_ca' => 'catalană',
+	'UserLanguage_Language_ce' => 'cecenă',
+	'UserLanguage_Language_co' => 'corsicană',
+	'UserLanguage_Language_cs' => 'cehă',
+	'UserLanguage_Language_cu' => 'slavonă',
+	'UserLanguage_Language_cv' => 'ciuvașă',
+	'UserLanguage_Language_cy' => 'velșă',
+	'UserLanguage_Language_da' => 'daneză',
+	'UserLanguage_Language_de' => 'germană',
+	'UserLanguage_Language_el' => 'greacă',
+	'UserLanguage_Language_en' => 'engleză',
+	'UserLanguage_Language_eo' => 'esperanto',
+	'UserLanguage_Language_es' => 'spaniolă',
+	'UserLanguage_Language_et' => 'estoniană',
+	'UserLanguage_Language_eu' => 'bască',
+	'UserLanguage_Language_fa' => 'persană',
+	'UserLanguage_Language_fi' => 'finlandeză',
+	'UserLanguage_Language_fj' => 'fijiană',
+	'UserLanguage_Language_fo' => 'faroeză',
+	'UserLanguage_Language_fr' => 'franceză',
+	'UserLanguage_Language_fy' => 'frizonă occidentală',
+	'UserLanguage_Language_ga' => 'irlandeză',
+	'UserLanguage_Language_gd' => 'gaelică scoțiană',
+	'UserLanguage_Language_gl' => 'galiciană',
+	'UserLanguage_Language_gn' => 'guarani',
+	'UserLanguage_Language_gu' => 'gujarati',
+	'UserLanguage_Language_he' => 'ebraică',
+	'UserLanguage_Language_hi' => 'hindi',
+	'UserLanguage_Language_hr' => 'croată',
+	'UserLanguage_Language_ht' => 'haitiană',
+	'UserLanguage_Language_hu' => 'maghiară',
+	'UserLanguage_Language_hy' => 'armeană',
+	'UserLanguage_Language_ia' => 'interlingua',
+	'UserLanguage_Language_id' => 'indoneziană',
+	'UserLanguage_Language_ie' => 'interlingue',
+	'UserLanguage_Language_ik' => 'inupiak',
+	'UserLanguage_Language_is' => 'islandeză',
+	'UserLanguage_Language_it' => 'italiană',
+	'UserLanguage_Language_ja' => 'japoneză',
+	'UserLanguage_Language_jv' => 'javaneză',
+	'UserLanguage_Language_ka' => 'georgiană',
+	'UserLanguage_Language_kg' => 'congoleză',
+	'UserLanguage_Language_kk' => 'kazahă',
+	'UserLanguage_Language_kl' => 'kalaallisut',
+	'UserLanguage_Language_km' => 'khmeră',
+	'UserLanguage_Language_kn' => 'kannada',
+	'UserLanguage_Language_ko' => 'coreeană',
+	'UserLanguage_Language_ks' => 'cașmireză',
+	'UserLanguage_Language_ku' => 'kurdă',
+	'UserLanguage_Language_ky' => 'kîrgîză',
+	'UserLanguage_Language_la' => 'latină',
+	'UserLanguage_Language_lb' => 'luxemburgheză',
+	'UserLanguage_Language_ln' => 'lingala',
+	'UserLanguage_Language_lo' => 'laoțiană',
+	'UserLanguage_Language_lt' => 'lituaniană',
+	'UserLanguage_Language_lv' => 'letonă',
+	'UserLanguage_Language_mg' => 'malgașă',
+	'UserLanguage_Language_mi' => 'maori',
+	'UserLanguage_Language_mk' => 'macedoneană',
+	'UserLanguage_Language_ml' => 'malayalam',
+	'UserLanguage_Language_mn' => 'mongolă',
+	'UserLanguage_Language_mr' => 'marathi',
+	'UserLanguage_Language_ms' => 'malay',
+	'UserLanguage_Language_mt' => 'malteză',
+	'UserLanguage_Language_my' => 'birmaneză',
+	'UserLanguage_Language_ne' => 'nepaleză',
+	'UserLanguage_Language_nl' => 'olandeză',
+	'UserLanguage_Language_nn' => 'norvegiană nynorsk',
+	'UserLanguage_Language_no' => 'norvegiană',
+	'UserLanguage_Language_nv' => 'navajo',
+	'UserLanguage_Language_oc' => 'occitană',
+	'UserLanguage_Language_om' => 'oromo',
+	'UserLanguage_Language_or' => 'oriya',
+	'UserLanguage_Language_pa' => 'punjabi',
+	'UserLanguage_Language_pi' => 'pali',
+	'UserLanguage_Language_pl' => 'poloneză',
+	'UserLanguage_Language_ps' => 'pașto',
+	'UserLanguage_Language_pt' => 'portugheză',
+	'UserLanguage_Language_qu' => 'quechua',
+	'UserLanguage_Language_rm' => 'retoromană',
+	'UserLanguage_Language_ro' => 'română',
+	'UserLanguage_Language_ru' => 'rusă',
+	'UserLanguage_Language_sa' => 'sanscrită',
+	'UserLanguage_Language_sc' => 'sardiniană',
+	'UserLanguage_Language_sd' => 'sindhi',
+	'UserLanguage_Language_si' => 'singaleză',
+	'UserLanguage_Language_sk' => 'slovacă',
+	'UserLanguage_Language_sl' => 'slovenă',
+	'UserLanguage_Language_sm' => 'samoană',
+	'UserLanguage_Language_so' => 'somaleză',
+	'UserLanguage_Language_sq' => 'albaneză',
+	'UserLanguage_Language_sr' => 'sârbă',
+	'UserLanguage_Language_st' => 'sesotho',
+	'UserLanguage_Language_su' => 'sundaneză',
+	'UserLanguage_Language_sv' => 'suedeză',
+	'UserLanguage_Language_sw' => 'swahili',
+	'UserLanguage_Language_ta' => 'tamilă',
+	'UserLanguage_Language_te' => 'telugu',
+	'UserLanguage_Language_tg' => 'tadjică',
+	'UserLanguage_Language_th' => 'thailandeză',
+	'UserLanguage_Language_ti' => 'tigrinya',
+	'UserLanguage_Language_tk' => 'turkmenă',
+	'UserLanguage_Language_tl' => 'tagalog',
+	'UserLanguage_Language_tn' => 'setswana',
+	'UserLanguage_Language_tr' => 'turcă',
+	'UserLanguage_Language_tt' => 'tătară',
+	'UserLanguage_Language_tw' => 'twi',
+	'UserLanguage_Language_ty' => 'tahitiană',
+	'UserLanguage_Language_ug' => 'uigură',
+	'UserLanguage_Language_uk' => 'ucraineană',
+	'UserLanguage_Language_ur' => 'urdu',
+	'UserLanguage_Language_uz' => 'uzbecă',
+	'UserLanguage_Language_vi' => 'vietnameză',
+	'UserLanguage_Language_vo' => 'volapuk',
+	'UserLanguage_Language_wa' => 'valonă',
+	'UserLanguage_Language_wo' => 'wolof',
+	'UserLanguage_Language_xh' => 'xhosa',
+	'UserLanguage_Language_yi' => 'idiș',
+	'UserLanguage_Language_yo' => 'yoruba',
+	'UserLanguage_Language_zh' => 'chineză',
+	'UserLanguage_Language_zu' => 'zulu',
 );
