@@ -41,9 +41,6 @@ $translations = array(
 	'General_Description' => 'Popis',
 	'General_Done' => 'Hotovo',
 	'General_PoweredBy' => 'Beží na',
-	'General_MetricsToPlot' => 'Metriky na zobrazenie',
-	'General_MetricToPlot' => 'Metrika na zobrazenie',
-	'General_RecordsToPlot' => 'Záznamy na zobrazenie',
 	'General_Name' => 'Meno',
 	'General_Value' => 'Hodnota',
 	'General_Total' => 'Spolu',
@@ -77,7 +74,6 @@ $translations = array(
 	'General_NumberOfVisits' => 'Počet návštev',
 	'General_VisitConvertedGoal' => 'Návšteva dokončila aspoň jeden cieľ',
 	'General_VisitConvertedGoalId' => 'Návšteva dokončila špecifické ID cieľu',
-	'General_EcommerceVisitStatus' => 'Navštívte stav Ecommerce návštevy na konci trvania návštevy. Napríklad: Pre výber všetkých návštev, ktoré vykonali online objednávku by API požiadavka obsahovala %s',
 	'General_VisitConvertedNGoals' => 'Návšteva dokončila %s cieľov',
 	'General_NewVisitor' => 'Nový návštevník',
 	'General_NewVisits' => 'Nové návštevy',
@@ -185,7 +181,6 @@ $translations = array(
 	'General_MediumToHighTrafficItIsRecommendedTo' => 'Pre webové sídla, ktoré majú stredne veľkú až veľkú návštevnosť, odporúčame pre spracovanie štatistík nastavenie v daný deň maximálne na každú každú pol hodinu (%s sekúnd), alebo každú hodinu (%s sekúnd).',
 	'General_RequiresFlash' => 'Zobrazenie grafu vyžaduje Flash',
 	'General_GraphHelp' => 'Ďalšie informácie o zobrazení grafov.',
-	'General_NoDataForGraph' => 'Pre tento graf nie sú dáta.',
 	'General_NoDataForTagCloud' => 'Pre tento oblak nie sú dáta.',
 	'General_DisplaySimpleTable' => 'Zobrazenie jednoduchej tabuľky',
 	'General_DisplayTableWithMoreMetrics' => 'Zobraziť tabuľku s viacerými metrikami',
@@ -313,7 +308,9 @@ $translations = array(
 	'Actions_SubmenuPages' => 'Stránky',
 	'Actions_SubmenuPagesEntry' => 'Vstupné stránky',
 	'Actions_SubmenuPagesExit' => 'Výstupné stránky',
+	'Actions_ExitPageTitles' => 'Titulky výstupnej stránky',
 	'Actions_SubmenuPageTitles' => 'Názov stránky',
+	'Actions_PageUrls' => 'URL stránok',
 	'Actions_SubmenuOutlinks' => 'Externé stránky',
 	'Actions_SubmenuDownloads' => 'Sťahovania',
 	'Actions_ColumnClicks' => 'Kliknutia',
@@ -322,77 +319,90 @@ $translations = array(
 	'Actions_ColumnDownloads' => 'Sťahovania',
 	'Actions_ColumnUniqueDownloads' => 'Jedinečné sťahovania',
 	'Actions_ColumnOutlinks' => 'Konkajšie odkazy',
+	'Actions_ColumnUniqueOutlinks' => 'Unikátne vonkajšie odkazy',
 	'Actions_ColumnPageName' => 'Názov stránky',
 	'Actions_ColumnPageURL' => 'Adresa stránky',
+	'Actions_ColumnSearchKeyword' => 'Kľúčové slovo',
 	'Actions_ColumnClickedURL' => 'Kliknutí na odkaz',
 	'Actions_ColumnDownloadURL' => 'Stiahnuté URL',
+	'Actions_ColumnEntryPageURL' => 'URL vstupnej stránky',
+	'Actions_ColumnEntryPageTitle' => 'Titulok vstupnej stránky',
 	'Actions_ColumnExitPageURL' => 'URL výstupnej stránky',
 	'Actions_ColumnExitPageTitle' => 'Titulok výstupnej stránky',
+	'Actions_ColumnSearches' => 'Vyhľadávania',
 	'AnonymizeIP_PluginDescription' => 'Anonymnosť posledný bajt IP adresy návštevníkov v súlade s miestnymi zákonmi na ochranu súkromia.',
+	'API_QuickDocumentationTitle' => 'Rýchla dokumentácia k API',
 	'API_UserAuthentication' => 'Overenie užívateľa',
 	'API_LoadedAPIs' => 'Úspešne načítané %s API',
 	'CoreAdminHome_PluginDescription' => 'Správa oblasti Piwik.',
 	'CoreAdminHome_MenuGeneralSettings' => 'Všeobecné nastavenie',
 	'CoreAdminHome_Administration' => 'Administrácia',
+	'CoreAdminHome_UseCustomLogo' => 'Použiť vlastné logo',
+	'CoreAdminHome_LogoUpload' => 'Vyberte logo pre načítanie',
 	'CoreHome_PluginDescription' => 'Web Analytik report štruktúra.',
 	'CoreHome_WebAnalyticsReports' => 'Web Analytik report',
 	'CoreHome_ThereIsNoDataForThisReport' => 'Neexistujú žiadne dáta pre túto správu.',
 	'CoreHome_CategoryNoData' => 'Pre túto kategóriu nie sú dáta. Skúste použiť „Vrátane celej populácie“.',
 	'CoreHome_ShowJSCode' => 'Zobraziť javascript kód pre vloženie',
+	'CoreHome_Default_js' => 'Prednastavené',
 	'CoreHome_PageOf_js' => '%1$s z %2$s',
 	'CoreHome_PeriodDay' => 'Deň',
 	'CoreHome_PeriodWeek' => 'Týždeň',
 	'CoreHome_PeriodMonth' => 'Mesiac',
 	'CoreHome_PeriodYear' => 'Rok',
+	'CoreHome_PeriodRange' => 'Rozsah',
 	'CoreHome_PeriodDays' => 'dni',
 	'CoreHome_PeriodWeeks' => 'týždne',
 	'CoreHome_PeriodMonths' => 'mesiace',
 	'CoreHome_PeriodYears' => 'roky',
-	'CoreHome_DaySu_js' => 'Ne',
-	'CoreHome_DayMo_js' => 'Po',
-	'CoreHome_DayTu_js' => 'Ut',
-	'CoreHome_DayWe_js' => 'St',
-	'CoreHome_DayTh_js' => 'Št',
-	'CoreHome_DayFr_js' => 'Pi',
-	'CoreHome_DaySa_js' => 'So',
-	'CoreHome_ShortDay_1_js' => 'Ne',
-	'CoreHome_ShortDay_2_js' => 'Po',
-	'CoreHome_ShortDay_3_js' => 'Ut',
-	'CoreHome_ShortDay_4_js' => 'St',
-	'CoreHome_ShortDay_5_js' => 'Št',
-	'CoreHome_ShortDay_6_js' => 'Pia',
-	'CoreHome_ShortDay_7_js' => 'So',
-	'CoreHome_LongDay_1_js' => 'Nedeľa',
-	'CoreHome_LongDay_2_js' => 'Pondelok',
-	'CoreHome_LongDay_3_js' => 'Utorok',
-	'CoreHome_LongDay_4_js' => 'Streda',
-	'CoreHome_LongDay_5_js' => 'Štvrtok',
-	'CoreHome_LongDay_6_js' => 'Piatok',
-	'CoreHome_LongDay_7_js' => 'Sobota',
-	'CoreHome_ShortMonth_1_js' => 'Jan',
-	'CoreHome_ShortMonth_2_js' => 'Feb',
-	'CoreHome_ShortMonth_3_js' => 'Mar',
-	'CoreHome_ShortMonth_4_js' => 'Apr',
-	'CoreHome_ShortMonth_5_js' => 'Máj',
-	'CoreHome_ShortMonth_6_js' => 'Jún',
-	'CoreHome_ShortMonth_7_js' => 'Júl',
-	'CoreHome_ShortMonth_8_js' => 'Aug',
-	'CoreHome_ShortMonth_9_js' => 'Sep',
-	'CoreHome_ShortMonth_10_js' => 'Okt',
-	'CoreHome_ShortMonth_11_js' => 'Nov',
-	'CoreHome_ShortMonth_12_js' => 'Dec',
-	'CoreHome_MonthJanuary_js' => 'Január',
-	'CoreHome_MonthFebruary_js' => 'Február',
-	'CoreHome_MonthMarch_js' => 'Marec',
-	'CoreHome_MonthApril_js' => 'Apríl',
-	'CoreHome_MonthMay_js' => 'Máj',
-	'CoreHome_MonthJune_js' => 'Jún',
-	'CoreHome_MonthJuly_js' => 'Júl',
-	'CoreHome_MonthAugust_js' => 'August',
-	'CoreHome_MonthSeptember_js' => 'September',
-	'CoreHome_MonthOctober_js' => 'Október',
-	'CoreHome_MonthNovember_js' => 'November',
-	'CoreHome_MonthDecember_js' => 'December',
+	'General_DaySu_js' => 'Ne',
+	'General_DayMo_js' => 'Po',
+	'General_DayTu_js' => 'Ut',
+	'General_DayWe_js' => 'St',
+	'General_DayTh_js' => 'Št',
+	'General_DayFr_js' => 'Pi',
+	'General_DaySa_js' => 'So',
+	'General_ShortDay_1_js' => 'Ne',
+	'General_ShortDay_2_js' => 'Po',
+	'General_ShortDay_3_js' => 'Ut',
+	'General_ShortDay_4_js' => 'St',
+	'General_ShortDay_5_js' => 'Št',
+	'General_ShortDay_6_js' => 'Pia',
+	'General_ShortDay_7_js' => 'So',
+	'General_LongDay_1_js' => 'Nedeľa',
+	'General_LongDay_2_js' => 'Pondelok',
+	'General_LongDay_3_js' => 'Utorok',
+	'General_LongDay_4_js' => 'Streda',
+	'General_LongDay_5_js' => 'Štvrtok',
+	'General_LongDay_6_js' => 'Piatok',
+	'General_LongDay_7_js' => 'Sobota',
+	'General_ShortMonth_1_js' => 'Jan',
+	'General_ShortMonth_2_js' => 'Feb',
+	'General_ShortMonth_3_js' => 'Mar',
+	'General_ShortMonth_4_js' => 'Apr',
+	'General_ShortMonth_5_js' => 'Máj',
+	'General_ShortMonth_6_js' => 'Jún',
+	'General_ShortMonth_7_js' => 'Júl',
+	'General_ShortMonth_8_js' => 'Aug',
+	'General_ShortMonth_9_js' => 'Sep',
+	'General_ShortMonth_10_js' => 'Okt',
+	'General_ShortMonth_11_js' => 'Nov',
+	'General_ShortMonth_12_js' => 'Dec',
+	'General_MonthJanuary_js' => 'Január',
+	'General_MonthFebruary_js' => 'Február',
+	'General_MonthMarch_js' => 'Marec',
+	'General_MonthApril_js' => 'Apríl',
+	'General_MonthMay_js' => 'Máj',
+	'General_MonthJune_js' => 'Jún',
+	'General_MonthJuly_js' => 'Júl',
+	'General_MonthAugust_js' => 'August',
+	'General_MonthSeptember_js' => 'September',
+	'General_MonthOctober_js' => 'Október',
+	'General_MonthNovember_js' => 'November',
+	'General_MonthDecember_js' => 'December',
+	'CoreHome_ReportGeneratedOn' => 'Report vygenerovaný %s',
+	'CoreHome_ReportGeneratedXAgo' => 'Report vygenerovaný pred %s',
+	'General_LoadingPopover_js' => 'Načítavanie %s...',
 	'CorePluginsAdmin_PluginDescription' => 'Pluginy v administračnom rozhraní.',
 	'CorePluginsAdmin_Plugins' => 'Zásuvné moduly',
 	'CorePluginsAdmin_PluginsManagement' => 'Správa modulov',
@@ -639,6 +649,7 @@ $translations = array(
 	'UserCountry_PluginDescription' => 'Report návštevníkov podľa krajiny',
 	'UserCountry_Country' => 'Krajina',
 	'UserCountry_Continent' => 'Kontinent',
+	'UserCountry_City' => 'Mesto',
 	'UserCountry_DistinctCountries' => 'Počet rôznych krajín: %s',
 	'UserCountry_Location' => 'Miesto',
 	'UserCountry_SubmenuLocations' => 'Umiestnenie',
@@ -1049,7 +1060,179 @@ $translations = array(
 	'PDFReports_PiwikReports' => 'Reporty',
 	'PDFReports_EmailHello' => 'Ahoj,',
 	'PDFReports_PleaseFindAttachedFile' => 'Nájdete v priloženom súbore %1$s reporte pre %2$s.',
-
-	// FOR REVIEW
-	'GeoIP_ColumnCity' => 'Mesto',
+	'UserLanguage_Language_aa' => 'afarčina',
+	'UserLanguage_Language_ab' => 'abcházština',
+	'UserLanguage_Language_ae' => 'avestčina',
+	'UserLanguage_Language_af' => 'afrikánčina',
+	'UserLanguage_Language_ak' => 'akančina',
+	'UserLanguage_Language_am' => 'amharčina',
+	'UserLanguage_Language_an' => 'aragónčina',
+	'UserLanguage_Language_ar' => 'arabčina',
+	'UserLanguage_Language_as' => 'ásámčina',
+	'UserLanguage_Language_av' => 'avarčina',
+	'UserLanguage_Language_ay' => 'aymarčina',
+	'UserLanguage_Language_az' => 'azerbajdžančina',
+	'UserLanguage_Language_ba' => 'baskirčina',
+	'UserLanguage_Language_be' => 'bieloruština',
+	'UserLanguage_Language_bg' => 'bulharčina',
+	'UserLanguage_Language_bh' => 'bihárske jazyky',
+	'UserLanguage_Language_bi' => 'bislama',
+	'UserLanguage_Language_bm' => 'bambarčina',
+	'UserLanguage_Language_bn' => 'bengálčina',
+	'UserLanguage_Language_bo' => 'tibetčina',
+	'UserLanguage_Language_br' => 'bretónčina',
+	'UserLanguage_Language_bs' => 'bosniačtina',
+	'UserLanguage_Language_ca' => 'katalánčina',
+	'UserLanguage_Language_ce' => 'čečenčina',
+	'UserLanguage_Language_ch' => 'čamorčina',
+	'UserLanguage_Language_co' => 'korzičtina',
+	'UserLanguage_Language_cr' => 'krí',
+	'UserLanguage_Language_cs' => 'čeština',
+	'UserLanguage_Language_cu' => 'cirkevná slovančina',
+	'UserLanguage_Language_cv' => 'čuvaština',
+	'UserLanguage_Language_cy' => 'waleština',
+	'UserLanguage_Language_da' => 'dánčina',
+	'UserLanguage_Language_de' => 'nemčina',
+	'UserLanguage_Language_dv' => 'divehi',
+	'UserLanguage_Language_dz' => 'dzongkä',
+	'UserLanguage_Language_ee' => 'eweština',
+	'UserLanguage_Language_el' => 'gréčtina',
+	'UserLanguage_Language_en' => 'angličtina',
+	'UserLanguage_Language_eo' => 'esperanto',
+	'UserLanguage_Language_es' => 'španielčina',
+	'UserLanguage_Language_et' => 'estónčina',
+	'UserLanguage_Language_eu' => 'baskičtina',
+	'UserLanguage_Language_fa' => 'perzština',
+	'UserLanguage_Language_ff' => 'fulbčina',
+	'UserLanguage_Language_fi' => 'fínčina',
+	'UserLanguage_Language_fj' => 'fidžijčina',
+	'UserLanguage_Language_fo' => 'faerčina',
+	'UserLanguage_Language_fr' => 'francúzština',
+	'UserLanguage_Language_fy' => 'západná frízština',
+	'UserLanguage_Language_ga' => 'írčina',
+	'UserLanguage_Language_gd' => 'škótčina',
+	'UserLanguage_Language_gl' => 'galícijčina',
+	'UserLanguage_Language_gn' => 'guaraní',
+	'UserLanguage_Language_gu' => 'gudžarátčina',
+	'UserLanguage_Language_gv' => 'mančina',
+	'UserLanguage_Language_ha' => 'hauština',
+	'UserLanguage_Language_he' => 'hebrejčina',
+	'UserLanguage_Language_hi' => 'hindčina',
+	'UserLanguage_Language_ho' => 'hiri motu',
+	'UserLanguage_Language_hr' => 'chorvátčina',
+	'UserLanguage_Language_ht' => 'haitský',
+	'UserLanguage_Language_hu' => 'maďarčina',
+	'UserLanguage_Language_hy' => 'arménčina',
+	'UserLanguage_Language_hz' => 'herero',
+	'UserLanguage_Language_ia' => 'interlingua',
+	'UserLanguage_Language_id' => 'indonézština',
+	'UserLanguage_Language_ie' => 'interlingue',
+	'UserLanguage_Language_ig' => 'igboština',
+	'UserLanguage_Language_is' => 'islandčina',
+	'UserLanguage_Language_it' => 'taliančina',
+	'UserLanguage_Language_ja' => 'japončina',
+	'UserLanguage_Language_jv' => 'jávčina',
+	'UserLanguage_Language_ka' => 'gruzínčina',
+	'UserLanguage_Language_kg' => 'konžština',
+	'UserLanguage_Language_kj' => 'kuaňama',
+	'UserLanguage_Language_kk' => 'kazaština',
+	'UserLanguage_Language_kl' => 'grónska eskimáčtina',
+	'UserLanguage_Language_km' => 'kambodžská khmérčina',
+	'UserLanguage_Language_kn' => 'kannadčina',
+	'UserLanguage_Language_ko' => 'kórejčina',
+	'UserLanguage_Language_kr' => 'kanurijčina',
+	'UserLanguage_Language_ks' => 'kašmírčina',
+	'UserLanguage_Language_ku' => 'kurdčina',
+	'UserLanguage_Language_kv' => 'komijčina',
+	'UserLanguage_Language_kw' => 'kornčina',
+	'UserLanguage_Language_ky' => 'kirgizština',
+	'UserLanguage_Language_la' => 'latinčina',
+	'UserLanguage_Language_lb' => 'luxemburčina',
+	'UserLanguage_Language_lg' => 'gandčina',
+	'UserLanguage_Language_ln' => 'lingalčina',
+	'UserLanguage_Language_lo' => 'laoština',
+	'UserLanguage_Language_lt' => 'litovčina',
+	'UserLanguage_Language_lu' => 'luba-katanga',
+	'UserLanguage_Language_lv' => 'lotyština',
+	'UserLanguage_Language_mg' => 'malgaština',
+	'UserLanguage_Language_mh' => 'kajin-majol',
+	'UserLanguage_Language_mi' => 'maorijčina',
+	'UserLanguage_Language_mk' => 'macedónčina',
+	'UserLanguage_Language_ml' => 'malajálamčina',
+	'UserLanguage_Language_mn' => 'mongolčina',
+	'UserLanguage_Language_mr' => 'maráthčina',
+	'UserLanguage_Language_ms' => 'malajčina',
+	'UserLanguage_Language_mt' => 'maltčina',
+	'UserLanguage_Language_my' => 'barmčina',
+	'UserLanguage_Language_na' => 'nauru',
+	'UserLanguage_Language_nb' => 'bokmål',
+	'UserLanguage_Language_ne' => 'nepálčina',
+	'UserLanguage_Language_ng' => 'ndonga',
+	'UserLanguage_Language_nl' => 'holandčina',
+	'UserLanguage_Language_nn' => 'nórsky nynorsk',
+	'UserLanguage_Language_no' => 'nórčina',
+	'UserLanguage_Language_nv' => 'navajo',
+	'UserLanguage_Language_ny' => 'čewa',
+	'UserLanguage_Language_oc' => 'okcitánčina',
+	'UserLanguage_Language_oj' => 'odžibva',
+	'UserLanguage_Language_om' => 'oromčina',
+	'UserLanguage_Language_or' => 'uríjčina',
+	'UserLanguage_Language_os' => 'osetčina',
+	'UserLanguage_Language_pa' => 'pandžábčina',
+	'UserLanguage_Language_pi' => 'pálí',
+	'UserLanguage_Language_pl' => 'poľština',
+	'UserLanguage_Language_ps' => 'paštúnčina',
+	'UserLanguage_Language_pt' => 'portugalčina',
+	'UserLanguage_Language_qu' => 'kečuánčina',
+	'UserLanguage_Language_rm' => 'rétorománčina',
+	'UserLanguage_Language_rn' => 'rundčina',
+	'UserLanguage_Language_ro' => 'rumunčina',
+	'UserLanguage_Language_ru' => 'ruština',
+	'UserLanguage_Language_rw' => 'rwandčina',
+	'UserLanguage_Language_sa' => 'sanskrit',
+	'UserLanguage_Language_sc' => 'sardínčina',
+	'UserLanguage_Language_sd' => 'sindhčina',
+	'UserLanguage_Language_sg' => 'sango',
+	'UserLanguage_Language_si' => 'sinhalčina',
+	'UserLanguage_Language_sk' => 'slovenčina',
+	'UserLanguage_Language_sl' => 'slovinčina',
+	'UserLanguage_Language_sm' => 'samojčina',
+	'UserLanguage_Language_sn' => 'šončina',
+	'UserLanguage_Language_so' => 'somálčina',
+	'UserLanguage_Language_sq' => 'albánčina',
+	'UserLanguage_Language_sr' => 'srbčina',
+	'UserLanguage_Language_ss' => 'svazijčina',
+	'UserLanguage_Language_st' => 'južná sothčina',
+	'UserLanguage_Language_su' => 'sundčina',
+	'UserLanguage_Language_sv' => 'švédčina',
+	'UserLanguage_Language_sw' => 'swahilčina',
+	'UserLanguage_Language_ta' => 'tamilčina',
+	'UserLanguage_Language_te' => 'telugčina',
+	'UserLanguage_Language_tg' => 'tadžičtina',
+	'UserLanguage_Language_th' => 'thajčina',
+	'UserLanguage_Language_ti' => 'tigrejčina',
+	'UserLanguage_Language_tk' => 'turkménčina',
+	'UserLanguage_Language_tl' => 'tagalčina',
+	'UserLanguage_Language_tn' => 'tswančina',
+	'UserLanguage_Language_to' => 'tonžtina',
+	'UserLanguage_Language_tr' => 'turečtina',
+	'UserLanguage_Language_ts' => 'tsonga',
+	'UserLanguage_Language_tt' => 'tatárčina',
+	'UserLanguage_Language_tw' => 'twi',
+	'UserLanguage_Language_ty' => 'tahitčina',
+	'UserLanguage_Language_ug' => 'ujgurčina',
+	'UserLanguage_Language_uk' => 'ukrajinčina',
+	'UserLanguage_Language_ur' => 'urdčina',
+	'UserLanguage_Language_uz' => 'uzbečtina',
+	'UserLanguage_Language_ve' => 'vendčina',
+	'UserLanguage_Language_vi' => 'vietnamčina',
+	'UserLanguage_Language_vo' => 'volapük',
+	'UserLanguage_Language_wa' => 'valónčina',
+	'UserLanguage_Language_wo' => 'wolof',
+	'UserLanguage_Language_xh' => 'xhosa',
+	'UserLanguage_Language_yi' => 'jidiš',
+	'UserLanguage_Language_yo' => 'jorubčina',
+	'UserLanguage_Language_za' => 'čuangčina',
+	'UserLanguage_Language_zh' => 'čínština',
+	'UserLanguage_Language_zu' => 'zuluština',
 );
