@@ -24,7 +24,7 @@ $translations = array(
 	'General_Yes' => '是',
 	'General_No' => '否',
 	'General_Delete' => '刪除',
-	'General_Report' => '回報',
+	'General_Report' => '報表',
 	'General_Edit' => '編輯',
 	'General_Download' => '下載',
 	'General_Ok' => 'OK',
@@ -46,6 +46,8 @@ $translations = array(
 	'General_CurrentMonth' => '本月',
 	'General_CurrentYear' => '今年',
 	'General_DateRange' => '日期範圍：',
+	'General_LastDaysShort' => '最近 %s 天內',
+	'General_LastDays' => '最近 %s 天內(含今天)',
 	'General_LoadingData' => '載入資料中...',
 	'General_Loading_js' => '載入中...',
 	'General_GoTo' => '前往 %s',
@@ -66,6 +68,7 @@ $translations = array(
 	'General_YourChangesHaveBeenSaved' => '您的變更已儲存！',
 	'General_ErrorRequest' => '噢！請求期間發生問題，請重試！',
 	'General_ColumnNbUniqVisitors' => '獨立非重返訪客數',
+	'General_ColumnNbUniqVisitorsDocumentation' => '前來訪問網站的不重複訪客數。即使單一訪客一天訪問數次，也僅計一回。',
 	'General_ColumnNbVisits' => '訪客',
 	'General_ColumnPercentageVisits' => '% 個訪客',
 	'General_ColumnNbActions' => '活動量',
@@ -77,12 +80,15 @@ $translations = array(
 	'General_VisitDuration' => '平均訪問時間（以秒為單位）',
 	'General_ColumnAvgTimeOnSite' => '平均網站停留時間',
 	'General_ColumnBounceRate' => '跳出率',
+	'General_ColumnBounceRateDocumentation' => '入站後，只看一頁而無任何互動便直接離站的訪次比例。',
 	'General_ColumnExitRate' => '退出率',
+	'General_ColumnExitRateDocumentation' => '檢視此頁面後便離站的訪次比例',
 	'General_ColumnPageviews' => '瀏覽量',
 	'General_ColumnUniquePageviews' => '獨立非重返訪客瀏覽數',
 	'General_ColumnBounces' => '跳出',
 	'General_ColumnEntrances' => '主要到達網頁',
-	'General_ColumnExits' => '主要離開網頁',
+	'General_ColumnExits' => '主要離站網頁',
+	'General_ColumnExitsDocumentation' => '檢視此頁面後便離站的訪次',
 	'General_ColumnAverageTimeOnPage' => '平均網站停留時間',
 	'General_ColumnValuePerVisit' => '每次造訪價值',
 	'General_ColumnVisitsWithConversions' => '造訪轉換',
@@ -105,7 +111,6 @@ $translations = array(
 	'General_MediumToHighTrafficItIsRecommendedTo' => '對於中或高流量的網站，我們建議最多每隔半小時(%s 秒)或每小時(%s 秒)處理報告。',
 	'General_RequiresFlash' => '在 Piwik 顯示圖表必須有 Flash',
 	'General_GraphHelp' => '更多關於 Piwik 顯示圖表的資訊',
-	'General_NoDataForGraph' => '此圖表無任何資料。',
 	'General_NoDataForTagCloud' => '此標籤雲無任何資料。',
 	'General_DisplaySimpleTable' => '顯示簡易表格',
 	'General_DisplayTableWithMoreMetrics' => '顯示更多數據表',
@@ -211,11 +216,21 @@ $translations = array(
 	'Actions_Actions' => '進站活動',
 	'Actions_SubmenuPages' => '瀏覽頁面',
 	'Actions_SubmenuPagesEntry' => '到達網頁',
-	'Actions_SubmenuPagesExit' => '離開網頁',
+	'Actions_WidgetPagesEntry' => '到達網頁',
+	'Actions_SubmenuPagesExit' => '離站網頁',
+	'Actions_WidgetPagesExit' => '離站網頁',
+	'Actions_EntryPageTitles' => '到達網頁標題',
+	'Actions_WidgetEntryPageTitles' => '到達網頁標題',
+	'Actions_ExitPageTitles' => '離站網頁標題',
+	'Actions_WidgetExitPageTitles' => '離站網頁標題',
 	'Actions_SubmenuPageTitles' => '網頁標題',
+	'Actions_WidgetPageTitles' => '網頁標題',
+	'Actions_WidgetSearchKeywords' => '站內搜尋關鍵字',
+	'Actions_WidgetSearchNoResultKeywords' => '查無資訊的關鍵字',
 	'Actions_SubmenuOutlinks' => '離開連結',
 	'Actions_SubmenuDownloads' => '下載',
 	'Actions_ColumnClicks' => '點擊次數',
+	'Actions_ColumnClicksDocumentation' => '此連結被點擊的次數。',
 	'Actions_ColumnUniqueClicks' => '絕對不重複點擊次數',
 	'Actions_ColumnDownloads' => '下載次數',
 	'Actions_ColumnUniqueDownloads' => '絕對不重複下載次數',
@@ -223,6 +238,14 @@ $translations = array(
 	'Actions_ColumnPageURL' => '頁面網址',
 	'Actions_ColumnClickedURL' => '點擊的 URL 位址',
 	'Actions_ColumnDownloadURL' => '下載的 URL 位址',
+	'Actions_ColumnEntryPageURL' => '到達網頁 URL',
+	'Actions_ColumnEntryPageTitle' => '到達網頁標題',
+	'Actions_ColumnExitPageURL' => '離站網頁 URL',
+	'Actions_ColumnExitPageTitle' => '離站網頁標題',
+	'Actions_ColumnNoResultKeyword' => '查無資料的關鍵字',
+	'Actions_EntryPagesReportDocumentation' => '此報告涵括指定時段內之到達網頁相關資訊。所謂的到達網頁，便是訪客入站時所訪問的第一個頁面。 %s 到達網頁之 URL 以資料夾結構顯示。',
+	'Actions_EntryPageTitlesReportDocumentation' => '此報告涵括指定時段內，到達網頁標題的相關資訊。',
+	'Actions_ExitPageTitlesReportDocumentation' => '此報表涵括關於指定時段內離站網頁之標題等資訊',
 	'AnonymizeIP_PluginDescription' => '隱藏訪客IP位址最後一個字元以符合你的當地隱私條例/政策。',
 	'API_PluginDescription' => '所有在 Piwik 的資料都能使用簡單的 APIs 取得。這個外掛是網頁服務的切入點，讓你可以以 xml, json, php, csv 及其他格式取得網站分析資料。',
 	'API_QuickDocumentationTitle' => 'API 快速說明文件',
@@ -250,51 +273,51 @@ $translations = array(
 	'CoreHome_PeriodWeeks' => '週',
 	'CoreHome_PeriodMonths' => '月',
 	'CoreHome_PeriodYears' => '年',
-	'CoreHome_DaySu_js' => '日',
-	'CoreHome_DayMo_js' => '一',
-	'CoreHome_DayTu_js' => '二',
-	'CoreHome_DayWe_js' => '三',
-	'CoreHome_DayTh_js' => '四',
-	'CoreHome_DayFr_js' => '五',
-	'CoreHome_DaySa_js' => '六',
-	'CoreHome_ShortDay_1_js' => '周日',
-	'CoreHome_ShortDay_2_js' => '周一',
-	'CoreHome_ShortDay_3_js' => '周二',
-	'CoreHome_ShortDay_4_js' => '周三',
-	'CoreHome_ShortDay_5_js' => '周四',
-	'CoreHome_ShortDay_6_js' => '周五',
-	'CoreHome_ShortDay_7_js' => '周六',
-	'CoreHome_LongDay_1_js' => '星期日',
-	'CoreHome_LongDay_2_js' => '星期一',
-	'CoreHome_LongDay_3_js' => '星期二',
-	'CoreHome_LongDay_4_js' => '星期三',
-	'CoreHome_LongDay_5_js' => '星期四',
-	'CoreHome_LongDay_6_js' => '星期五',
-	'CoreHome_LongDay_7_js' => '星期六',
-	'CoreHome_ShortMonth_1_js' => '一',
-	'CoreHome_ShortMonth_2_js' => '二',
-	'CoreHome_ShortMonth_3_js' => '三',
-	'CoreHome_ShortMonth_4_js' => '四',
-	'CoreHome_ShortMonth_5_js' => '五',
-	'CoreHome_ShortMonth_6_js' => '六',
-	'CoreHome_ShortMonth_7_js' => '七',
-	'CoreHome_ShortMonth_8_js' => '八',
-	'CoreHome_ShortMonth_9_js' => '九',
-	'CoreHome_ShortMonth_10_js' => '十',
-	'CoreHome_ShortMonth_11_js' => '十一',
-	'CoreHome_ShortMonth_12_js' => '十二',
-	'CoreHome_MonthJanuary_js' => '一月',
-	'CoreHome_MonthFebruary_js' => '二月',
-	'CoreHome_MonthMarch_js' => '三月',
-	'CoreHome_MonthApril_js' => '四月',
-	'CoreHome_MonthMay_js' => '五月',
-	'CoreHome_MonthJune_js' => '六月',
-	'CoreHome_MonthJuly_js' => '七月',
-	'CoreHome_MonthAugust_js' => '八月',
-	'CoreHome_MonthSeptember_js' => '九月',
-	'CoreHome_MonthOctober_js' => '十月',
-	'CoreHome_MonthNovember_js' => '十一月',
-	'CoreHome_MonthDecember_js' => '十二月',
+	'General_DaySu_js' => '日',
+	'General_DayMo_js' => '一',
+	'General_DayTu_js' => '二',
+	'General_DayWe_js' => '三',
+	'General_DayTh_js' => '四',
+	'General_DayFr_js' => '五',
+	'General_DaySa_js' => '六',
+	'General_ShortDay_1_js' => '周日',
+	'General_ShortDay_2_js' => '周一',
+	'General_ShortDay_3_js' => '周二',
+	'General_ShortDay_4_js' => '周三',
+	'General_ShortDay_5_js' => '周四',
+	'General_ShortDay_6_js' => '周五',
+	'General_ShortDay_7_js' => '周六',
+	'General_LongDay_1_js' => '星期日',
+	'General_LongDay_2_js' => '星期一',
+	'General_LongDay_3_js' => '星期二',
+	'General_LongDay_4_js' => '星期三',
+	'General_LongDay_5_js' => '星期四',
+	'General_LongDay_6_js' => '星期五',
+	'General_LongDay_7_js' => '星期六',
+	'General_ShortMonth_1_js' => '一',
+	'General_ShortMonth_2_js' => '二',
+	'General_ShortMonth_3_js' => '三',
+	'General_ShortMonth_4_js' => '四',
+	'General_ShortMonth_5_js' => '五',
+	'General_ShortMonth_6_js' => '六',
+	'General_ShortMonth_7_js' => '七',
+	'General_ShortMonth_8_js' => '八',
+	'General_ShortMonth_9_js' => '九',
+	'General_ShortMonth_10_js' => '十',
+	'General_ShortMonth_11_js' => '十一',
+	'General_ShortMonth_12_js' => '十二',
+	'General_MonthJanuary_js' => '一月',
+	'General_MonthFebruary_js' => '二月',
+	'General_MonthMarch_js' => '三月',
+	'General_MonthApril_js' => '四月',
+	'General_MonthMay_js' => '五月',
+	'General_MonthJune_js' => '六月',
+	'General_MonthJuly_js' => '七月',
+	'General_MonthAugust_js' => '八月',
+	'General_MonthSeptember_js' => '九月',
+	'General_MonthOctober_js' => '十月',
+	'General_MonthNovember_js' => '十一月',
+	'General_MonthDecember_js' => '十二月',
 	'CorePluginsAdmin_PluginDescription' => '外掛管理介面。',
 	'CorePluginsAdmin_Plugins' => '外掛',
 	'CorePluginsAdmin_PluginsManagement' => '外掛管理',
@@ -361,13 +384,14 @@ $translations = array(
 	'Dashboard_Dashboard' => '展示板',
 	'Dashboard_DeleteWidgetConfirm' => '您確定要從展示板中刪除此組件嗎？',
 	'Dashboard_SelectWidget' => '請選取欲增加至展示板的組件',
-	'Dashboard_AddPreviewedWidget_js' => '增加已預覽的組件至展示板',
+	'Dashboard_AddPreviewedWidget_js' => '將組件加入展示板',
 	'Dashboard_WidgetPreview_js' => '組件預覽',
 	'Dashboard_Close_js' => '關閉',
 	'Dashboard_TitleWidgetInDashboard_js' => '組件已存在於展示板',
 	'Dashboard_TitleClickToAdd_js' => '點擊以增加至展示板',
 	'Dashboard_LoadingWidget_js' => '載入組件中，請稍候...',
 	'Dashboard_WidgetNotFound_js' => '找不到組件',
+	'Dashboard_WidgetsAndDashboard' => '組件與展示版',
 	'DBStats_PluginDescription' => '這個外掛能回報 Piwik 的資料表使用情形。',
 	'DBStats_DatabaseUsage' => '資料庫使用狀況',
 	'DBStats_MainDescription' => 'Piwik 儲存所有你的網站分析資料於 MySQL 資料庫中。目前， Piwik 資料表已經使用了 %s。',
@@ -406,6 +430,7 @@ $translations = array(
 	'Feedback_ThePiwikTeam' => 'Piwik 小組',
 	'Feedback_ExceptionBodyLength' => '訊息至少要有 %s 的字元以上。',
 	'Feedback_ExceptionNoUrls' => '訊息不能包含一個網址，藉此避免垃圾訊息。',
+	'Feedback_TopLinkTooltip' => '請分享您的意見，或提出專業支援要求。',
 	'Goals_Goals' => '目標',
 	'Goals_GoalsOverview' => '目標總覽',
 	'Goals_GoalsManagement' => '目標管理',
@@ -475,7 +500,6 @@ $translations = array(
 	'Installation_PleaseFixTheFollowingErrors' => '請修復以下錯誤',
 	'Installation_LargePiwikInstances' => 'Piwik 給予大型網站的協助',
 	'Installation_JsTag' => 'JavaScript 原始碼',
-	'Installation_JsTagArchivingHelp' => '在一個中或高流量的網站，請查閱<a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">如何設定自動彙整頁面</a>來使 Piwik 運作的更順暢！',
 	'Installation_Congratulations' => '恭喜你',
 	'Installation_CongratulationsHelp' => '<p>恭喜！ 你的 Piwik 安裝已經完成。</p><p>請確認你的 JavaScript 追蹤碼已插入至你的網頁中，然後等候你的首位訪客吧！</p>',
 	'Installation_ContinueToPiwik' => '繼續 Piwik',
@@ -548,9 +572,13 @@ $translations = array(
 	'Live_LinkVisitorLog' => '查看詳細的訪客記錄',
 	'Live_Actions' => '動作',
 	'Live_Action' => '動作',
+	'Live_VisitorsInRealTime' => '目前正在參觀網站的訪客',
 	'Live_VisitorLog' => '訪客記錄',
 	'Live_Time' => '時間',
 	'Live_Referrer_URL' => '推薦連結',
+	'Live_LastMinutes' => '最近 %s 分鐘內',
+	'Live_LastHours' => '最近 %s 小時內',
+	'Live_VisitorsLastVisit' => '此訪客於 %s 天前曾來訪',
 	'Login_PluginDescription' => '登入驗證外掛，超級使用者從 config/config.inc.php 檔案讀取憑證，其他使用者則從資料庫。可以很容易取代或導入新的驗證機制（OpenID, htaccess, 自訂驗證等等）。',
 	'Login_LoginPasswordNotCorrect' => '使用者名稱 & 密碼不正確。',
 	'Login_Password' => '密碼',
@@ -563,6 +591,7 @@ $translations = array(
 	'Login_PasswordsDoNotMatch' => '密碼並不相符！',
 	'Login_InvalidUsernameEmail' => '無效的使用者名稱 和/或 E-mail 位址',
 	'Login_InvalidOrExpiredToken' => '權杖不正確或已過期！',
+	'Login_MailTopicPasswordChange' => '確認密碼變更',
 	'Login_ContactAdmin' => '可能原因：您的伺服主機可能已經停用了 mail() 函式。<br />請聯絡您的 Piwik 管理員！',
 	'Login_ExceptionPasswordMD5HashExpected' => '密碼參數會是一個 MD5 雜湊加密的密碼！',
 	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => '超級使用者無法以 \'%s\' 機制通過身份驗證。',
@@ -611,7 +640,8 @@ $translations = array(
 	'Referers_WidgetKeywords' => '關鍵字清單',
 	'Referers_WidgetCampaigns' => '廣告活動清單',
 	'Referers_WidgetExternalWebsites' => '外部網站清單',
-	'Referers_WidgetSearchEngines' => '最佳搜尋引擎',
+	'Referers_WidgetSocials' => '社交網站清單',
+	'Referers_WidgetSearchEngines' => '搜尋引擎',
 	'Referers_WidgetOverview' => '總覽',
 	'SecurityInfo_PluginDescription' => '基於 PhpSecInfo 從 PHP 安全協會，這個外掛提供安全性資訊，並提供你的PHP環境改善建議。它是一個多層次的安全工具。它不會從原始碼 / 應用程式來取代。',
 	'SecurityInfo_Security' => '安全性',
@@ -689,6 +719,7 @@ $translations = array(
 	'UserCountry_DistinctCountries' => '%s 個不同的國家',
 	'UserCountry_Location' => '位置',
 	'UserCountry_SubmenuLocations' => '所在地',
+	'UserCountry_WidgetLocation' => '訪客所在地點',
 	'UserCountry_country_ac' => '英屬亞森松島',
 	'UserCountry_country_ad' => '安道爾',
 	'UserCountry_country_ae' => '阿拉伯聯合大公國',
@@ -967,7 +998,9 @@ $translations = array(
 	'UserSettings_Browsers' => '使用瀏覽器',
 	'UserSettings_Plugins' => '瀏覽器外掛',
 	'UserSettings_Configurations' => '客戶端配置',
+	'UserSettings_WidgetGlobalVisitorsDocumentation' => '此報表列出貴站訪客最常見的設定配置。設定配置包含作業系統、瀏覽器、螢幕解析度等資訊。',
 	'UserSettings_OperatingSystems' => '作業系統',
+	'UserSettings_WidgetOperatingSystemFamily' => '作業系統家族',
 	'UserSettings_Resolutions' => '解析度',
 	'UserSettings_WideScreen' => '寬螢幕',
 	'UserSettings_ColumnBrowserFamily' => '瀏覽器家族',
@@ -979,10 +1012,11 @@ $translations = array(
 	'UserSettings_ColumnTypeOfScreen' => '螢幕類型',
 	'UserSettings_WidgetResolutions' => '畫面解析度',
 	'UserSettings_WidgetBrowsers' => '使用瀏覽器',
+	'UserSettings_WidgetBrowserVersion' => '瀏覽器版本',
 	'UserSettings_WidgetPlugins' => '瀏覽器外掛清單',
 	'UserSettings_PluginDetectionDoesNotWorkInIE' => '注意：外掛偵測無法在 Internet Explorer 上運作。這個報告僅提供非 IE 瀏覽器。',
 	'UserSettings_WidgetWidescreen' => '傳統螢幕 / 寬螢幕',
-	'UserSettings_WidgetBrowserFamilies' => '瀏覽器依家族分',
+	'UserSettings_WidgetBrowserFamilies' => '瀏覽器家族',
 	'UserSettings_WidgetOperatingSystems' => '作業系統',
 	'UserSettings_WidgetGlobalVisitors' => '全域訪客配置',
 	'UserSettings_SubmenuSettings' => '環境設定值',
@@ -1039,13 +1073,13 @@ $translations = array(
 	'VisitFrequency_ColumnReturningVisits' => '重返造訪',
 	'VisitFrequency_ColumnActionsByReturningVisits' => '重返造訪的活動數',
 	'VisitFrequency_ColumnAverageVisitDurationForReturningVisitors' => '重返造訪的平均訪問時間（以秒為單位）',
-	'VisitFrequency_ColumnBounceRateForReturningVisits' => '重返造訪的跳出率',
+	'VisitFrequency_ColumnBounceRateForReturningVisits' => '回訪客的跳出率',
 	'VisitFrequency_ColumnAvgActionsPerReturningVisit' => '每個重返造訪的平均活動數',
 	'VisitFrequency_ReturnVisits' => '%s 個重返造訪數',
 	'VisitFrequency_ReturnActions' => '%s 個活動數由重返造訪所產生',
 	'VisitFrequency_ReturnAvgActions' => '%s 個活動數每個重返造訪',
 	'VisitFrequency_ReturnAverageVisitDuration' => '%s 重返造訪的平均訪問時間',
-	'VisitFrequency_ReturnBounceRate' => '%s 個重返造訪離開率（於瀏覽單一網頁後離開網站）',
+	'VisitFrequency_ReturnBounceRate' => '回訪客跳出率 %s（僅瀏覽一頁便離站）',
 	'VisitFrequency_WidgetOverview' => '造訪頻率總覽',
 	'VisitFrequency_WidgetGraphReturning' => '重返造訪圖表',
 	'VisitFrequency_SubmenuFrequency' => '造訪頻率',
@@ -1065,7 +1099,7 @@ $translations = array(
 	'VisitorInterest_ColumnVisitDuration' => '造訪停留時間',
 	'VisitorInterest_ColumnPagesPerVisit' => '每次造訪瀏覽的頁面數',
 	'VisitorInterest_WidgetLengths' => '訪客停留時間',
-	'VisitorInterest_WidgetPages' => '每次造訪瀏覽的頁面數',
+	'VisitorInterest_WidgetPages' => '平均瀏覽頁數',
 	'VisitorInterest_Engagement' => '忠誠度',
 	'VisitorInterest_PlusXMin' => '%s 分',
 	'VisitorInterest_BetweenXYMinutes' => '%1$s-%2$s 分',
@@ -1074,13 +1108,13 @@ $translations = array(
 	'VisitorInterest_BetweenXYSeconds' => '%1$s-%2$s 秒',
 	'VisitsSummary_PluginDescription' => '一般分析項目報告：造訪次數、絕對不重複訪客、活動數、跳出率等等。',
 	'VisitsSummary_VisitsSummary' => '訪客總覽',
-	'VisitsSummary_NbVisits' => '%s 個造訪次數',
-	'VisitsSummary_NbUniqueVisitors' => '%s 個絕對不重複訪客',
+	'VisitsSummary_NbVisits' => '造訪次數 %s 次',
+	'VisitsSummary_NbUniqueVisitors' => '不重複訪客 %s 位',
 	'VisitsSummary_NbActionsDescription' => '%s 個活動（檢視網頁、下載和離開連結）',
-	'VisitsSummary_AverageVisitDuration' => '%s 平均訪問時間',
+	'VisitsSummary_AverageVisitDuration' => '平均訪問時間 %s',
 	'VisitsSummary_MaxNbActions' => '%s 由單一次造訪所產生的最大活動數',
 	'VisitsSummary_NbActionsPerVisit' => '%s 每個訪客的活動數',
-	'VisitsSummary_NbVisitsBounced' => '%s 跳出率（於瀏覽單一網頁後離開網站）',
+	'VisitsSummary_NbVisitsBounced' => '跳出率 %s（僅瀏覽一頁便離站）',
 	'VisitsSummary_GenerateTime' => '頁面生成時間： %s 秒',
 	'VisitsSummary_GenerateQueries' => '%s 個查詢已執行',
 	'VisitsSummary_WidgetLastVisits' => '最近造訪圖表',
@@ -1098,6 +1132,7 @@ $translations = array(
 	'VisitTime_SubmenuTimes' => '造訪時段',
 	'VisitTime_NHour' => '%s 時',
 	'Widgetize_PluginDescription' => '這個外掛讓你輕鬆輸出任何 Piwik 模組至你的網誌、網站或 iGoogle 及 Netvibes!',
+	'Widgetize_TopLinkTooltip' => '將 Piwik 報表匯出為組件，並於你的 APP 中以 iframe 嵌入展示板。',
 	'PDFReports_EmailReports' => '郵寄報表',
 	'PDFReports_SendReportNow' => '立即寄送報表',
 	'PDFReports_EmailSchedule' => '郵寄排程',
@@ -1109,4 +1144,194 @@ $translations = array(
 	'PDFReports_PiwikReports' => 'Piwik 報表',
 	'PDFReports_EmailHello' => '您好，',
 	'PDFReports_PleaseFindAttachedFile' => '請找到為了 %2$s 您的報表 %1$s 的附件檔！',
+	'UserLanguage_Language_aa' => '阿法文',
+	'UserLanguage_Language_ab' => '阿布哈西亚文',
+	'UserLanguage_Language_ae' => '阿维斯塔文',
+	'UserLanguage_Language_af' => '南非荷兰文',
+	'UserLanguage_Language_ak' => '阿肯文',
+	'UserLanguage_Language_am' => '阿姆哈拉文',
+	'UserLanguage_Language_an' => '阿拉贡文',
+	'UserLanguage_Language_ar' => '阿拉伯文',
+	'UserLanguage_Language_as' => '阿萨姆文',
+	'UserLanguage_Language_av' => '阿瓦尔文',
+	'UserLanguage_Language_ay' => '艾马拉文',
+	'UserLanguage_Language_az' => '阿塞拜疆文',
+	'UserLanguage_Language_ba' => '巴什客尔文',
+	'UserLanguage_Language_be' => '白俄罗斯文',
+	'UserLanguage_Language_bg' => '保加利亚文',
+	'UserLanguage_Language_bh' => '比哈尔文',
+	'UserLanguage_Language_bi' => '比斯拉马文',
+	'UserLanguage_Language_bm' => '班巴拉文',
+	'UserLanguage_Language_bn' => '孟加拉文',
+	'UserLanguage_Language_bo' => '藏文',
+	'UserLanguage_Language_br' => '布里多尼文',
+	'UserLanguage_Language_bs' => '波斯尼亚文',
+	'UserLanguage_Language_ca' => '加泰罗尼亚文',
+	'UserLanguage_Language_ce' => '车臣文',
+	'UserLanguage_Language_ch' => '查莫罗文',
+	'UserLanguage_Language_co' => '科西嘉文',
+	'UserLanguage_Language_cr' => '克里族文',
+	'UserLanguage_Language_cs' => '捷克文',
+	'UserLanguage_Language_cu' => '宗教斯拉夫文',
+	'UserLanguage_Language_cv' => '楚瓦什文',
+	'UserLanguage_Language_cy' => '威尔士文',
+	'UserLanguage_Language_da' => '丹麦文',
+	'UserLanguage_Language_de' => '德文',
+	'UserLanguage_Language_dv' => '迪维希文',
+	'UserLanguage_Language_dz' => '不丹文',
+	'UserLanguage_Language_ee' => '埃维文',
+	'UserLanguage_Language_el' => '希腊文',
+	'UserLanguage_Language_en' => '英文',
+	'UserLanguage_Language_eo' => '世界文',
+	'UserLanguage_Language_es' => '西班牙文',
+	'UserLanguage_Language_et' => '爱沙尼亚文',
+	'UserLanguage_Language_eu' => '巴斯克文',
+	'UserLanguage_Language_fa' => '波斯文',
+	'UserLanguage_Language_ff' => '夫拉文',
+	'UserLanguage_Language_fi' => '芬兰文',
+	'UserLanguage_Language_fj' => '斐济文',
+	'UserLanguage_Language_fo' => '法罗文',
+	'UserLanguage_Language_fr' => '法文',
+	'UserLanguage_Language_fy' => '弗里斯兰文',
+	'UserLanguage_Language_ga' => '爱尔兰文',
+	'UserLanguage_Language_gd' => '苏格兰盖尔文',
+	'UserLanguage_Language_gl' => '加利西亚文',
+	'UserLanguage_Language_gn' => '瓜拉尼文',
+	'UserLanguage_Language_gu' => '古加拉提文',
+	'UserLanguage_Language_gv' => '马恩岛文',
+	'UserLanguage_Language_ha' => '豪撒文',
+	'UserLanguage_Language_he' => '希伯来文',
+	'UserLanguage_Language_hi' => '印地文',
+	'UserLanguage_Language_ho' => '希里莫图文',
+	'UserLanguage_Language_hr' => '克罗地亚文',
+	'UserLanguage_Language_ht' => '海地文',
+	'UserLanguage_Language_hu' => '匈牙利文',
+	'UserLanguage_Language_hy' => '亚美尼亚文',
+	'UserLanguage_Language_hz' => '赫雷罗文',
+	'UserLanguage_Language_ia' => '国际语',
+	'UserLanguage_Language_id' => '印度尼西亚文',
+	'UserLanguage_Language_ie' => '国际语E',
+	'UserLanguage_Language_ig' => '伊格博文',
+	'UserLanguage_Language_ii' => '四川话',
+	'UserLanguage_Language_ik' => '依奴皮维克文',
+	'UserLanguage_Language_io' => '伊多文',
+	'UserLanguage_Language_is' => '冰岛文',
+	'UserLanguage_Language_it' => '意大利文',
+	'UserLanguage_Language_iu' => '伊努伊特文',
+	'UserLanguage_Language_ja' => '日文',
+	'UserLanguage_Language_jv' => '爪哇文',
+	'UserLanguage_Language_ka' => '格鲁吉亚文',
+	'UserLanguage_Language_kg' => '刚果文',
+	'UserLanguage_Language_ki' => '吉库尤文',
+	'UserLanguage_Language_kj' => '宽亚玛文',
+	'UserLanguage_Language_kk' => '哈萨克文',
+	'UserLanguage_Language_kl' => '格陵兰文',
+	'UserLanguage_Language_km' => '柬埔寨文',
+	'UserLanguage_Language_kn' => '坎纳达文',
+	'UserLanguage_Language_ko' => '韩文',
+	'UserLanguage_Language_kr' => '卡努里文',
+	'UserLanguage_Language_ks' => '克什米尔文',
+	'UserLanguage_Language_ku' => '库尔德文',
+	'UserLanguage_Language_kv' => '科米文',
+	'UserLanguage_Language_kw' => '凯尔特文',
+	'UserLanguage_Language_ky' => '吉尔吉斯文',
+	'UserLanguage_Language_la' => '拉丁文',
+	'UserLanguage_Language_lb' => '卢森堡文',
+	'UserLanguage_Language_lg' => '卢干达文',
+	'UserLanguage_Language_li' => '淋布尔吉文',
+	'UserLanguage_Language_ln' => '林加拉文',
+	'UserLanguage_Language_lo' => '老挝文',
+	'UserLanguage_Language_lt' => '立陶宛文',
+	'UserLanguage_Language_lu' => '鲁巴加丹加文',
+	'UserLanguage_Language_lv' => '拉脱维亚文',
+	'UserLanguage_Language_mg' => '马尔加什文',
+	'UserLanguage_Language_mh' => '马绍尔文',
+	'UserLanguage_Language_mi' => '毛利文',
+	'UserLanguage_Language_mk' => '马其顿文',
+	'UserLanguage_Language_ml' => '马来亚拉姆文',
+	'UserLanguage_Language_mn' => '蒙古文',
+	'UserLanguage_Language_mr' => '马拉地文',
+	'UserLanguage_Language_ms' => '马来文',
+	'UserLanguage_Language_mt' => '马耳他文',
+	'UserLanguage_Language_my' => '缅甸文',
+	'UserLanguage_Language_na' => '瑙鲁文',
+	'UserLanguage_Language_nb' => '挪威博克马尔文',
+	'UserLanguage_Language_nd' => '北恩德贝勒文',
+	'UserLanguage_Language_ne' => '尼泊尔文',
+	'UserLanguage_Language_ng' => '恩东加文',
+	'UserLanguage_Language_nl' => '荷兰文',
+	'UserLanguage_Language_nn' => '挪威尼诺斯克文',
+	'UserLanguage_Language_no' => '挪威文',
+	'UserLanguage_Language_nr' => '南部恩德贝勒文',
+	'UserLanguage_Language_nv' => '纳瓦霍文',
+	'UserLanguage_Language_ny' => '尼扬贾文；齐切瓦文；切瓦文',
+	'UserLanguage_Language_oc' => '奥克西唐语',
+	'UserLanguage_Language_oj' => '奥吉布瓦文',
+	'UserLanguage_Language_om' => '奥洛莫文',
+	'UserLanguage_Language_or' => '欧里亚文',
+	'UserLanguage_Language_os' => '奥塞梯文',
+	'UserLanguage_Language_pa' => '旁遮普文',
+	'UserLanguage_Language_pi' => '巴利文',
+	'UserLanguage_Language_pl' => '波兰文',
+	'UserLanguage_Language_ps' => '普什图文',
+	'UserLanguage_Language_pt' => '葡萄牙文',
+	'UserLanguage_Language_qu' => '盖丘亚文',
+	'UserLanguage_Language_rm' => '列托－罗曼文',
+	'UserLanguage_Language_rn' => '基隆迪文',
+	'UserLanguage_Language_ro' => '罗马尼亚文',
+	'UserLanguage_Language_ru' => '俄文',
+	'UserLanguage_Language_rw' => '卢旺达文',
+	'UserLanguage_Language_sa' => '梵文',
+	'UserLanguage_Language_sc' => '萨丁文',
+	'UserLanguage_Language_sd' => '信德文',
+	'UserLanguage_Language_se' => '北萨米文',
+	'UserLanguage_Language_sg' => '桑戈文',
+	'UserLanguage_Language_si' => '僧伽罗文',
+	'UserLanguage_Language_sk' => '斯洛伐克文',
+	'UserLanguage_Language_sl' => '斯洛文尼亚文',
+	'UserLanguage_Language_sm' => '萨摩亚文',
+	'UserLanguage_Language_sn' => '绍纳文',
+	'UserLanguage_Language_so' => '索马里文',
+	'UserLanguage_Language_sq' => '阿尔巴尼亚文',
+	'UserLanguage_Language_sr' => '塞尔维亚文',
+	'UserLanguage_Language_ss' => '斯瓦特文',
+	'UserLanguage_Language_st' => '塞索托文',
+	'UserLanguage_Language_su' => '巽他语',
+	'UserLanguage_Language_sv' => '瑞典文',
+	'UserLanguage_Language_sw' => '斯瓦希里文',
+	'UserLanguage_Language_ta' => '泰米尔文',
+	'UserLanguage_Language_te' => '泰卢固文',
+	'UserLanguage_Language_tg' => '塔吉克文',
+	'UserLanguage_Language_th' => '泰文',
+	'UserLanguage_Language_ti' => '提格里尼亚文',
+	'UserLanguage_Language_tk' => '土库曼文',
+	'UserLanguage_Language_tl' => '塔加洛语',
+	'UserLanguage_Language_tn' => '塞茨瓦纳文',
+	'UserLanguage_Language_to' => '汤加文',
+	'UserLanguage_Language_tr' => '土耳其文',
+	'UserLanguage_Language_ts' => '宗加文',
+	'UserLanguage_Language_tt' => '塔塔尔文',
+	'UserLanguage_Language_tw' => '特威文',
+	'UserLanguage_Language_ty' => '塔西提文',
+	'UserLanguage_Language_ug' => '维吾尔文',
+	'UserLanguage_Language_uk' => '乌克兰文',
+	'UserLanguage_Language_ur' => '乌尔都文',
+	'UserLanguage_Language_uz' => '乌兹别克文',
+	'UserLanguage_Language_ve' => '文达文',
+	'UserLanguage_Language_vi' => '越南文',
+	'UserLanguage_Language_vo' => '沃拉普克文',
+	'UserLanguage_Language_wa' => '瓦隆文',
+	'UserLanguage_Language_wo' => '沃洛夫文',
+	'UserLanguage_Language_xh' => '科萨文',
+	'UserLanguage_Language_yi' => '依地文',
+	'UserLanguage_Language_yo' => '约鲁巴文',
+	'UserLanguage_Language_za' => '壮语',
+	'UserLanguage_Language_zh' => '中文',
+	'UserLanguage_Language_zu' => '祖鲁文',
+
+	// FOR REVIEW
+	'EntryPage_Bounces' => '跳出次數',
+	'Forecast_Bounce' => '跳出訪客數',
+	'Forecast_Visitors' => '訪客',
+	'UserLanguage_WidgetLanguage' => '訪客使用語言',
 );
